@@ -20,48 +20,72 @@
 //
 
 #include "Exception.h"
+#include "Backtrace.h"
 #include "Logger.h"
+#include "OSHelper.h"
 
 #include <cstdlib>
+#include <sstream>
 
 using namespace std;
 
 namespace avg {
 
-Exception::Exception (int Code, const std::string& sErr)
-    : m_Code (Code),
+Exception::Exception(int code, const string& sErr)
+    : m_Code (code),
       m_sErr (sErr)
 {
 }
 
-Exception::Exception (const Exception& ex)
-    : m_Code (ex.GetCode ()),
-      m_sErr (ex.GetStr ())
+Exception::Exception(const Exception& ex)
+    : m_Code (ex.GetCode()),
+      m_sErr (ex.GetStr())
 {
 }
 
-
 Exception::~Exception()
 {
 }
 
-
-int Exception::GetCode () const
+int Exception::GetCode() const
 {
     return m_Code;
 }
 
-const string& Exception::GetStr () const
+const string& Exception::GetStr() const
 {
     return m_sErr;
 }
 
-void fatalError(const std::string& sMsg)
+void fatalError(const string& sMsg)
 {
     AVG_TRACE(Logger::ERROR, "Internal error: "+sMsg+" Aborting.");
     exit(-1);
 }
 
-
+void debugBreak()
+{
+#ifdef _WIN32
+    __asm int 3;
+#else
+    asm("int $3");
+#endif
 }
 
+void avgAssert(bool b, const char * pszFile, int line)
+{
+    if (!b) {
+        string sDummy;
+        static bool bBreak = getEnv("AVG_BREAK_ON_ASSERT", sDummy);
+        if (bBreak) {
+            debugBreak();
+        } else {
+            stringstream ss;
+            ss << "Assertion failed in " << pszFile << ": " << line;
+            dumpBacktrace();
+            throw(Exception(AVG_ERR_ASSERT_FAILED, ss.str()));
+        }
+    }
+}
+
+}
