@@ -45,7 +45,7 @@
 #define AVG_ERR_LOAD_DURING_PLAYBACK 19
 #define AVG_ERR_CANT_PARSE_STRING 20
 #define AVG_ERR_INVALID_CAPTURE 21
-#define AVG_ERR_QUEUE_EMPTY 22
+
 #define AVG_ERR_NO_NODE 23
 #define AVG_ERR_NO_ARG 24
 #define AVG_ERR_INVALID_ARGS 25
@@ -55,24 +55,30 @@
 #define AVG_ERR_CAMERA_FATAL 29
 #define AVG_ERR_CAMERA_NONFATAL 30
 #define AVG_ERR_DEPRECATED 31
+#define AVG_ERR_ASSERT_FAILED 32
+#define AVG_ERR_MT_INIT 33
 
 namespace avg {
  
 class AVG_API Exception 
 {
     public:
-        Exception (int Code, const std::string& sErr = "");
-        Exception (const Exception& ex);
-        virtual ~Exception ();
-        virtual int GetCode () const;
-        virtual const std::string& GetStr () const;
+        Exception(int code, const std::string& sErr = "");
+        Exception(const Exception& ex);
+        virtual ~Exception();
+        virtual int GetCode() const;
+        virtual const std::string& GetStr() const;
 
     private:
         int m_Code;
         std::string m_sErr;
 };
 
-void fatalError(const std::string& sMsg);
+void AVG_API fatalError(const std::string& sMsg);
+void AVG_API debugBreak();
+void AVG_API avgAssert(bool b, const char * pszFile, int line);
+
+#define AVG_ASSERT(b) avgAssert((b) != 0, __FILE__, __LINE__);
 
 }
 
