@@ -27,11 +27,13 @@
 
 namespace avg {
     
-std::string getPath(const std::string& Filename);
-std::string getFilenamePart(const std::string& Filename);
+std::string getPath(const std::string& sFilename);
+std::string getFilenamePart(const std::string& sFilename);
+std::string getCWD();
+
 bool isAbsPath(const std::string& path);
 
-bool fileExists(const std::string& FileName);
+bool fileExists(const std::string& sFilename);
 
 void readWholeFile(const std::string& sFilename, std::string& sContents);
 
@@ -39,6 +41,7 @@ void writeWholeFile(const std::string& sFilename, const std::string& sContent);
 
 void copyFile(const std::string& sSourceFile, const std::string& sDestFile);
 
+
 #ifdef WIN32
 #define unlink _unlink
 #endif
