@@ -62,7 +62,7 @@ bool lineSegmentsIntersect(const DLineSegment& l0, const DLineSegment& l1)
         x1hi=l0.p1.x; 
         x1lo=l0.p0.x;
     }
-    if (xdiff1>0) {
+    if (xdiff1 > 0) {
         if (x1hi < l1.p1.x || l1.p0.x < x1lo) {
             return false;
         }
@@ -78,14 +78,14 @@ bool lineSegmentsIntersect(const DLineSegment& l0, const DLineSegment& l1)
     double y1lo, y1hi;
 
     /* Y bound box test*/
-    if (ydiff0<0) {
+    if (ydiff0 < 0) {
         y1lo=l0.p1.y; 
         y1hi=l0.p0.y;
     } else {
         y1hi=l0.p1.y; 
         y1lo=l0.p0.y;
     }
-    if (ydiff1>0) {
+    if (ydiff1 > 0) {
         if (y1hi < l1.p1.y || l1.p0.y < y1lo) {
             return false;
         }
@@ -99,28 +99,28 @@ bool lineSegmentsIntersect(const DLineSegment& l0, const DLineSegment& l1)
     double Cy = l0.p0.y-l1.p0.y;
     double d = ydiff1*Cx - xdiff1*Cy;                  /* alpha numerator*/
     double f = ydiff0*xdiff1 - xdiff0*ydiff1;          /* both denominator*/
-    if (f>0) {                                         /* alpha tests*/
-        if (d<0 || d>f) {
+    if (f > 0) {                                       /* alpha tests*/
+        if (d < 0 || d > f) {
             return false;
         }
     } else {
-        if (d>0 || d<f) {
+        if (d > 0 || d < f) {
             return false;
         }
     }
 
     double e = xdiff0*Cy - ydiff0*Cx;                  /* beta numerator*/
-    if(f>0) {                                          /* beta tests*/
-        if (e<0 || e>f) {
+    if(f > 0) {                                        /* beta tests*/
+        if (e < 0 || e > f) {
             return false;
         }
     } else {
-        if (e>0 || e<f) {
+        if (e > 0 || e < f) {
             return false;
         }
     }
 
-    if (f==0) {
+    if (f == 0) {
         // Theoretically, lines could still intersect in this case, but we don't care
         // because given numerical inaccuracies, the result is random anyway :-).
         return false;
@@ -138,35 +138,25 @@ bool lineSegmentsIntersect(const DLineSegment& l0, const DLineSegment& l1)
     return true;
 }
 
-// Standard Jordan Curve Theorem (aka ray casting, even-odd-rule, crossing number)
-// point-in-polygon test.
+// Original code from: 
+//     http://www.ecse.rpi.edu/Homepages/wrf/Research/Short_Notes/pnpoly.html.
 // Precomputing a bounding box for the polygon would speed this up a lot,
-// but we're not using the code in a speed-critical place so far.
+// but the function hasn't shown up on any profiles so far.
 bool pointInPolygon(const DPoint& pt, const vector<DPoint>& poly)
 {
     if (poly.size() < 3) {
         return false;
     }
-    DPoint pointOutside(0,0);
-    vector<DPoint>::const_iterator it;
-    for (it=poly.begin(); it != poly.end(); ++it) {
-        if (pointOutside.x > it->x) {
-            pointOutside = *it;
+    bool bPtInPoly = false;
+    for (unsigned i = 0, j = poly.size()-1; i < poly.size(); j = i++) {
+        if (((poly[i].y > pt.y) != (poly[j].y > pt.y)) &&
+                (pt.x < (poly[j].x-poly[i].x)*(pt.y-poly[i].y) / (poly[j].y-poly[i].y)
+                 +poly[i].x))
+        {
+            bPtInPoly = !bPtInPoly;
         }
     }
-    pointOutside.x -= 1;
-
-    DLineSegment line0(pointOutside, pt);
-    DPoint lastPt = *(--poly.end());
-    bool ptInPoly = false;
-    for (it=poly.begin(); it != poly.end(); ++it) {
-        DLineSegment line1(lastPt, *it);
-        if (lineSegmentsIntersect(line0, line1)) {
-            ptInPoly = !ptInPoly;
-        }
-        lastPt = *it;
-    }
-    return ptInPoly;
+    return bPtInPoly;
 }
  
 DPoint getLineLineIntersection(const DPoint& p1, const DPoint& v1, const DPoint& p2, 
