@@ -23,6 +23,7 @@
 #define _Logger_H_
 
 #include "../api.h"
+#include "UTF8String.h"
 
 #include <string>
 #include <vector>
@@ -42,7 +43,7 @@ public:
     void setCategories(int flags);
     void pushCategories();
     void popCategories();
-    void trace(int category, const std::string& msg);
+    void trace(int category, const UTF8String& sMsg);
     inline bool isFlagSet(int category) {
         return (category & m_Flags) != 0;
     }
@@ -51,6 +52,7 @@ public:
     static const long BLTS;
     static const long PROFILE;
     static const long PROFILE_LATEFRAMES;
+    static const long PROFILE_VIDEO;
     static const long EVENTS;
     static const long EVENTS2;
     static const long CONFIG;  
@@ -72,10 +74,10 @@ private:
     std::vector<int> m_FlagStack;
 };
 
-#define AVG_TRACE(category, msg) { \
+#define AVG_TRACE(category, sMsg) { \
     if (Logger::get()->isFlagSet(category)) { \
         std::stringstream tmp(std::stringstream::in | std::stringstream::out); \
-        tmp << msg; \
+        tmp << sMsg; \
         Logger::get()->trace(category, tmp.str()); \
     }\
 }
