@@ -28,13 +28,15 @@ using namespace std;
 
 namespace avg {
 
-bool ispow2(int n) {
+bool ispow2(int n)
+{
     return ((n & (n-1)) == 0);
 }
 
-int nextpow2(int n) {
+int nextpow2(int n)
+{
     int ret=1;
-    while (ret<n) {
+    while (ret < n) {
         ret *= 2;
     }
     return ret;
