@@ -40,7 +40,7 @@ unsigned getMemoryUsage();
 
 // Converts a utf-8-encoded filename to something windows can use.
 // Under other operating systems, returns the input string.
-std::string convertUTF8ToFilename(const std::string & sName);
+AVG_API std::string convertUTF8ToFilename(const std::string & sName);
 
 }
 
