@@ -22,13 +22,13 @@
 #include "Point.h"
 
 #include "MathHelper.h"
+#include "Exception.h"
 
 #if defined(__SSE__) || defined(_WIN32)
 #include <xmmintrin.h>
 #endif
 
 #include <math.h>
-#include <assert.h>
 #include <float.h>
 
 #include <string>
@@ -60,7 +60,7 @@ Point<NUM>::Point(const Point<NUM>& p)
 template<class NUM>
 Point<NUM>::Point(const std::vector<NUM>& v)
 {
-    assert(v.size() == 2);
+    AVG_ASSERT(v.size() == 2);
     x = v[0];
     y = v[1];
 }
@@ -72,7 +72,7 @@ Point<NUM>::~Point()
 }
     
 template<class NUM>
-double Point<NUM>::getNorm()
+double Point<NUM>::getNorm() const
 {
     return sqrt(double(x*x+y*y));
 }
@@ -199,7 +199,7 @@ Point<NUM> Point<NUM>::operator *(const Point<NUM>& pt) const
 template<>
 Point<int> Point<int>::fromPolar(double angle, double radius)
 {
-    assert(false);
+    AVG_ASSERT(false);
     return Point<int>(0,0);
 }
 
@@ -209,10 +209,16 @@ Point<double> Point<double>::fromPolar(double angle, double radius)
     return Point<double>(cos(angle)*radius, sin(angle)*radius);
 }
 
+template<class NUM>
+double Point<NUM>::getAngle() const
+{
+    return atan2(double(y), double(x));
+}
+
 template<>
 Point<int> Point<int>::getNormalized() const
 {
-    assert(false);
+    AVG_ASSERT(false);
     return Point<int>(0,0);
 }
 
@@ -240,6 +246,16 @@ Point<double> Point<double>::getNormalized() const
 #endif
 }
 
+template<class NUM>
+Point<NUM> Point<NUM>::safeGetNormalized() const
+{
+    if (x==0 && y==0) {
+        throw Exception(AVG_ERR_OUT_OF_RANGE, "Can't normalize (0,0).");
+    } else {
+        return getNormalized();
+    }
+}
+
 template<class NUM>
 std::ostream& operator<<( std::ostream& os, const Point<NUM> &p)
 {
