@@ -20,7 +20,6 @@
 //
 
 #include "ProfilingZone.h"
-#include "ThreadProfiler.h"
 #include "ObjectCounter.h"
 
 #include <iostream>
@@ -30,14 +29,13 @@ using namespace std;
 
 namespace avg {
 
-ProfilingZone::ProfilingZone(const string& sName, bool bIsStatic)
-    : m_sName(sName),
+ProfilingZone::ProfilingZone(const ProfilingZoneID& zoneID)
+    : m_ZoneID(zoneID),
       m_TimeSum(0),
       m_AvgTime(0),
       m_NumFrames(0),
       m_Indent(0),
-      m_bIsRegistered(false),
-      m_bIsStatic(bIsStatic)
+      m_bIsRegistered(false)
 {
     ObjectCounter::get()->incRef(&typeid(*this));
 }
@@ -47,37 +45,6 @@ ProfilingZone::~ProfilingZone()
     ObjectCounter::get()->decRef(&typeid(*this));
 }
 
-void ProfilingZone::clear()
-{
-    m_TimeSum = 0;
-    m_AvgTime = 0;
-    m_NumFrames = 0;
-    m_bIsRegistered = false;
-}
-
-bool ProfilingZone::isStatic()
-{
-    return m_bIsStatic;
-}
-
-void ProfilingZone::start()
-{
-    ThreadProfilerPtr pProfiler = ThreadProfiler::get();
-    if (!pProfiler) {
-        assert(false);
-    }
-    // Start gets called when the zone is first entered. 
-    if (!m_bIsRegistered && pProfiler->isRunning()) {
-        // This stuff makes sure that the zones are registered in the order 
-        // they are entered.
-        pProfiler->addZone(*this);
-        m_Indent = pProfiler->getIndent();
-        clear();
-        m_bIsRegistered = true;
-    }
-    pProfiler->pushActiveZone(this);
-}
-
 void ProfilingZone::reset()
 {
     m_NumFrames++;
@@ -95,6 +62,11 @@ long long ProfilingZone::getAvgUSecs() const
     return m_AvgTime;
 }
 
+void ProfilingZone::setIndentLevel(int indent)
+{
+    m_Indent = indent;
+}
+
 int ProfilingZone::getIndentLevel() const
 {
     return m_Indent;
@@ -107,13 +79,7 @@ string ProfilingZone::getIndentString() const
 
 const string& ProfilingZone::getName() const
 {
-    return m_sName;
+    return m_ZoneID.getName();
 }
     
-void ProfilingZone::add(long long usecs)
-{
-    ThreadProfiler::get()->popActiveZone(this);
-    m_TimeSum += usecs;
-}
-
 }
