@@ -23,19 +23,17 @@
 #define _ScopeTimer_H_
 
 #include "../api.h"
-#include "ProfilingZone.h"
-#include "TimeSource.h"
+#include "ProfilingZoneID.h"
 
 namespace avg {
     
 class AVG_API ScopeTimer {
 public:
-    ScopeTimer(ProfilingZone& Zone);
+    ScopeTimer(ProfilingZoneID& zoneID);
     virtual ~ScopeTimer();
    
 private:
-    ProfilingZone& m_Zone;
-    long long m_StartTime;
+    ProfilingZoneID& m_ZoneID;
 };
 
 }
