@@ -25,6 +25,7 @@
 #include <ctype.h>
 #include <algorithm>
 #include <cstdio>
+#include <iterator>
 
 using namespace std;
 
@@ -121,7 +122,7 @@ std::string removeStartEndSpaces(const string& s)
     return sResult;
 }
 
-string tolower(const string& s)
+string toLowerCase(const string& s)
 {
     string sResult;
     char lower[2];
