@@ -37,36 +37,38 @@ namespace avg {
 class ThreadProfiler;
 typedef boost::shared_ptr<ThreadProfiler> ThreadProfilerPtr;
 
-class AVG_API ThreadProfiler {
+class AVG_API ThreadProfiler
+{
 public:
     static ThreadProfilerPtr& get();
     static void kill();
     ThreadProfiler();
     virtual ~ThreadProfiler();
+    void setLogCategory(long category);
  
-    void addZone(ProfilingZone& Zone);
-    void clear();
     void start();
     bool isRunning();
-    void pushActiveZone(ProfilingZone * pZone);
-    void popActiveZone(ProfilingZone * pZone);
+    void startZone(const ProfilingZoneID& zoneID);
+    void stopZone(const ProfilingZoneID& zoneID);
     void dumpFrame();
     void dumpStatistics();
     void reset();
-    int getIndent();
     int getNumZones();
 
     const std::string& getName() const;
     void setName(const std::string& sName);
 
 private:
+    ProfilingZonePtr addZone(const ProfilingZoneID& zoneID);
     std::string m_sName;
 
-    typedef std::list<ProfilingZone*> ZoneList;
-    ZoneList m_Zones;
+    typedef std::map<const ProfilingZoneID*, ProfilingZonePtr> ZoneMap;
+    typedef std::list<ProfilingZonePtr> ZoneList;
+    ZoneMap m_ZoneMap;
     ZoneList m_ActiveZones;
+    ZoneList m_Zones;
     bool m_bRunning;
-    boost::thread m_Thread;
+    long m_LogCategory;
 
     static boost::thread_specific_ptr<ThreadProfilerPtr> s_pInstance;
 };
