@@ -24,10 +24,16 @@
 
 #include "../api.h"
 
+#ifdef __APPLE__ 
+#include <mach/mach_time.h>
+#endif
+
 namespace avg {
 
-typedef unsigned long long CycleCount;
 
+// This class is a monotonic time source with an undefined start time. Time is guarranteed
+// to increase monotonically. The time source has no jumps and does not go backwards,
+// even if system time is changed.
 class AVG_API TimeSource {
 public:
     static TimeSource* get();
@@ -36,10 +42,13 @@ public:
     long long getCurrentMillisecs();
     long long getCurrentMicrosecs();
     
-    void sleepUntil(long long ticks);
+    void sleepUntil(long long targetTime);
 
 private:    
     TimeSource();
+#ifdef __APPLE__
+    mach_timebase_info_data_t m_TimebaseInfo;
+#endif
     
     static TimeSource* m_pTimeSource;
 };
