@@ -24,6 +24,7 @@
 #include "WorkerThread.h"
 #include "ObjectCounter.h"
 #include "Point.h"
+#include "Matrix3x4.h"
 #include "Triangulate.h"
 #include "GeomHelper.h"
 #include "OSHelper.h"
@@ -34,22 +35,26 @@
 #include "BicubicSpline.h"
 #include "BezierCurve.h"
 #include "Signal.h"
+#include "Backtrace.h"
 
 #include "TestSuite.h"
 #include "TimeSource.h"
 
 #include <boost/thread/thread.hpp>
+
 #include <boost/bind.hpp>
 
 #include <iostream>
+#include <sstream>
 #include <stdio.h>
 #include <stdlib.h>
 
 using namespace avg;
-using namespace boost;
 using namespace std;
+using namespace boost;
 
-class QueueTest: public Test {
+class QueueTest: public Test
+{
 public:
     QueueTest()
         : Test("QueueTest", 2)
@@ -65,53 +70,63 @@ public:
 private:
     void runSingleThreadTests()
     {
-        Queue<int> q;
+        Queue<string> q;
+        typedef Queue<string>::QElementPtr ElemPtr;
         TEST(q.empty());
-        q.push(1);
+        q.push(ElemPtr(new string("1")));
         TEST(q.size() == 1);
         TEST(!q.empty());
-        q.push(2);
-        q.push(3);
+        q.push(ElemPtr(new string("2")));
+        q.push(ElemPtr(new string("3")));
         TEST(q.size() == 3);
-        TEST(q.pop() == 1);
-        TEST(q.pop() == 2);
-        q.push(4);
-        TEST(q.pop() == 3);
-        TEST(q.peek() == 4);
-        TEST(q.pop() == 4);
+        TEST(*q.pop() == "1");
+        TEST(*q.pop() == "2");
+        q.push(ElemPtr(new string("4")));
+        TEST(*q.pop() == "3");
+        TEST(*q.peek() == "4");
+        TEST(*q.pop() == "4");
         TEST(q.empty());
-        bool bExceptionThrown = false;
-        try {
-            q.pop(false);
-        } catch (Exception& ex) {
-            if (ex.GetCode() == AVG_ERR_QUEUE_EMPTY) {
-                bExceptionThrown = true;
-            }
-        }
-        TEST(bExceptionThrown);
+        ElemPtr pElem = q.pop(false);
+        TEST(!pElem);
     }
 
     void runMultiThreadTests()
     {
-        Queue<int> q(10);
-        thread pusher(bind(&pushThread, &q));
-        thread popper(bind(&popThread, &q));
-        pusher.join();
-        popper.join();
-        TEST(q.empty());
+        {
+            Queue<string> q(10);
+            thread pusher(boost::bind(&pushThread, &q, 100));
+            thread popper(boost::bind(&popThread, &q, 100));
+            pusher.join();
+            popper.join();
+            TEST(q.empty());
+        }
+        {
+            Queue<string> q(10);
+            thread pusher1(boost::bind(&pushThread, &q, 100));
+            thread pusher2(boost::bind(&pushThread, &q, 100));
+            thread popper(boost::bind(&popThread, &q, 200));
+            pusher1.join();
+            pusher2.join();
+            popper.join();
+            TEST(q.empty());
+        }
     }
 
-    static void pushThread(Queue<int>* pq)
+    static void pushThread(Queue<string>* pq, int numPushes)
     {
-        for (int i=0; i<100; ++i) {
-            pq->push(i);
+        typedef Queue<string>::QElementPtr ElemPtr;
+        for (int i=0; i<numPushes; ++i) {
+            stringstream ss;
+            ss << i;
+            string s = ss.str();
+            pq->push(ElemPtr(new string(s)));
             msleep(1);
         }
     }
 
-    static void popThread(Queue<int>* pq)
+    static void popThread(Queue<string>* pq, int numPops)
     {
-        for (int i=0; i<100; ++i) {
+        for (int i=0; i<numPops; ++i) {
             pq->peek();
             pq->pop();
             msleep(3);
@@ -119,11 +134,12 @@ private:
     }
 };
 
-class TestWorkerThread: public WorkerThread<TestWorkerThread> {
+class TestWorkerThread: public WorkerThread<TestWorkerThread>
+{
 public:
-    TestWorkerThread(CmdQueue& CmdQ, int* pNumFuncCalls, int* pIntParam, 
-            std::string* pStringParam)
-        : WorkerThread<TestWorkerThread>("Thread1", CmdQ),
+    TestWorkerThread(CQueue& cmdQ, int* pNumFuncCalls, int* pIntParam, 
+            string* pStringParam)
+        : WorkerThread<TestWorkerThread>("Thread1", cmdQ),
           m_pNumFuncCalls(pNumFuncCalls),
           m_pIntParam(pIntParam),
           m_pStringParam(pStringParam)
@@ -139,6 +155,7 @@ public:
     bool work()
     {
         (*m_pNumFuncCalls)++;
+        waitForCommand();
         return true;
     }
 
@@ -159,7 +176,9 @@ private:
     std::string * m_pStringParam;
 };
 
-class WorkerThreadTest: public Test {
+
+class WorkerThreadTest: public Test
+{
 public:
     WorkerThreadTest()
         : Test("WorkerThreadTest", 2)
@@ -168,25 +187,27 @@ public:
 
     void runTests() 
     {
-        TestWorkerThread::CmdQueue CmdQ;
+        typedef TestWorkerThread::CmdPtr CmdPtr;
+        TestWorkerThread::CQueue cmdQ;
         boost::thread* pTestThread;
-        int NumFuncCalls = 0;
-        int IntParam = 0;
-        std::string StringParam;
-        CmdQ.push(Command<TestWorkerThread>(boost::bind(&TestWorkerThread::doSomething,
-                _1, 23, "foo")));
-        CmdQ.push(Command<TestWorkerThread>(boost::bind(&TestWorkerThread::stop, _1)));
-        pTestThread = new boost::thread(TestWorkerThread(CmdQ, &NumFuncCalls,
-                &IntParam, &StringParam));
+        int numFuncCalls = 0;
+        int intParam = 0;
+        std::string stringParam;
+        cmdQ.pushCmd(boost::bind(&TestWorkerThread::doSomething, _1, 23, "foo"));
+        cmdQ.pushCmd(boost::bind(&TestWorkerThread::stop, _1));
+        pTestThread = new boost::thread(TestWorkerThread(cmdQ, &numFuncCalls,
+                &intParam, &stringParam));
         pTestThread->join();
         delete pTestThread;
-        TEST(NumFuncCalls == 3);
-        TEST(IntParam == 23);
-        TEST(StringParam == "foo");
+        TEST(numFuncCalls == 3);
+        TEST(intParam == 23);
+        TEST(stringParam == "foo");
     }
 };
 
-class DummyClass {
+
+class DummyClass
+{
 public:
     DummyClass()
     {
@@ -201,6 +222,7 @@ public:
     int i;
 };
 
+
 class ObjectCounterTest: public Test {
 public:
     ObjectCounterTest()
@@ -210,23 +232,25 @@ public:
 
     void runTests() 
     {
-        assert(ObjectCounter::get()->getCount(&typeid(DummyClass)) == 0);
+        TEST(ObjectCounter::get()->getCount(&typeid(DummyClass)) == 0);
         {
             DummyClass dummy1;
             DummyClass dummy2;
-            assert(ObjectCounter::get()->getCount(&typeid(dummy1)) == 2);
+            TEST(ObjectCounter::get()->getCount(&typeid(dummy1)) == 2);
         }
-        assert(ObjectCounter::get()->getCount(&typeid(DummyClass)) == 0);
+        TEST(ObjectCounter::get()->getCount(&typeid(DummyClass)) == 0);
     }
 };
 
+
 // The following pragmas avoid a compiler warning (potential division by 0)
 #ifdef _MSC_VER
 #pragma optimize("", off)
 #pragma warning(push)
 #pragma warning(disable:4723)
 #endif
-class PointTest: public Test {
+class PointTest: public Test
+{
 public:
     PointTest()
         : Test("PointTest", 2)
@@ -308,9 +332,12 @@ public:
             TEST(getLineLineIntersection(p1, v1, p2, v2) == DPoint(1,1));
         }
         TEST(almostEqual(DPoint(10,0).getRotatedPivot(PI, DPoint(15,5)), DPoint(20,10)));
-        TEST(almostEqual(DPoint(10,0).getRotatedPivot(PI*0.5, DPoint(15,5)), DPoint(20,0)));
-        TEST(almostEqual(DPoint(10,0).getRotatedPivot(PI*1.5, DPoint(15,5)), DPoint(10,10)));
-        TEST(almostEqual(DPoint(10,0).getRotatedPivot(PI*2, DPoint(15,5)), DPoint(10,0)));
+        TEST(almostEqual(DPoint(10,0).getRotatedPivot(PI*0.5, DPoint(15,5)),
+                DPoint(20,0)));
+        TEST(almostEqual(DPoint(10,0).getRotatedPivot(PI*1.5, DPoint(15,5)), 
+                DPoint(10,10)));
+        TEST(almostEqual(DPoint(10,0).getRotatedPivot(PI*2, DPoint(15,5)), 
+                DPoint(10,0)));
         TEST(almostEqual(DPoint(23,0).getRotatedPivot(PI*0.5), DPoint(0,23)));
 
         TEST(almostEqual(DPoint(10,0), DPoint::fromPolar(0, 10)));
@@ -323,7 +350,35 @@ public:
 #pragma optimize("", on)
 #endif
 
-class TriangleTest: public Test {
+
+class Matrix3x4Test: public Test
+{
+public:
+    Matrix3x4Test()
+        : Test("Matrix3x4Test", 2)
+    {
+    }
+
+    void runTests()
+    {
+        Matrix3x4 mat1;
+        Matrix3x4 mat2;
+        mat1 *= mat2;
+        TEST(almostEqual(mat1, Matrix3x4()));
+
+        mat2 = Matrix3x4::createTranslate(0,0,0);
+        mat1 *= mat2;
+        TEST(almostEqual(mat1, Matrix3x4()));
+
+        mat2 = Matrix3x4::createScale(1,1,1);
+        mat1 *= mat2;
+        TEST(almostEqual(mat1, Matrix3x4()));
+    }
+};
+
+
+class TriangleTest: public Test
+{
 public:
     TriangleTest()
         : Test("TriangleTest", 2)
@@ -359,7 +414,9 @@ public:
 
 };
 
-class FileTest: public Test {
+
+class FileTest: public Test
+{
 public:
     FileTest()
         : Test("FileTest", 2)
@@ -373,7 +430,9 @@ public:
     }
 };
 
-class OSTest: public Test {
+
+class OSTest: public Test
+{
 public:
     OSTest()
         : Test("OSTest", 2)
@@ -391,7 +450,9 @@ public:
     }
 };
 
-class StringTest: public Test {
+
+class StringTest: public Test
+{
 public:
     StringTest()
         : Test("StringTest", 2)
@@ -412,7 +473,7 @@ public:
             }
         }
         TEST(bExceptionThrown);
-        TEST(stringToDPoint(" ( 3.4 , 2.1 ) ")== DPoint(3.4, 2.1));
+        TEST(stringToDPoint(" ( 3.4 , 2.1 ) ") == DPoint(3.4, 2.1));
         vector<double> v;
         fromString("(1,2,3,4,5)", v);
         TEST(v.size() == 5 && v[0] == 1 && v[4] == 5);
@@ -422,7 +483,9 @@ public:
     }
 };
 
-class SplineTest: public Test {
+
+class SplineTest: public Test
+{
 public:
     SplineTest()
         : Test("SplineTest", 2)
@@ -513,7 +576,9 @@ public:
     }
 };
 
-class BezierCurveTest: public Test {
+
+class BezierCurveTest: public Test
+{
 public:
     BezierCurveTest()
         : Test("BezierCurveTest", 2)
@@ -531,7 +596,9 @@ public:
     }
 };
 
-class Listener {
+
+class Listener
+{
 public:
     Listener(Signal<Listener>& signal)
         : m_Signal(signal),
@@ -564,7 +631,9 @@ private:
     bool m_bFuncCalled;
 };
 
-class DisconnectingSelfListener: public Listener {
+
+class DisconnectingSelfListener: public Listener
+{
 public:
     DisconnectingSelfListener(Signal<Listener>& signal)
         : Listener(signal)
@@ -578,7 +647,9 @@ public:
     }
 };
 
-class DisconnectingOtherListener: public Listener {
+
+class DisconnectingOtherListener: public Listener
+{
 public:
     DisconnectingOtherListener(Signal<Listener>& signal, Listener* pOther)
         : Listener(signal),
@@ -599,7 +670,9 @@ private:
     Listener* m_pOther;
 };
 
-class ConnectingOtherListener: public Listener {
+
+class ConnectingOtherListener: public Listener
+{
 public:
     ConnectingOtherListener(Signal<Listener>& signal, Listener* pOther)
         : Listener(signal),
@@ -621,8 +694,8 @@ private:
 };
 
 
-
-class SignalTest: public Test {
+class SignalTest: public Test
+{
 public:
     SignalTest()
         : Test("SignalTest", 2)
@@ -687,7 +760,28 @@ public:
     }
 };
 
-class BaseTestSuite: public TestSuite {
+
+class BacktraceTest: public Test
+{
+public:
+    BacktraceTest()
+        : Test("BacktraceTest", 2)
+    {
+    }
+
+    void runTests()
+    {
+        vector<string> sFuncs;
+        getBacktrace(sFuncs);
+#ifndef _WIN32
+        TEST(sFuncs[0].find("runTests") != string::npos);
+#endif
+    }
+};
+
+
+class BaseTestSuite: public TestSuite
+{
 public:
     BaseTestSuite() 
         : TestSuite("BaseTestSuite")
@@ -696,6 +790,7 @@ public:
         addTest(TestPtr(new WorkerThreadTest));
         addTest(TestPtr(new ObjectCounterTest));
         addTest(TestPtr(new PointTest));
+        addTest(TestPtr(new Matrix3x4Test));
         addTest(TestPtr(new TriangleTest));
         addTest(TestPtr(new FileTest));
         addTest(TestPtr(new OSTest));
@@ -703,14 +798,16 @@ public:
         addTest(TestPtr(new SplineTest));
         addTest(TestPtr(new BezierCurveTest));
         addTest(TestPtr(new SignalTest));
+        addTest(TestPtr(new BacktraceTest));
     }
 };
 
+
 int main(int nargs, char** args)
 {
-    BaseTestSuite Suite;
-    Suite.runTests();
-    bool bOK = Suite.isOk();
+    BaseTestSuite suite;
+    suite.runTests();
+    bool bOK = suite.isOk();
 
     if (bOK) {
         return 0;
