@@ -54,7 +54,7 @@ ConradRelais::ConradRelais(Player * pPlayer, int port)
     } else {
         initBoard();
         if (m_File != -1) {
-            pPlayer->registerFrameListener(this);
+            pPlayer->registerFrameEndListener(this);
         }
     }
 }
@@ -63,7 +63,7 @@ ConradRelais::~ConradRelais()
 {
     if (m_File != -1) {
         send();
-        m_pPlayer->unregisterFrameListener(this);
+        m_pPlayer->unregisterFrameEndListener(this);
         close(m_File);
         m_File = -1;
     }
@@ -141,7 +141,7 @@ void ConradRelais::initBoard()
     while (bOk) {
         ssize_t rc = read(m_File, rbuf, 4);
         if (rc != 4  || rbuf[0] != 254 || rbuf[1] != m_NumCards+1) {
-    	    bOk = false;
+            bOk = false;
         } else {
             m_NumCards++;
         }
