@@ -25,15 +25,17 @@
 #include "Bitmap.h"
 
 #include "../base/MathHelper.h"
+#include "../base/Exception.h"
 
 #include <iostream>
 #include <math.h>
+
 using namespace std;
 
 namespace avg {
     
-FilterGauss::FilterGauss(double Radius)
-    : m_Radius(Radius)
+FilterGauss::FilterGauss(double radius)
+    : m_Radius(radius)
 {
     calcKernel();
 }
@@ -44,22 +46,22 @@ FilterGauss::~FilterGauss()
 
 BitmapPtr FilterGauss::apply(BitmapPtr pBmpSrc)
 {
-    assert(pBmpSrc->getPixelFormat() == I8);
-    int IntRadius = int(ceil(m_Radius));
+    AVG_ASSERT(pBmpSrc->getPixelFormat() == I8);
+    int intRadius = int(ceil(m_Radius));
     
     // Convolve in x-direction
-    IntPoint TempSize(pBmpSrc->getSize().x-2*IntRadius, pBmpSrc->getSize().y);
-    BitmapPtr pTempBmp = BitmapPtr(new Bitmap(TempSize, I8, pBmpSrc->getName()));
-    int SrcStride = pBmpSrc->getStride();
-    int TempStride = pTempBmp->getStride();
+    IntPoint tempSize(pBmpSrc->getSize().x-2*intRadius, pBmpSrc->getSize().y);
+    BitmapPtr pTempBmp = BitmapPtr(new Bitmap(tempSize, I8, pBmpSrc->getName()));
+    int srcStride = pBmpSrc->getStride();
+    int tempStride = pTempBmp->getStride();
     unsigned char * pSrcLine = pBmpSrc->getPixels();
     unsigned char * pTempLine = pTempBmp->getPixels();
-    for (int y = 0; y<TempSize.y; ++y) {
-        unsigned char * pSrcPixel = pSrcLine+IntRadius;
+    for (int y = 0; y < tempSize.y; ++y) {
+        unsigned char * pSrcPixel = pSrcLine+intRadius;
         unsigned char * pTempPixel = pTempLine;
-        switch (IntRadius) {
+        switch (intRadius) {
             case 3:
-                for (int x = 0; x < TempSize.x; ++x) {
+                for (int x = 0; x < tempSize.x; ++x) {
                     *pTempPixel = (*(pSrcPixel-3)*m_Kernel[0] + 
                             *(pSrcPixel-2)*m_Kernel[1] +
                             *(pSrcPixel-1)*m_Kernel[2] + 
@@ -72,7 +74,7 @@ BitmapPtr FilterGauss::apply(BitmapPtr pBmpSrc)
                 }
                 break;
             case 2:
-                for (int x = 0; x < TempSize.x; ++x) {
+                for (int x = 0; x < tempSize.x; ++x) {
                     *pTempPixel = (*(pSrcPixel-2)*m_Kernel[0] +
                             *(pSrcPixel-1)*m_Kernel[1] + 
                             *(pSrcPixel)*m_Kernel[2] +
@@ -83,7 +85,7 @@ BitmapPtr FilterGauss::apply(BitmapPtr pBmpSrc)
                 }
                 break;
             case 1:
-                for (int x = 0; x < TempSize.x; ++x) {
+                for (int x = 0; x < tempSize.x; ++x) {
                     *pTempPixel = (*(pSrcPixel-1)*m_Kernel[0] + 
                             *(pSrcPixel)*m_Kernel[1] +
                             *(pSrcPixel+1)*m_Kernel[2])/256;
@@ -93,10 +95,10 @@ BitmapPtr FilterGauss::apply(BitmapPtr pBmpSrc)
                 break;
             default:
                 // This is _really_ slow!
-                for (int x = 0; x < TempSize.x; ++x) {
+                for (int x = 0; x < tempSize.x; ++x) {
                     *pTempPixel = 0;
-                    unsigned char * pKernelPixel = pSrcPixel-IntRadius;
-                    for (int w=0; w <= IntRadius*2; ++w) {
+                    unsigned char * pKernelPixel = pSrcPixel-intRadius;
+                    for (int w=0; w <= intRadius*2; ++w) {
                         *pTempPixel += ((*pKernelPixel)*m_Kernel[w])/256;
                         pKernelPixel++;
                     }
@@ -104,68 +106,68 @@ BitmapPtr FilterGauss::apply(BitmapPtr pBmpSrc)
                     ++pTempPixel;
                 }
         }
-        pSrcLine += SrcStride;
-        pTempLine += TempStride;
+        pSrcLine += srcStride;
+        pTempLine += tempStride;
     }
 
     // Convolve in y-direction
-    IntPoint DestSize(TempSize.x, TempSize.y-2*IntRadius);
-    BitmapPtr pDestBmp = BitmapPtr(new Bitmap(DestSize, I8, pBmpSrc->getName()));
-    int DestStride = pDestBmp->getStride();
-    pTempLine = pTempBmp->getPixels()+IntRadius*TempStride;
+    IntPoint destSize(tempSize.x, tempSize.y-2*intRadius);
+    BitmapPtr pDestBmp = BitmapPtr(new Bitmap(destSize, I8, pBmpSrc->getName()));
+    int destStride = pDestBmp->getStride();
+    pTempLine = pTempBmp->getPixels()+intRadius*tempStride;
     unsigned char * pDestLine = pDestBmp->getPixels();
-    for (int y = 0; y<DestSize.y; ++y) {
+    for (int y = 0; y < destSize.y; ++y) {
         unsigned char * pTempPixel = pTempLine;
         unsigned char * pDestPixel = pDestLine;
-        switch (IntRadius) {
+        switch (intRadius) {
             case 3:
-                for (int x = 0; x < DestSize.x; ++x) {
-                    *pDestPixel = (*(pTempPixel-3*TempStride)*m_Kernel[0] +
-                            *(pTempPixel-2*TempStride)*m_Kernel[1] +
-                            *(pTempPixel-1*TempStride)*m_Kernel[2] + 
+                for (int x = 0; x < destSize.x; ++x) {
+                    *pDestPixel = (*(pTempPixel-3*tempStride)*m_Kernel[0] +
+                            *(pTempPixel-2*tempStride)*m_Kernel[1] +
+                            *(pTempPixel-1*tempStride)*m_Kernel[2] + 
                             *(pTempPixel)*m_Kernel[3] +
-                            *(pTempPixel+1*TempStride)*m_Kernel[4] + 
-                            *(pTempPixel+2*TempStride)*m_Kernel[5] +
-                            *(pTempPixel+3*TempStride)*m_Kernel[6])/256;
+                            *(pTempPixel+1*tempStride)*m_Kernel[4] + 
+                            *(pTempPixel+2*tempStride)*m_Kernel[5] +
+                            *(pTempPixel+3*tempStride)*m_Kernel[6])/256;
                     ++pTempPixel;
                     ++pDestPixel;
                 }
                 break;
             case 2:
-                for (int x = 0; x < DestSize.x; ++x) {
-                    *pDestPixel = (*(pTempPixel-2*TempStride)*m_Kernel[0] +
-                            *(pTempPixel-1*TempStride)*m_Kernel[1] + 
+                for (int x = 0; x < destSize.x; ++x) {
+                    *pDestPixel = (*(pTempPixel-2*tempStride)*m_Kernel[0] +
+                            *(pTempPixel-1*tempStride)*m_Kernel[1] + 
                             *(pTempPixel)*m_Kernel[2] +
-                            *(pTempPixel+1*TempStride)*m_Kernel[3] + 
-                            *(pTempPixel+2*TempStride)*m_Kernel[4])/256;
+                            *(pTempPixel+1*tempStride)*m_Kernel[3] + 
+                            *(pTempPixel+2*tempStride)*m_Kernel[4])/256;
                     ++pTempPixel;
                     ++pDestPixel;
                 }
                 break;
             case 1:
-                for (int x = 0; x < DestSize.x; ++x) {
-                    *pDestPixel = (*(pTempPixel-1*TempStride)*m_Kernel[0] + 
+                for (int x = 0; x < destSize.x; ++x) {
+                    *pDestPixel = (*(pTempPixel-1*tempStride)*m_Kernel[0] + 
                             *(pTempPixel)*m_Kernel[1] +
-                            *(pTempPixel+1*TempStride)*m_Kernel[2])/256;
+                            *(pTempPixel+1*tempStride)*m_Kernel[2])/256;
                     ++pTempPixel;
                     ++pDestPixel;
                 }
                 break;
             default:
                 // This is _really_ slow!
-                for (int x = 0; x < TempSize.x; ++x) {
+                for (int x = 0; x < tempSize.x; ++x) {
                     *pDestPixel = 0;
-                    unsigned char * pKernelPixel = pTempPixel-IntRadius*TempStride;
-                    for (int w=0; w <= IntRadius*2; ++w) {
+                    unsigned char * pKernelPixel = pTempPixel-intRadius*tempStride;
+                    for (int w = 0; w <= intRadius*2; ++w) {
                         *pDestPixel += (*pKernelPixel*m_Kernel[w])/256;
-                        pKernelPixel+=TempStride;
+                        pKernelPixel += tempStride;
                     }
                     ++pTempPixel;
                     ++pDestPixel;
                 }
         }
-        pTempLine += TempStride;
-        pDestLine += DestStride;
+        pTempLine += tempStride;
+        pDestLine += destStride;
     }
     return pDestBmp;
 }
@@ -174,7 +176,7 @@ void FilterGauss::dumpKernel()
 {
     cerr << "Gauss, radius " << m_Radius << endl;
     cerr << "  Kernel width: " << m_KernelWidth << endl;
-    for (int i=0; i<m_KernelWidth; ++i) {
+    for (int i = 0; i < m_KernelWidth; ++i) {
         cerr << "  " << m_Kernel[i] << endl;
     }
 }
@@ -183,17 +185,17 @@ void FilterGauss::calcKernel()
 {
     double FloatKernel[15];
     double Sum = 0;
-    int IntRadius = int(ceil(m_Radius));
-    m_KernelWidth = IntRadius*2+1;
-    for (int i=0; i<= IntRadius; ++i) {
-        FloatKernel[IntRadius+i] = exp(-i*i/m_Radius-1)/sqrt(2*PI);
-        FloatKernel[IntRadius-i] = FloatKernel[IntRadius+i];
-        Sum += FloatKernel[IntRadius+i];
+    int intRadius = int(ceil(m_Radius));
+    m_KernelWidth = intRadius*2+1;
+    for (int i = 0; i <= intRadius; ++i) {
+        FloatKernel[intRadius+i] = exp(-i*i/m_Radius-1)/sqrt(2*PI);
+        FloatKernel[intRadius-i] = FloatKernel[intRadius+i];
+        Sum += FloatKernel[intRadius+i];
         if (i != 0) {
-            Sum += FloatKernel[IntRadius-i];
+            Sum += FloatKernel[intRadius-i];
         }
     }
-    for (int i=0; i<m_KernelWidth; ++i) {
+    for (int i = 0; i < m_KernelWidth; ++i) {
         m_Kernel[i] = int(FloatKernel[i]*256/Sum+0.5);
     }
 }
