@@ -39,7 +39,7 @@ public:
 private:
 };
 
-} // namespace
+}
 
 #endif
 
