@@ -35,16 +35,16 @@ FilterFlip::~FilterFlip()
 
 BitmapPtr FilterFlip::apply(BitmapPtr pBmpSource) 
 {
-    IntPoint Size = pBmpSource->getSize();
-    BitmapPtr pBmpDest(new Bitmap (Size, 
-                pBmpSource->getPixelFormat(), pBmpSource->getName()));
+    IntPoint size = pBmpSource->getSize();
+    BitmapPtr pBmpDest(new Bitmap(size, pBmpSource->getPixelFormat(), 
+            pBmpSource->getName()));
 
     unsigned char* pSrcLine = pBmpSource->getPixels();
-    unsigned char* pDestLine = pBmpDest->getPixels()+(Size.y-1)*pBmpDest->getStride();
-    int LineLen = pBmpSource->getBytesPerPixel()*Size.x;
+    unsigned char* pDestLine = pBmpDest->getPixels()+(size.y-1)*pBmpDest->getStride();
+    int lineLen = pBmpSource->getBytesPerPixel()*size.x;
 
-    for (int y = 0; y<Size.y; y++) {
-        memcpy(pDestLine, pSrcLine, LineLen);
+    for (int y = 0; y < size.y; y++) {
+        memcpy(pDestLine, pSrcLine, lineLen);
         pSrcLine += pBmpSource->getStride();
         pDestLine -= pBmpDest->getStride();
     }
