@@ -22,12 +22,13 @@
 #ifndef _Filterfliprgb_H
 #define _Filterfliprgb_H
 
+#include "../api.h"
 #include "Filter.h"
 
 namespace avg {
 
 // Filter that flips the R and B components of a bitmap.
-class FilterFlipRGB : public Filter
+class AVG_API FilterFlipRGB : public Filter
 {
 public:
   FilterFlipRGB();
