@@ -21,33 +21,30 @@
 
 #include "GPUBandpassFilter.h"
 #include "Bitmap.h"
+#include "ShaderRegistry.h"
 
 #include "../base/ObjectCounter.h"
 #include "../base/Exception.h"
 
 #include <iostream>
 
+#define SHADERID "BANDPASS"
+
 using namespace std;
 
 namespace avg {
 
-OGLShaderPtr GPUBandpassFilter::s_pShader;
-
 GPUBandpassFilter::GPUBandpassFilter(const IntPoint& size, PixelFormat pfSrc, 
-        double min, double max, double postScale, bool bInvert)
-    : GPUFilter(size, pfSrc, B8G8R8A8, true),
+        double min, double max, double postScale, bool bInvert, bool bStandalone)
+    : GPUFilter(size, pfSrc, B8G8R8A8, bStandalone),
       m_PostScale(postScale),
       m_bInvert(bInvert),
-      m_pMinPBO(new PBOImage(size, R32G32B32A32F, R32G32B32A32F, false, false)),
-      m_pMaxPBO(new PBOImage(size, R32G32B32A32F, R32G32B32A32F, false, false)),
-      m_MinFilter(getSrcPBO(), m_pMinPBO, min),
-      m_MaxFilter(getSrcPBO(), m_pMaxPBO, max)
+      m_MinFilter(size, pfSrc, R32G32B32A32F, min, false),
+      m_MaxFilter(size, pfSrc, R32G32B32A32F, max, false)
 {
     ObjectCounter::get()->incRef(&typeid(*this));
 
-    if (!s_pShader) {
-        initShader();
-    }
+    initShader();
 }
 
 GPUBandpassFilter::~GPUBandpassFilter()
@@ -55,22 +52,20 @@ GPUBandpassFilter::~GPUBandpassFilter()
     ObjectCounter::get()->decRef(&typeid(*this));
 }
 
-void GPUBandpassFilter::applyOnGPU()
+void GPUBandpassFilter::applyOnGPU(GLTexturePtr pSrcTex)
 {
-    m_MinFilter.apply();
-    m_MaxFilter.apply();
+    m_MinFilter.apply(pSrcTex);
+    m_MaxFilter.apply(pSrcTex);
 
     getFBO()->activate();
-    GLhandleARB hProgram = s_pShader->getProgram();
-    glproc::UseProgramObject(hProgram);
-    OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, 
-            "GPUBandpassFilter::apply: glUseProgramObject()");
-    glproc::Uniform1i(glproc::GetUniformLocation(hProgram, "minTex"), 0);
-    glproc::Uniform1i(glproc::GetUniformLocation(hProgram, "maxTex"), 1);
-    glproc::Uniform1f(glproc::GetUniformLocation(hProgram, "postScale"), float(m_PostScale));
-    glproc::Uniform1i(glproc::GetUniformLocation(hProgram, "bInvert"), m_bInvert);
-    m_pMaxPBO->activateTex(GL_TEXTURE1);
-    m_pMinPBO->draw();
+    OGLShaderPtr pShader = getShader(SHADERID);
+    pShader->activate();
+    pShader->setUniformIntParam("minTex", 0);
+    pShader->setUniformIntParam("maxTex", 1);
+    pShader->setUniformFloatParam("postScale", float(m_PostScale));
+    pShader->setUniformIntParam("bInvert", m_bInvert);
+    m_MaxFilter.getDestTex()->activate(GL_TEXTURE1);
+    draw(m_MinFilter.getDestTex());
 
     glproc::UseProgramObject(0);
 }
@@ -78,17 +73,15 @@ void GPUBandpassFilter::applyOnGPU()
 void GPUBandpassFilter::initShader()
 {
     string sProgram =
-        "#extension GL_ARB_texture_rectangle : enable\n" 
-       
-        "uniform sampler2DRect minTex;\n"
-        "uniform sampler2DRect maxTex;\n"
+        "uniform sampler2D minTex;\n"
+        "uniform sampler2D maxTex;\n"
         "uniform float postScale;\n"
         "uniform bool bInvert;\n"
 
         "void main(void)\n"
         "{\n"
-        "  vec4 min =texture2DRect(minTex, gl_TexCoord[0].st);\n" 
-        "  vec4 max =texture2DRect(maxTex, gl_TexCoord[0].st);\n"
+        "  vec4 min = texture2D(minTex, gl_TexCoord[0].st);\n" 
+        "  vec4 max = texture2D(maxTex, gl_TexCoord[0].st);\n"
         "  gl_FragColor = vec4(0.502, 0.502, 0.502, 0)+(max-min)*postScale;\n"
         "  if (bInvert) {\n"
         "    gl_FragColor = vec4(1.004,1.004,1.004,1)-gl_FragColor;\n"
@@ -97,7 +90,7 @@ void GPUBandpassFilter::initShader()
         "}\n"
         ;
 
-    s_pShader = OGLShaderPtr(new OGLShader(sProgram));
+    getOrCreateShader(SHADERID, sProgram);
 }
 
 } // namespace
