@@ -26,8 +26,6 @@
 #include "GPUFilter.h"
 #include "GPUBlurFilter.h"
 #include "Bitmap.h"
-#include "PBOImage.h"
-#include "OGLShader.h"
 
 namespace avg {
 
@@ -35,23 +33,19 @@ class AVG_API GPUBandpassFilter: public GPUFilter
 {
 public:
     GPUBandpassFilter(const IntPoint& size, PixelFormat pfSrc, double min, double max, 
-            double postScale, bool bInvert);
+            double postScale, bool bInvert, bool bStandalone=true);
     virtual ~GPUBandpassFilter();
 
-    virtual void applyOnGPU();
+    virtual void applyOnGPU(GLTexturePtr pSrcTex);
 
 private:
     static void initShader();
 
     double m_PostScale;
     bool m_bInvert;
-    PBOImagePtr m_pMinPBO;
-    PBOImagePtr m_pMaxPBO;
 
     GPUBlurFilter m_MinFilter;
     GPUBlurFilter m_MaxFilter;
-
-    static OGLShaderPtr s_pShader;
 };
 
 } // namespace
