@@ -24,38 +24,32 @@
 
 #include "../api.h"
 #include "GPUFilter.h"
-#include "PBOImage.h"
-#include "OGLShader.h"
+#include "GLTexture.h"
 
 namespace avg {
 
 class AVG_API GPUBlurFilter: public GPUFilter
 {
 public:
-    GPUBlurFilter(const IntPoint& size, PixelFormat pfSrc, double stdDev);
-    GPUBlurFilter(PBOImagePtr pSrcPBO, PBOImagePtr pDestPBO, double stdDev);
-    void init();
+    GPUBlurFilter(const IntPoint& size, PixelFormat pfSrc, PixelFormat pfDest, 
+            double stdDev, bool bStandalone=true);
     virtual ~GPUBlurFilter();
-
-    virtual void applyOnGPU();
+    
+    void setParam(double stdDev);
+    virtual void applyOnGPU(GLTexturePtr pSrcTex);
 
 private:
-    static void initShaders();
+    void initShaders();
     void dumpKernel();
     void calcKernel();
 
     double m_StdDev;
-    int m_KernelWidth;
-    float m_Kernel[255];
 
-    PBOImagePtr m_pGaussCurvePBO;
-    PBOImagePtr m_pInterPBO;
-    FBOPtr m_pInterFBO;
-
-    static OGLShaderPtr s_pHorizShader;
-    static OGLShaderPtr s_pVertShader;
+    GLTexturePtr m_pGaussCurveTex;
 };
 
+typedef boost::shared_ptr<GPUBlurFilter> GPUBlurFilterPtr;
+
 } // namespace
 #endif
 
