@@ -21,28 +21,27 @@
 
 #include "GPUBrightnessFilter.h"
 #include "Bitmap.h"
+#include "ShaderRegistry.h"
 
 #include "../base/ObjectCounter.h"
 #include "../base/Exception.h"
 
 #include <iostream>
 
+#define SHADERID "BRIGHTNESS"
+
 using namespace std;
 
 namespace avg {
 
-OGLShaderPtr GPUBrightnessFilter::s_pShader;
-
 GPUBrightnessFilter::GPUBrightnessFilter(const IntPoint& size, PixelFormat pf, 
-        double alpha)
-    : GPUFilter(size, pf, B8G8R8A8, true),
+        double alpha, bool bStandalone)
+    : GPUFilter(size, pf, B8G8R8A8, bStandalone),
       m_Alpha(alpha)
 {
     ObjectCounter::get()->incRef(&typeid(*this));
 
-    if (!s_pShader) {
-        initShader();
-    }
+    initShader();
 }
 
 GPUBrightnessFilter::~GPUBrightnessFilter()
@@ -50,16 +49,13 @@ GPUBrightnessFilter::~GPUBrightnessFilter()
     ObjectCounter::get()->decRef(&typeid(*this));
 }
 
-void GPUBrightnessFilter::applyOnGPU()
+void GPUBrightnessFilter::applyOnGPU(GLTexturePtr pSrcTex)
 {
-    GLhandleARB hProgram = s_pShader->getProgram();
-    glproc::UseProgramObject(hProgram);
-    OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, 
-            "GPUBrightnessFilter::apply: glUseProgramObject()");
-    glproc::Uniform1f(glproc::GetUniformLocation(hProgram, "alpha"),
-            GLfloat(m_Alpha));
-    glproc::Uniform1i(glproc::GetUniformLocation(hProgram, "Texture"), 0);
-    getSrcPBO()->draw();
+    OGLShaderPtr pShader = getShader(SHADERID);
+    pShader->activate();
+    pShader->setUniformIntParam("Texture", 0);
+    pShader->setUniformFloatParam("alpha", GLfloat(m_Alpha));
+    draw(pSrcTex);
 
     glproc::UseProgramObject(0);
 }
@@ -67,20 +63,18 @@ void GPUBrightnessFilter::applyOnGPU()
 void GPUBrightnessFilter::initShader()
 {
     string sProgram =
-        "#extension GL_ARB_texture_rectangle : enable\n" 
-        
         "uniform float alpha;\n"
-        "uniform sampler2DRect Texture;\n"
+        "uniform sampler2D Texture;\n"
 
         "void main(void)\n"
         "{\n"
-        "  vec4 tex =texture2DRect(Texture, gl_TexCoord[0].st);\n" 
-        "  gl_FragColor.rgb = tex.rgb*alpha;\n"
-        "  gl_FragColor.a = tex.a;\n"
+        "    vec4 tex =texture2D(Texture, gl_TexCoord[0].st);\n" 
+        "    gl_FragColor.rgb = tex.rgb*alpha;\n"
+        "    gl_FragColor.a = tex.a;\n"
         "}\n"
         ;
 
-    s_pShader = OGLShaderPtr(new OGLShader(sProgram));
+    getOrCreateShader(SHADERID, sProgram);
 }
 
 } // namespace
