@@ -25,25 +25,22 @@
 #include "../api.h"
 #include "GPUFilter.h"
 #include "Bitmap.h"
-#include "PBOImage.h"
-#include "OGLShader.h"
 
 namespace avg {
 
 class AVG_API GPUBrightnessFilter: public GPUFilter
 {
 public:
-    GPUBrightnessFilter(const IntPoint& size, PixelFormat pf, double alpha);
+    GPUBrightnessFilter(const IntPoint& size, PixelFormat pf, double alpha, 
+            bool bStandalone=true);
     virtual ~GPUBrightnessFilter();
 
-    virtual void applyOnGPU();
+    virtual void applyOnGPU(GLTexturePtr pSrcTex);
 
 private:
     static void initShader();
 
     double m_Alpha;
-
-    static OGLShaderPtr s_pShader;
 };
 
 } // namespace
