@@ -24,39 +24,48 @@
 
 #include "../api.h"
 #include "Filter.h"
+#include "VertexArray.h"
 #include "Bitmap.h"
-#include "PBOImage.h"
+#include "PBO.h"
 #include "FBO.h"
 
+#include <boost/thread/tss.hpp>
+
 namespace avg {
 
 class AVG_API GPUFilter: public Filter
 {
 public:
-    GPUFilter(const IntPoint& size, PixelFormat pfSrc, PixelFormat pfDest, bool bOwnFBO);
-    GPUFilter(PBOImagePtr pSrcPBO, PBOImagePtr pDestPBO, bool bOwnFBO);
+    GPUFilter(const IntPoint& size, PixelFormat pfSrc, PixelFormat pfDest, 
+            bool bStandalone, unsigned numTextures=1);
     virtual ~GPUFilter();
 
     virtual BitmapPtr apply(BitmapPtr pBmpSource);
-    virtual void apply(FBOPtr pFBO = FBOPtr());
-    virtual void applyOnGPU() = 0;
+    virtual void apply(GLTexturePtr pSrcTex);
+    virtual void applyOnGPU(GLTexturePtr pSrcTex) = 0;
+    GLTexturePtr getDestTex(int i=0) const;
+    BitmapPtr getImage() const;
+
     FBOPtr getFBO();
 
-    static bool isSupported();
+    static void glContextGone();
 
 protected:
-    void setFBO(FBOPtr pFBO);
+    void draw(GLTexturePtr pTex);
     const IntPoint& getSize() const;
-
-    PBOImagePtr getSrcPBO();
-    PBOImagePtr getDestPBO();
+    const std::string& getStdShaderCode() const;
+    GLTexturePtr calcBlurKernelTex(double stdDev, double opacity=-1) const;
 
 private:
-    PBOImagePtr m_pSrcPBO;
-    PBOImagePtr m_pDestPBO;
+    GLTexturePtr m_pSrcTex;
+    PBOPtr m_pSrcPBO;
     FBOPtr m_pFBO;
+
+    static boost::thread_specific_ptr<PBOPtr> s_pFilterKernelPBO;
 };
 
+typedef boost::shared_ptr<GPUFilter> GPUFilterPtr;
+
 } // namespace
 #endif
 
