@@ -28,12 +28,16 @@
 #include <dlfcn.h>
 #endif
 
-#include <assert.h>
 #include <cstdio>
 #include <iostream>
 #include <sstream>
 #include <cstring>
 #include <cstdlib>
+#include <assert.h>
+
+#if defined(__APPLE__)
+#include <OpenGL/OpenGL.h>
+#endif
 
 using namespace std;
 
@@ -62,15 +66,29 @@ namespace glproc {
     PFNGLUNIFORM1IARBPROC Uniform1i;
     PFNGLUNIFORM1FARBPROC Uniform1f;
     PFNGLUNIFORM2FARBPROC Uniform2f;
+    PFNGLUNIFORM3FARBPROC Uniform3f;
+    PFNGLUNIFORM4FARBPROC Uniform4f;
     PFNGLUNIFORM1FVARBPROC Uniform1fv;
+    PFNGLUNIFORMMATRIX4FVARBPROC UniformMatrix4fv;
+
+    PFNGLBLENDFUNCSEPARATEPROC BlendFuncSeparate;
     PFNGLBLENDEQUATIONPROC BlendEquation;
+    PFNGLBLENDCOLORPROC BlendColor;
     PFNGLACTIVETEXTUREPROC ActiveTexture;
     PFNGLGENERATEMIPMAPEXTPROC GenerateMipmap;
+
     PFNGLCHECKFRAMEBUFFERSTATUSEXTPROC CheckFramebufferStatus;
     PFNGLGENFRAMEBUFFERSEXTPROC GenFramebuffers;
     PFNGLBINDFRAMEBUFFEREXTPROC BindFramebuffer;
     PFNGLFRAMEBUFFERTEXTURE2DEXTPROC FramebufferTexture2D;
     PFNGLDELETEFRAMEBUFFERSEXTPROC DeleteFramebuffers;
+    PFNGLGENRENDERBUFFERSEXTPROC GenRenderbuffers;
+    PFNGLBINDRENDERBUFFEREXTPROC BindRenderbuffer;
+    PFNGLRENDERBUFFERSTORAGEEXTPROC RenderbufferStorage;
+    PFNGLRENDERBUFFERSTORAGEMULTISAMPLEEXTPROC RenderbufferStorageMultisample;
+    PFNGLFRAMEBUFFERRENDERBUFFEREXTPROC FramebufferRenderbuffer;
+    PFNGLBLITFRAMEBUFFEREXTPROC BlitFramebuffer;
+    PFNGLDELETERENDERBUFFERSEXTPROC DeleteRenderbuffers;
 #ifdef linux
     PFNGLXSWAPINTERVALSGIPROC SwapIntervalSGI;
     PFNGLXWAITVIDEOSYNCSGIPROC WaitVideoSyncSGI;
@@ -82,31 +100,31 @@ namespace glproc {
     void * s_hGLLib = 0;
 }
 
-void OGLErrorCheck(int avgcode, const char * where) 
+void OGLErrorCheck(int avgcode, const string& sWhere) 
 {
     GLenum err = glGetError();
     if (err != GL_NO_ERROR) {
         stringstream s;
-        s << "OpenGL error in " << where <<": " << gluErrorString(err) 
+        s << "OpenGL error in " << sWhere <<": " << gluErrorString(err) 
             << " (#" << err << ") ";
         AVG_TRACE(Logger::ERROR, s.str());
         if (err != GL_INVALID_OPERATION) {
             OGLErrorCheck(avgcode, "  --");
         }
-        assert(false);
+        AVG_ASSERT(false);
     }
 }
 
 #ifdef _WIN32
-void winOGLErrorCheck(BOOL bOK, const string & where) 
+void winOGLErrorCheck(BOOL bOK, const string& sWhere) 
 {
     if (!bOK) {
         char szErr[512];
         FormatMessage((FORMAT_MESSAGE_IGNORE_INSERTS | FORMAT_MESSAGE_FROM_SYSTEM),
                 0, GetLastError(), MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
                 szErr, 512, 0);
-        AVG_TRACE(Logger::ERROR, where+":"+szErr);
-        assert(false);
+        AVG_TRACE(Logger::ERROR, sWhere+":"+szErr);
+        AVG_ASSERT(false);
     }
 }
 #endif
@@ -117,7 +135,6 @@ bool queryOGLExtension(const char *extName)
     size_t extNameLen = strlen(extName);
 
     p = (char *)glGetString(GL_EXTENSIONS);
-//    cout << "OpenGL extensions string: " << p << endl;
     if (NULL == p) {
         throw Exception(AVG_ERR_VIDEO_GENERAL, "Couldn't get OpenGL extension string.");
     }
@@ -134,7 +151,8 @@ bool queryOGLExtension(const char *extName)
     return false;
 }
 
-bool queryGLXExtension(const char *extName) {
+bool queryGLXExtension(const char *extName)
+{
 #if (defined __APPLE__) || (defined _WIN32)
     return false;
 #else
@@ -145,7 +163,6 @@ bool queryGLXExtension(const char *extName) {
     if (NULL == p) {
         throw Exception(AVG_ERR_VIDEO_GENERAL, "Couldn't get GLX extension string.");
     }
-//    cout << "GLX extensions string: " << p << endl;
 
     char * end = p + strlen(p);
 
@@ -162,18 +179,19 @@ bool queryGLXExtension(const char *extName) {
 #endif
 }
 
-void getGLVersion(int & major, int& minor)
+void getGLVersion(int& major, int& minor)
 {
     const char* pVersion = (const char*)glGetString(GL_VERSION);
     sscanf(pVersion, "%d.%d", &major, &minor);
 }
 
-void getGLShadingLanguageVersion(int & major, int& minor)
+void getGLShadingLanguageVersion(int& major, int& minor)
 {
     int glMajor, glMinor;
     getGLVersion(glMajor, glMinor);
 
-    major = minor = 0;
+    major = 0;
+    minor = 0;
     if (glMajor == 1) {
         if (queryOGLExtension("GL_ARB_shading_language_100")) {
             major = 1;
@@ -233,12 +251,61 @@ void popGLState()
     OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, "popGLState()");
 }
 
+#if defined(__APPLE__)
+CGLContextObj g_AVGGLContext;
+#elif defined(__linux__)
+Display* g_pAVGGLDisplay;
+GLXDrawable g_pAVGGLDrawable;
+GLXContext g_AVGGLContext;
+#elif defined(_WIN32)
+HDC g_AVGGLHDC;
+HGLRC g_AVGGLContext;
+#endif
+
+void AVG_API saveAVGGLContext()
+{
+#if defined(__APPLE__)
+    g_AVGGLContext = CGLGetCurrentContext();
+#elif defined(__linux__)
+    g_pAVGGLDisplay = glXGetCurrentDisplay();
+    g_pAVGGLDrawable = glXGetCurrentDrawable();
+    g_AVGGLContext = glXGetCurrentContext();
+#elif defined(_WIN32)
+    g_AVGGLHDC = wglGetCurrentDC();
+    g_AVGGLContext = wglGetCurrentContext();
+#endif
+}
+
+void AVG_API restoreAVGGLContext()
+{
+    AVG_ASSERT(g_AVGGLContext);
+#if defined(__APPLE__)
+    CGLSetCurrentContext(g_AVGGLContext);
+#elif defined(__linux__)
+    glXMakeCurrent(g_pAVGGLDisplay, g_pAVGGLDrawable, g_AVGGLContext);
+#elif defined(_WIN32)
+    wglMakeCurrent(g_AVGGLHDC, g_AVGGLContext);
+#endif
+}
+
+void AVG_API clearGLBuffers(GLbitfield mask)
+{
+    glClearColor(0.0, 0.0, 0.0, 0.0); 
+    if (mask & GL_STENCIL_BUFFER_BIT) {
+        glStencilMask(~0);
+        glClearStencil(0);
+    }
+    glClear(mask);
+    OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, "clearGLBuffers()");
+    if (mask & GL_STENCIL_BUFFER_BIT) {
+        glStencilMask(0);
+    }
+}
+
+
 void invalidGLCall()
 {
-    // Use this to cause core dump so we have the stack.
-//    printf("%s");
-    throw Exception(AVG_ERR_VIDEO_GENERAL, "Illegal gl entry point called.");
-    // Cause core dump.
+    assert(false);
 }
 
 void loadGLLibrary()
@@ -273,7 +340,7 @@ void loadGLLibrary()
 
 GLfunction getProcAddress(const string& sName)
 {
-    assert(glproc::s_hGLLib);
+    AVG_ASSERT(glproc::s_hGLLib);
 #ifdef _WIN32
     GLfunction pProc = (GLfunction)wglGetProcAddress(sName.c_str());
 /*
@@ -282,7 +349,8 @@ GLfunction getProcAddress(const string& sName)
         FormatMessage((FORMAT_MESSAGE_IGNORE_INSERTS | FORMAT_MESSAGE_FROM_SYSTEM),
                 0, GetLastError(), MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT),
                 szErr, 512, 0);
-        throw Exception(AVG_ERR_VIDEO_GENERAL, string("wglGetProcAddress("+sName+") failed: ") + szErr);
+        throw Exception(AVG_ERR_VIDEO_GENERAL, 
+                string("wglGetProcAddress("+sName+") failed: ") + szErr);
     }
 */
 #else
@@ -309,9 +377,6 @@ GLfunction getFuzzyProcAddress(const char * psz)
     }
     if (!pProc) {
         pProc = invalidGLCall;
-//        AVG_TRACE(Logger::WARNING, "Couldn't initialize pointer to " << psz);
-    } else {
-//        AVG_TRACE(Logger::WARNING, "Pointer to " << psz << " initialized.");
     }
     return pProc;
 }
@@ -319,7 +384,6 @@ GLfunction getFuzzyProcAddress(const char * psz)
 GLfunction getglXProcAddress(const char * psz)
 {
     GLfunction pProc = (GLfunction)glXGetProcAddress((const GLubyte *)psz);
-    //GLfunction pProc = (GLfunction)glXGetProcAddressARB((const GLubyte *)psz);
     if (!pProc) {
         pProc = invalidGLCall;
     }
@@ -379,8 +443,16 @@ namespace glproc {
         Uniform1i = (PFNGLUNIFORM1IARBPROC)getFuzzyProcAddress("glUniform1i");
         Uniform1f = (PFNGLUNIFORM1FARBPROC)getFuzzyProcAddress("glUniform1f");
         Uniform2f = (PFNGLUNIFORM2FARBPROC)getFuzzyProcAddress("glUniform2f");
+        Uniform3f = (PFNGLUNIFORM3FARBPROC)getFuzzyProcAddress("glUniform3f");
+        Uniform4f = (PFNGLUNIFORM4FARBPROC)getFuzzyProcAddress("glUniform4f");
         Uniform1fv = (PFNGLUNIFORM1FVARBPROC)getFuzzyProcAddress("glUniform1fv");
+        UniformMatrix4fv = (PFNGLUNIFORMMATRIX4FVARBPROC)
+                getFuzzyProcAddress("glUniformMatrix4fv");
+        
+        BlendFuncSeparate = (PFNGLBLENDFUNCSEPARATEPROC)
+                getFuzzyProcAddress("glBlendFuncSeparate");
         BlendEquation = (PFNGLBLENDEQUATIONPROC)getFuzzyProcAddress("glBlendEquation");
+        BlendColor = (PFNGLBLENDCOLORPROC)getFuzzyProcAddress("glBlendColor");
         ActiveTexture = (PFNGLACTIVETEXTUREPROC)getFuzzyProcAddress("glActiveTexture");
         GenerateMipmap = (PFNGLGENERATEMIPMAPEXTPROC)getFuzzyProcAddress
                 ("glGenerateMipmap");
@@ -395,6 +467,20 @@ namespace glproc {
                 getFuzzyProcAddress("glFramebufferTexture2D");
         DeleteFramebuffers = (PFNGLDELETEFRAMEBUFFERSEXTPROC)
                 getFuzzyProcAddress("glDeleteFramebuffers");
+        GenRenderbuffers = (PFNGLGENRENDERBUFFERSEXTPROC)
+                getFuzzyProcAddress("glGenRenderbuffers");
+        BindRenderbuffer = (PFNGLBINDRENDERBUFFEREXTPROC)
+                getFuzzyProcAddress("glBindRenderbuffer");
+        RenderbufferStorage= (PFNGLRENDERBUFFERSTORAGEEXTPROC)
+                getFuzzyProcAddress("glRenderbufferStorage");
+        RenderbufferStorageMultisample = (PFNGLRENDERBUFFERSTORAGEMULTISAMPLEEXTPROC)
+                getFuzzyProcAddress("glRenderbufferStorageMultisample");
+        FramebufferRenderbuffer = (PFNGLFRAMEBUFFERRENDERBUFFEREXTPROC)
+                getFuzzyProcAddress("glFramebufferRenderbuffer");
+        BlitFramebuffer = (PFNGLBLITFRAMEBUFFEREXTPROC)
+                getFuzzyProcAddress("glBlitFramebuffer");
+        DeleteRenderbuffers = (PFNGLDELETERENDERBUFFERSEXTPROC)
+                getFuzzyProcAddress("glDeleteRenderbuffers");
 #ifdef linux
         SwapIntervalSGI = (PFNGLXSWAPINTERVALSGIPROC)
                 getglXProcAddress("glXSwapIntervalSGI");
