@@ -48,23 +48,27 @@ typedef int (*PFNWGLEXTGETSWAPINTERVALPROC) (void);
 
 namespace avg {
 
-void AVG_API OGLErrorCheck(int avgcode, const char * where);
+void AVG_API OGLErrorCheck(int avgcode, const std::string& where);
 #ifdef _WIN32
-void AVG_API winOGLErrorCheck(BOOL bOK, const std::string & where);
+void AVG_API winOGLErrorCheck(BOOL bOK, const std::string& sWhere);
 #endif
-bool AVG_API queryOGLExtension(const char *extName);
-bool AVG_API queryGLXExtension(const char *extName);
-void AVG_API getGLVersion(int & major, int& minor);
-void AVG_API getGLShadingLanguageVersion(int & major, int& minor);
+bool AVG_API queryOGLExtension(const char* extName);
+bool AVG_API queryGLXExtension(const char* extName);
+void AVG_API getGLVersion(int& major, int& minor);
+void AVG_API getGLShadingLanguageVersion(int& major, int& minor);
 std::string AVG_API oglModeToString(int mode);
 
 enum OGLMemoryMode { 
-    OGL,  // Standard OpenGL
-    PBO   // pixel buffer objects
+    MM_OGL,  // Standard OpenGL
+    MM_PBO   // pixel buffer objects
 };
 
 void AVG_API pushGLState();
 void AVG_API popGLState();
+void AVG_API saveAVGGLContext();
+void AVG_API restoreAVGGLContext();
+
+void AVG_API clearGLBuffers(GLbitfield mask);
 
 typedef void (*GLfunction)();
 GLfunction AVG_API getFuzzyProcAddress(const char * psz);
@@ -92,8 +96,14 @@ namespace glproc {
     extern AVG_API PFNGLUNIFORM1IARBPROC Uniform1i;
     extern AVG_API PFNGLUNIFORM1FARBPROC Uniform1f;
     extern AVG_API PFNGLUNIFORM2FARBPROC Uniform2f;
+    extern AVG_API PFNGLUNIFORM3FARBPROC Uniform3f;
+    extern AVG_API PFNGLUNIFORM4FARBPROC Uniform4f;
     extern AVG_API PFNGLUNIFORM1FVARBPROC Uniform1fv;
+    extern AVG_API PFNGLUNIFORMMATRIX4FVARBPROC UniformMatrix4fv;
+
+    extern AVG_API PFNGLBLENDFUNCSEPARATEPROC BlendFuncSeparate;
     extern AVG_API PFNGLBLENDEQUATIONPROC BlendEquation;
+    extern AVG_API PFNGLBLENDCOLORPROC BlendColor;
     extern AVG_API PFNGLACTIVETEXTUREPROC ActiveTexture;
     extern AVG_API PFNGLGENERATEMIPMAPEXTPROC GenerateMipmap;
 
@@ -102,7 +112,15 @@ namespace glproc {
     extern AVG_API PFNGLBINDFRAMEBUFFEREXTPROC BindFramebuffer;
     extern AVG_API PFNGLFRAMEBUFFERTEXTURE2DEXTPROC FramebufferTexture2D;
     extern AVG_API PFNGLDELETEFRAMEBUFFERSEXTPROC DeleteFramebuffers;
-
+    extern AVG_API PFNGLGENRENDERBUFFERSEXTPROC GenRenderbuffers;
+    extern AVG_API PFNGLBINDRENDERBUFFEREXTPROC BindRenderbuffer;
+    extern AVG_API PFNGLRENDERBUFFERSTORAGEEXTPROC RenderbufferStorage;
+    extern AVG_API PFNGLRENDERBUFFERSTORAGEMULTISAMPLEEXTPROC
+            RenderbufferStorageMultisample;
+    extern AVG_API PFNGLFRAMEBUFFERRENDERBUFFEREXTPROC FramebufferRenderbuffer;
+    extern AVG_API PFNGLBLITFRAMEBUFFEREXTPROC BlitFramebuffer;
+    extern AVG_API PFNGLDELETERENDERBUFFERSEXTPROC DeleteRenderbuffers;
+    
 #ifdef linux
     extern PFNGLXSWAPINTERVALSGIPROC SwapIntervalSGI;
     extern PFNGLXWAITVIDEOSYNCSGIPROC WaitVideoSyncSGI;
@@ -118,9 +136,5 @@ namespace glproc {
 
 }
 
-#ifndef GL_TEXTURE_RECTANGLE_NV
-#define GL_TEXTURE_RECTANGLE_NV           0x84F5
-#endif
-
 #endif
  
