@@ -20,6 +20,9 @@
 //
 
 #include "OGLImagingContext.h"
+#undef check
+#include "ShaderRegistry.h"
+#include "GPUFilter.h"
 
 #include "../base/Exception.h"
 
@@ -27,16 +30,15 @@
 // XXX: If the following includes are not there, the MS linker optimizes away
 // the classes so they can't be used by plugins anymore (!). Adding /OPT:NOREF
 // to the linker flags doesn't help. 
-#include "IteratingGPUFilter.h"
 #include "FilterGetAlpha.h"
 #include "FilterErosion.h"
 #include "FilterDilation.h"
 #include "FilterGetAlpha.h"
 #include "FilterResizeBilinear.h"
 #include "FilterResizeGaussian.h"
+#include "FilterThreshold.h"
 #endif
 
-#include <assert.h>
 #include <iostream>
 
 namespace avg {
@@ -70,7 +72,7 @@ void registerWindowClass()
   wc.lpszClassName = pClassName;
   
   BOOL bOK = RegisterClass(&wc);
-  assert(bOK);
+  AVG_ASSERT(bOK);
 }
 #endif
 
@@ -87,20 +89,20 @@ int X11ErrorHandler(Display * pDisplay, XErrorEvent * pErrEvent)
 }
 #endif
 
-OGLImagingContext::OGLImagingContext(const IntPoint & size)
+OGLImagingContext::OGLImagingContext()
 {
 #ifdef __APPLE__
     GLint attributes[] = {AGL_RGBA, AGL_ALL_RENDERERS,AGL_NONE};
     AGLPixelFormat format;
     format = aglChoosePixelFormat(NULL, 0, attributes);
-    assert(format);
+    AVG_ASSERT(format);
 
     m_Context = aglCreateContext(format, NULL);
-    assert(m_Context);
+    AVG_ASSERT(m_Context);
     aglDestroyPixelFormat(format);
 
     bool bOk = aglSetCurrentContext(m_Context);
-    assert (bOk);
+    AVG_ASSERT (bOk);
 #else
 #ifdef linux
     Display *dpy;
@@ -116,7 +118,7 @@ OGLImagingContext::OGLImagingContext(const IntPoint & size)
             0};
     vi = glXChooseVisual(dpy, DefaultScreen(dpy), attributes);
     m_Context = glXCreateContext(dpy, vi, 0, GL_TRUE);
-    assert(m_Context);
+    AVG_ASSERT(m_Context);
     Pixmap pmp = XCreatePixmap(dpy, RootWindow(dpy, vi->screen),
             8, 8, vi->depth);
     GLXPixmap pixmap = glXCreateGLXPixmap(dpy, vi, pmp);
@@ -168,15 +170,13 @@ OGLImagingContext::OGLImagingContext(const IntPoint & size)
                 "GPU imaging not supported by current OpenGL configuration.");
     }
 
-    // Coordinates
-    setSize(size);
-
-    setStandardState(size);
-//    IteratingGPUFilter f(IntPoint(100, 100), 15);
+    setStandardState();
 }
 
 OGLImagingContext::~OGLImagingContext()
 {
+    ShaderRegistry::kill();
+    GPUFilter::glContextGone();
 #ifdef __APPLE__
     if (m_Context) {
         aglSetCurrentContext(0);
@@ -197,20 +197,14 @@ void OGLImagingContext::activate()
 {
 #ifdef __APPLE__
     bool bOk = aglSetCurrentContext(m_Context);
-    assert(bOk);
+    AVG_ASSERT(bOk);
 #elif defined _WIN32
     BOOL bOk = wglMakeCurrent(m_hDC, m_Context);
-    assert(bOk);
+    AVG_ASSERT(bOk);
 #endif
     // TODO: X version
 }
 
-void OGLImagingContext::setSize(const IntPoint& size)
-{
-    m_Size = size;
-    setSizeState(size);
-}
-
 bool OGLImagingContext::isSupported()
 {
     int glMajorVer;
@@ -219,16 +213,13 @@ bool OGLImagingContext::isSupported()
     int slMinorVer;
     getGLVersion(glMajorVer, glMinorVer);
     getGLShadingLanguageVersion(slMajorVer, slMinorVer);
-    // Not sure if we need shader version 1.2 as well - we'll see.
     return (glMajorVer > 1 && queryOGLExtension("GL_ARB_texture_rectangle") && 
             queryOGLExtension("GL_ARB_pixel_buffer_object") &&
             queryOGLExtension("GL_EXT_framebuffer_object"));
 }
 
-void OGLImagingContext::setStandardState(const IntPoint & size)
+void OGLImagingContext::setStandardState()
 {
-    setSizeState(size);
-
     // Shading etc.
     glDisable(GL_BLEND);
     OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, "glDisable(GL_BLEND)");
@@ -244,8 +235,6 @@ void OGLImagingContext::setStandardState(const IntPoint & size)
     OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, "glTexEnvf()");
     glBlendFunc(GL_ONE, GL_ZERO);
     OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, "glBlendFunc()");
-    glEnable(GL_TEXTURE_RECTANGLE_ARB);
-    OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, "glEnable(GL_TEXTURE_RECTANGLE_ARB);");
     glDisable(GL_MULTISAMPLE);
     OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, "glDisable(GL_MULTISAMPLE);");
 
@@ -255,20 +244,5 @@ void OGLImagingContext::setStandardState(const IntPoint & size)
     glEnableClientState(GL_TEXTURE_COORD_ARRAY);
 }
 
-void OGLImagingContext::setSizeState(const IntPoint & size)
-{
-    glViewport(0, 0, size.x, size.y);
-    OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, "glViewport()");
-    glMatrixMode(GL_PROJECTION);
-    OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, "glMatrixMode()");
-    glLoadIdentity();
-    OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, "glLoadIdentity()");
-    gluOrtho2D(0, size.x, size.y, 0);
-    OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, "gluOrtho2D()");
-    glMatrixMode(GL_MODELVIEW);
-    glLoadIdentity();
-    OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, "glLoadIdentity()");
-}
-
 }
 
