@@ -23,6 +23,8 @@
 
 #include "../base/Logger.h"
 #include "../base/Exception.h"
+#include "../base/Matrix3x4.h"
+
 #include <iostream>
 
 using namespace std;
@@ -85,6 +87,11 @@ void OGLShader::setUniformFloatParam(const std::string& sName, float val)
             (string("OGLShader: glUniform(")+sName+")").c_str());
 }
 
+void OGLShader::setUniformFloatParam(const std::string& sName, double val)
+{
+    return setUniformFloatParam(sName, float(val));
+}
+
 void OGLShader::setUniformFloatArrayParam(const std::string& sName, int count, 
         float* pVal)
 {
@@ -102,6 +109,24 @@ void OGLShader::setUniformDPointParam(const std::string& sName, DPoint pt)
             (string("OGLShader: glUniform(")+sName+")").c_str());
 }
         
+void OGLShader::setUniformColorParam(const std::string& sName, Pixel32 col)
+{
+    int loc = safeGetUniformLoc(sName);
+    glproc::Uniform4f(loc, col.getR()/255.f, col.getG()/255.f, col.getB()/255.f,
+            col.getA()/255.f);
+    OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, 
+            (string("OGLShader: glUniform(")+sName+")").c_str());
+}
+        
+void OGLShader::setUniformVec4fParam(const std::string& sName, float x, float y, float z, 
+                float w)
+{
+    int loc = safeGetUniformLoc(sName);
+    glproc::Uniform4f(loc, x, y, z, w);
+    OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, 
+            (string("OGLShader: glUniform(")+sName+")").c_str());
+}
+
 void OGLShader::dumpInfoLog(GLhandleARB hObj)
 {
     int InfoLogLength;
@@ -110,7 +135,9 @@ void OGLShader::dumpInfoLog(GLhandleARB hObj)
     glproc::GetObjectParameteriv(hObj, GL_OBJECT_INFO_LOG_LENGTH_ARB, &InfoLogLength);
     OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, 
             "OGLShader::dumpInfoLog: glGetObjectParameteriv()");
-    if (InfoLogLength > 1) {
+    bool bLogContainsGarbage = (string((char *)glGetString(GL_VENDOR)) 
+            != "NVIDIA Corporation");
+    if (InfoLogLength > 1 && !bLogContainsGarbage) {
         pInfoLog = (GLcharARB*)malloc(InfoLogLength);
         int CharsWritten;
         glproc::GetInfoLog(hObj, InfoLogLength, &CharsWritten, pInfoLog);
