@@ -24,6 +24,7 @@
 
 #include "../api.h"
 #include "OGLHelper.h"
+#include "Pixel32.h"
 
 #include "../base/Point.h"
 
@@ -33,9 +34,10 @@
 
 namespace avg {
 
+class Matrix3x4;
+
 class AVG_API OGLShader {
     public:
-        OGLShader(std::string sProgram);
         virtual ~OGLShader();
 
         void activate();
@@ -43,10 +45,17 @@ class AVG_API OGLShader {
 
         void setUniformIntParam(const std::string& sName, int val);
         void setUniformFloatParam(const std::string& sName, float val);
+        void setUniformFloatParam(const std::string& sName, double val);
         void setUniformFloatArrayParam(const std::string& sName, int count, float* pVal);
         void setUniformDPointParam(const std::string& sName, DPoint pt);
+        void setUniformColorParam(const std::string& sName, Pixel32 col);
+        void setUniformVec4fParam(const std::string& sName, float x, float y, float z, 
+                float w);
 
     private:
+        OGLShader(std::string sProgram);
+        friend class ShaderRegistry;
+
         void dumpInfoLog(GLhandleARB hObj);
         int safeGetUniformLoc(const std::string& sName);
 
