@@ -22,6 +22,7 @@
 #ifndef _Pixel16_H_
 #define _Pixel16_H_
 
+#include "../api.h"
 #include "Pixeldefs.h"
 #include "Pixel24.h"
 #include "Pixel32.h"
@@ -29,9 +30,11 @@
 #include <stdlib.h>
 #include <math.h>
 
+namespace avg {
+
 // 16 bit pixel class. A pixel in this class contains 5 bits of
 // red, 6 of green and 5 of blue (in that order). 
-class Pixel16
+class AVG_API Pixel16
 {
   public:
     Pixel16 ();
@@ -173,4 +176,5 @@ inline bool Pixel16::operator !=(const Pixel16 Pix) const
 }
 
 
+}
 #endif
