@@ -23,8 +23,7 @@
 
 #include "../base/Exception.h"
 #include "../base/WideLine.h"
-
-#include <assert.h>
+#include "../base/ObjectCounter.h"
 
 #include <iostream>
 #include <stddef.h>
@@ -38,28 +37,20 @@ namespace avg {
 thread_specific_ptr<vector<unsigned int> > VertexArray::s_pGLVertexBufferIDs;
 thread_specific_ptr<vector<unsigned int> > VertexArray::s_pGLIndexBufferIDs;
 
-VertexArray::VertexArray(int numVerts, int numIndexes, int reserveVerts, 
-        int reserveIndexes)
-    : m_NumVerts(numVerts),
-      m_NumIndexes(numIndexes),
+VertexArray::VertexArray(int reserveVerts, int reserveIndexes)
+    : m_NumVerts(0),
+      m_NumIndexes(0),
       m_ReserveVerts(reserveVerts),
       m_ReserveIndexes(reserveIndexes),
-      m_CurVert(0),
-      m_CurIndex(0),
       m_bDataChanged(true)
 {
+    ObjectCounter::get()->incRef(&typeid(*this));
     if (m_ReserveVerts < 10) {
         m_ReserveVerts = 10;
     }
     if (m_ReserveIndexes < 20) {
         m_ReserveIndexes = 20;
     }
-    if (m_NumVerts > m_ReserveVerts) {
-        m_ReserveVerts = m_NumVerts;
-    }
-    if (m_NumIndexes > m_ReserveIndexes) {
-        m_ReserveIndexes = m_NumIndexes;
-    }
     m_pVertexData = new T2V3C4Vertex[m_ReserveVerts];
     m_pIndexData = new unsigned int[m_ReserveIndexes];
 
@@ -69,7 +60,6 @@ VertexArray::VertexArray(int numVerts, int numIndexes, int reserveVerts,
     {
         glproc::GenBuffers(1, &m_GLVertexBufferID);
         glproc::GenBuffers(1, &m_GLIndexBufferID);
-        setBufferSize();
     } else {
         m_GLVertexBufferID = s_pGLVertexBufferIDs->back();
         s_pGLVertexBufferIDs->pop_back();
@@ -80,126 +70,97 @@ VertexArray::VertexArray(int numVerts, int numIndexes, int reserveVerts,
 
 VertexArray::~VertexArray()
 {
-    if (m_ReserveVerts == 10) {
+    if (m_ReserveVerts == 10 && s_pGLVertexBufferIDs.get() != 0) {
         s_pGLVertexBufferIDs->push_back(m_GLVertexBufferID);
     } else {
         glproc::DeleteBuffers(1, &m_GLVertexBufferID);
     }
-    if (m_ReserveIndexes == 20) {
+    if (m_ReserveIndexes == 20 && s_pGLIndexBufferIDs.get() != 0) {
         s_pGLIndexBufferIDs->push_back(m_GLIndexBufferID);
     } else {
         glproc::DeleteBuffers(1, &m_GLIndexBufferID);
     }
     delete[] m_pVertexData;
     delete[] m_pIndexData;
+    ObjectCounter::get()->decRef(&typeid(*this));
 }
 
-void VertexArray::appendPos(const DPoint& pos, 
-        const DPoint& texPos, const Pixel32& color)
+void VertexArray::appendPos(const DPoint& pos, const DPoint& texPos, const Pixel32& color)
 {
-    assert(m_CurVert < m_NumVerts);
-    T2V3C4Vertex* pVertex = &(m_pVertexData[m_CurVert]);
-    if (pVertex->m_Pos[0] != (GLfloat)pos.x || 
-            pVertex->m_Pos[1] != (GLfloat)pos.y ||
-            pVertex->m_Tex[0] != (GLfloat)texPos.x || 
-            pVertex->m_Tex[1] != (GLfloat)texPos.y ||
-            pVertex->m_Color != color)
-    {
-        T2V3C4Vertex* pVertex = &m_pVertexData[m_CurVert];
-        pVertex->m_Pos[0] = (GLfloat)pos.x;
-        pVertex->m_Pos[1] = (GLfloat)pos.y;
-        pVertex->m_Pos[2] = 0.0;
-        pVertex->m_Tex[0] = (GLfloat)texPos.x;
-        pVertex->m_Tex[1] = (GLfloat)texPos.y;
-        pVertex->m_Color = color;
-        m_bDataChanged = true;
+    if (m_NumVerts >= m_ReserveVerts-1) {
+        grow();
     }
-    m_CurVert++;
+    T2V3C4Vertex* pVertex = &(m_pVertexData[m_NumVerts]);
+    pVertex->m_Pos[0] = (GLfloat)pos.x;
+    pVertex->m_Pos[1] = (GLfloat)pos.y;
+    pVertex->m_Pos[2] = 0.0;
+    pVertex->m_Tex[0] = (GLfloat)texPos.x;
+    pVertex->m_Tex[1] = (GLfloat)texPos.y;
+    pVertex->m_Color = color;
+    m_bDataChanged = true;
+    m_NumVerts++;
 }
 
 void VertexArray::appendTriIndexes(int v0, int v1, int v2)
 {
-    m_pIndexData[m_CurIndex] = v0;
-    m_pIndexData[m_CurIndex+1] = v1;
-    m_pIndexData[m_CurIndex+2] = v2;
-    m_CurIndex+=3;
+    if (m_NumIndexes >= m_ReserveIndexes-3) {
+        grow();
+    }
+    m_pIndexData[m_NumIndexes] = v0;
+    m_pIndexData[m_NumIndexes+1] = v1;
+    m_pIndexData[m_NumIndexes+2] = v2;
+    m_NumIndexes += 3;
 }
 
 void VertexArray::appendQuadIndexes(int v0, int v1, int v2, int v3)
 {
-    m_pIndexData[m_CurIndex] = v0;
-    m_pIndexData[m_CurIndex+1] = v1;
-    m_pIndexData[m_CurIndex+2] = v2;
-    m_pIndexData[m_CurIndex+3] = v1;
-    m_pIndexData[m_CurIndex+4] = v2;
-    m_pIndexData[m_CurIndex+5] = v3;
-    m_CurIndex+=6;
+    if (m_NumIndexes >= m_ReserveIndexes-6) {
+        grow();
+    }
+    m_pIndexData[m_NumIndexes] = v0;
+    m_pIndexData[m_NumIndexes+1] = v1;
+    m_pIndexData[m_NumIndexes+2] = v2;
+    m_pIndexData[m_NumIndexes+3] = v1;
+    m_pIndexData[m_NumIndexes+4] = v2;
+    m_pIndexData[m_NumIndexes+5] = v3;
+    m_NumIndexes += 6;
 }
 
 void VertexArray::addLineData(Pixel32 color, const DPoint& p1, const DPoint& p2, 
-        double width, double TC1, double TC2)
+        double width, double tc1, double tc2)
 {
     WideLine wl(p1, p2, width);
     int curVertex = getCurVert();
-    appendPos(wl.pl0, DPoint(TC1, 1), color);
-    appendPos(wl.pr0, DPoint(TC1, 0), color);
-    appendPos(wl.pl1, DPoint(TC2, 1), color);
-    appendPos(wl.pr1, DPoint(TC2, 0), color);
+    appendPos(wl.pl0, DPoint(tc1, 1), color);
+    appendPos(wl.pr0, DPoint(tc1, 0), color);
+    appendPos(wl.pl1, DPoint(tc2, 1), color);
+    appendPos(wl.pr1, DPoint(tc2, 0), color);
     appendQuadIndexes(curVertex+1, curVertex, curVertex+3, curVertex+2); 
 }
 
-void VertexArray::changeSize(int numVerts, int numIndexes)
-{
-    if ((numVerts < 3 && numVerts != 0) || (numIndexes < 3 && numIndexes != 0)) {
-        cerr << "numVerts: " << numVerts << ", numIndexes: " << numIndexes << endl;
-        assert (false);
-    }
-        
-    bool bNewBuffer = false;
-    m_NumVerts = numVerts;
-    m_NumIndexes = numIndexes;
-    if (m_NumVerts > m_ReserveVerts) {
-        m_ReserveVerts = int(m_ReserveVerts*1.5);
-        if (m_ReserveVerts < m_NumVerts) {
-            m_ReserveVerts = m_NumVerts;
-        }
-        delete[] m_pVertexData;
-        m_pVertexData = new T2V3C4Vertex[m_ReserveVerts];
-        bNewBuffer = true;
-    }
-    if (m_NumIndexes > m_ReserveIndexes) {
-        m_ReserveIndexes = int(m_ReserveIndexes*1.5);
-        if (m_ReserveIndexes < m_NumIndexes) {
-            m_ReserveIndexes = m_NumIndexes;
-        }
-        delete[] m_pIndexData;
-        m_pIndexData = new unsigned int[m_ReserveIndexes];
-        bNewBuffer = true;
-    }
-    m_CurVert = 0;
-    m_CurIndex = 0;
-    if (bNewBuffer) {
-        setBufferSize();
-    }
-    m_bDataChanged = true;
-}
-
 void VertexArray::reset()
 {
-    m_CurVert = 0;
-    m_CurIndex = 0;
+    m_NumVerts = 0;
+    m_NumIndexes = 0;
 }
 
 void VertexArray::update()
 {
-//    cerr << (void*)this << "VertexArray::update m_NumVerts=" << m_NumVerts << ", m_NumIndexes=" << m_NumIndexes << ", m_CurVert=" << m_CurVert << ", m_CurIndex=" << m_CurIndex << endl;
     if (m_bDataChanged) {
         glproc::BindBuffer(GL_ARRAY_BUFFER, m_GLVertexBufferID);
-        glproc::BufferSubData(GL_ARRAY_BUFFER, 0, m_NumVerts*sizeof(T2V3C4Vertex),
-                m_pVertexData);
+        glproc::BufferData(GL_ARRAY_BUFFER, m_ReserveVerts*sizeof(T2V3C4Vertex), 0, 
+                GL_DYNAMIC_DRAW);
+        void * pBuffer = glproc::MapBuffer(GL_ARRAY_BUFFER, GL_WRITE_ONLY);
+        memcpy(pBuffer, m_pVertexData, m_NumVerts*sizeof(T2V3C4Vertex));
+        glproc::UnmapBuffer(GL_ARRAY_BUFFER);
+        
         glproc::BindBuffer(GL_ELEMENT_ARRAY_BUFFER, m_GLIndexBufferID);
-        glproc::BufferSubData(GL_ELEMENT_ARRAY_BUFFER, 0, m_NumIndexes*sizeof(unsigned int),
-                m_pIndexData);
+        glproc::BufferData(GL_ELEMENT_ARRAY_BUFFER, 
+            m_ReserveIndexes*sizeof(unsigned int), 0, GL_DYNAMIC_DRAW);
+        pBuffer = glproc::MapBuffer(GL_ELEMENT_ARRAY_BUFFER, GL_WRITE_ONLY);
+        memcpy(pBuffer, m_pIndexData, m_NumIndexes*sizeof(unsigned int));
+        glproc::UnmapBuffer(GL_ELEMENT_ARRAY_BUFFER);
+        
         OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, "VertexArray::update");
     }
     m_bDataChanged = false;
@@ -207,9 +168,7 @@ void VertexArray::update()
 
 void VertexArray::draw()
 {
-    if (m_bDataChanged) {
-        update();
-    }
+    update();
     glproc::BindBuffer(GL_ARRAY_BUFFER, m_GLVertexBufferID);
     glTexCoordPointer(2, GL_FLOAT, sizeof(T2V3C4Vertex), 0);
     glColorPointer(4, GL_UNSIGNED_BYTE, sizeof(T2V3C4Vertex), 
@@ -219,28 +178,51 @@ void VertexArray::draw()
     OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, "VertexArray::draw:1");
 
     glproc::BindBuffer(GL_ELEMENT_ARRAY_BUFFER, m_GLIndexBufferID);
-    glDrawElements(GL_TRIANGLES, m_CurIndex, GL_UNSIGNED_INT, 0);
+    // TODO: glDrawRangeElements is allegedly faster.
+    glDrawElements(GL_TRIANGLES, m_NumIndexes, GL_UNSIGNED_INT, 0);
     OGLErrorCheck(AVG_ERR_VIDEO_GENERAL, "VertexArray::draw():2");
 }
 
 int VertexArray::getCurVert() const
 {
-    return m_CurVert;
+    return m_NumVerts;
 }
 
 int VertexArray::getCurIndex() const
 {
-    return m_CurIndex;
+    return m_NumIndexes;
 }
 
-void VertexArray::setBufferSize() 
+void VertexArray::grow()
 {
-    glproc::BindBuffer(GL_ARRAY_BUFFER, m_GLVertexBufferID);
-    glproc::BufferData(GL_ARRAY_BUFFER, m_ReserveVerts*sizeof(T2V3C4Vertex), 0, 
-            GL_STREAM_DRAW);
-    glproc::BindBuffer(GL_ELEMENT_ARRAY_BUFFER, m_GLIndexBufferID);
-    glproc::BufferData(GL_ELEMENT_ARRAY_BUFFER, 
-            m_ReserveIndexes*sizeof(unsigned int), 0, GL_STREAM_DRAW);
+    bool bChanged = false;
+    if (m_NumVerts >= m_ReserveVerts-1) {
+        bChanged = true;
+        int oldReserveVerts = m_ReserveVerts;
+        m_ReserveVerts = int(m_ReserveVerts*1.5);
+        if (m_ReserveVerts < m_NumVerts) {
+            m_ReserveVerts = m_NumVerts;
+        }
+        T2V3C4Vertex* pVertexData = m_pVertexData;
+        m_pVertexData = new T2V3C4Vertex[m_ReserveVerts];
+        memcpy(m_pVertexData, pVertexData, sizeof(T2V3C4Vertex)*oldReserveVerts);
+        delete[] pVertexData;
+    }
+    if (m_NumIndexes >= m_ReserveIndexes-6) {
+        bChanged = true;
+        int oldReserveIndexes = m_ReserveIndexes;
+        m_ReserveIndexes = int(m_ReserveIndexes*1.5);
+        if (m_ReserveIndexes < m_NumIndexes) {
+            m_ReserveIndexes = m_NumIndexes;
+        }
+        unsigned int * pIndexData = m_pIndexData;
+        m_pIndexData = new unsigned int[m_ReserveIndexes];
+        memcpy(m_pIndexData, pIndexData, sizeof(unsigned int)*oldReserveIndexes);
+        delete[] pIndexData;
+    }
+    if (bChanged) {
+        m_bDataChanged = true;
+    }
 }
 
 void VertexArray::initBufferCache()
@@ -255,14 +237,20 @@ void VertexArray::initBufferCache()
 
 void VertexArray::deleteBufferCache()
 {
-    for (unsigned i=0; i<s_pGLVertexBufferIDs->size(); ++i) {
-        glproc::DeleteBuffers(1, &((*s_pGLVertexBufferIDs)[i]));
+    if (s_pGLVertexBufferIDs.get() != 0) {
+        for (unsigned i=0; i<s_pGLVertexBufferIDs->size(); ++i) {
+            glproc::DeleteBuffers(1, &((*s_pGLVertexBufferIDs)[i]));
+        }
+        s_pGLVertexBufferIDs->clear();
+        s_pGLVertexBufferIDs.reset();
     }
-    s_pGLVertexBufferIDs->clear();
-    for (unsigned i=0; i<s_pGLIndexBufferIDs->size(); ++i) {
-        glproc::DeleteBuffers(1, &((*s_pGLIndexBufferIDs)[i]));
+    if (s_pGLIndexBufferIDs.get() != 0) {
+        for (unsigned i=0; i<s_pGLIndexBufferIDs->size(); ++i) {
+            glproc::DeleteBuffers(1, &((*s_pGLIndexBufferIDs)[i]));
+        }
+        s_pGLIndexBufferIDs->clear();
+        s_pGLIndexBufferIDs.reset();
     }
-    s_pGLIndexBufferIDs->clear();
 }
 
 }
