@@ -55,7 +55,7 @@ void runPerformanceTest()
 {
     TEST PerfTest;
     long long StartTime = TimeSource::get()->getCurrentMicrosecs();
-    for (int i=0; i<NUM_RUNS; ++i) {
+    for (int i = 0; i < NUM_RUNS; ++i) {
         PerfTest.run();
     }
     double ActiveTime = (TimeSource::get()->getCurrentMicrosecs()-StartTime)/1000.; 
@@ -173,7 +173,7 @@ public:
 
     void run() {
         Bitmap RGBBmp(IntPoint(1024, 1024), B8G8R8X8);
-        RGBBmp.copyYUVPixels(*m_pYBmp, *m_pUBmp, *m_pVBmp);
+        RGBBmp.copyYUVPixels(*m_pYBmp, *m_pUBmp, *m_pVBmp, false);
     }
 
 private:
