@@ -20,11 +20,12 @@
 //
 
 #include "GraphicsTest.h"
+#include "GLTexture.h"
 #include "GPUBrightnessFilter.h"
 #include "GPUBlurFilter.h"
 #include "GPUBandpassFilter.h"
+#include "GPUChromaKeyFilter.h"
 #include "OGLImagingContext.h"
-#include "IteratingGPUFilter.h"
 
 #include "../base/TestSuite.h"
 #include "../base/Exception.h"
@@ -37,6 +38,7 @@
 using namespace avg;
 using namespace std;
 
+/*
 class FBOTest: public GraphicsTest {
 public:
     FBOTest()
@@ -53,14 +55,16 @@ public:
         runImageTests("rgb24-64x64", GL_FLOAT);
         runImageTests("rgb24alpha-64x64", GL_FLOAT);
 
-        runPBOFloatbufTestI32F();
-        runPBOFloatbufTestR32G32B32A32F();
-        
-        runPBOBitmapTestR32G32B32A32F();
-        runPBOBitmapTestI32F();
+        if (GLTexture::isFloatFormatSupported()) {
+            runPBOFloatbufTest(I32F);
+            runPBOFloatbufTest(R32G32B32A32F);
+            
+            runPBOFloatBitmapTest(R32G32B32A32F);
+            runPBOFloatBitmapTest(I32F);
 
-        runPBOBitmapTestR32G32B32A32FextR8G8B8A8();
-        runPBOBitmapTestI32FextI8();
+            runPBOBitmapTestIntFloatExtByte(R32G32B32A32F, R8G8B8A8);
+            runPBOBitmapTestIntFloatExtByte(I32F, I8);
+        }
     }
 
 private:
@@ -74,124 +78,88 @@ private:
         runPBOImageTest(pbo, pBmp, string("pbo_")+sFName);
     }
 
-    void compareByteArrays(unsigned char *in, unsigned char *out, int n) {
-        for (int i=0; i<n; i++) {
+    void compareByteArrays(unsigned char *in, unsigned char *out, int n)
+    {
+        for (int i = 0; i < n; i++) {
             if (in[i] != out[i]) {
                 TEST_FAILED("compareByteArrays: " + toString((int)in[i]) + " (in) != "
                         + toString((int)out[i]) + " (out)")
             }
         }
     }
-    void compareFloatArrays(float *in, float *out, int n) {
-        for (int i=0; i<n; i++) {
-            if (fabs(in[i]-out[i])>1e-5) {
+
+    void compareFloatArrays(float *in, float *out, int n)
+    {
+        for (int i = 0; i < n; i++) {
+            if (fabs(in[i]-out[i]) > 1e-5) {
                 TEST_FAILED("compareFloatArrays: " + toString(in[i]) + " (in) != " 
                         + toString(out[i]) + " (out)")
             }
         }
     }
 
-    void setAndCompareImage(PBOImage *pbo, float *in, int n) {
-        pbo->setImage(in);
-        BitmapPtr res = pbo->getImage();
-        float *out = (float*)res->getPixels();
-        compareFloatArrays(in, out, n);
-    }
-
-    void fillFloatArray(float *data, int n) {
-        for (int i=0;i<n;i++) {
+    void fillFloatArray(float *data, int n)
+    {
+        for (int i = 0; i < n; i++) {
             data[i] = 0.01f * i;
         }
     }
-    void fillByteArray(unsigned char *data, int n) {
+
+    void fillByteArray(unsigned char *data, int n)
+    {
         for (int i = 0; i<n; i++) {
             data[i] = i * 2;
         }
     }
-    void runPBOFloatbufTest(PixelFormat pf) {
-        assert(pf == I32F || pf == R32G32B32A32F);
+
+    void runPBOFloatbufTest(PixelFormat pf)
+    {
+        cerr << "    Testing PBO (" << Bitmap::getPixelFormatString(pf) << ")" << endl;
+        AVG_ASSERT(pf == I32F || pf == R32G32B32A32F);
         IntPoint size = IntPoint(11, 3);
         int numFloats = size.x*size.y*Bitmap::getBytesPerPixel(pf)/sizeof(float);
-        float *pixels = new float[numFloats];
-        fillFloatArray(pixels, numFloats);
-
-        PBOImage pbo(size, pf, pf, false, true);
-        setAndCompareImage(&pbo, pixels, numFloats);
-        delete[] pixels;
-
-    }
-    void runPBOFloatbufTestI32F()
-    {
-        cerr << "    runPBOFloatbufTestI32F" << endl;
-        runPBOFloatbufTest(I32F);
-        return;
+        float* pPixels = new float[numFloats];
+        fillFloatArray(pPixels, numFloats);
     }
 
-    void runPBOFloatbufTestR32G32B32A32F()
-    {
-        cerr << "    runPBOFloatbufTestR32G32B32A32F" << endl;
-        runPBOFloatbufTest(R32G32B32A32F);
-        return;
-    }
     void runPBOFloatBitmapTest(PixelFormat pf)
     {
-        assert(pf == I32F || pf == R32G32B32A32F);
+        cerr << "    Testing PBO float bitmaps (" << Bitmap::getPixelFormatString(pf) 
+                << ")" << endl;
+        AVG_ASSERT(pf == I32F || pf == R32G32B32A32F);
         IntPoint size = IntPoint(5,3);
         int numFloats = size.x*size.y*Bitmap::getBytesPerPixel(pf)/sizeof(float);
-        float *pixels = new float [numFloats];
-        fillFloatArray(pixels, numFloats);
+        float* pPixels = new float [numFloats];
+        fillFloatArray(pPixels, numFloats);
 
         PBOImagePtr pPBO = PBOImagePtr(new PBOImage(size, pf, pf, true, true));
-        BitmapPtr pBmp = BitmapPtr (new Bitmap(size, pf, (unsigned char*)(pixels),
+        BitmapPtr pBmp = BitmapPtr (new Bitmap(size, pf, (unsigned char*)(pPixels),
             size.x*Bitmap::getBytesPerPixel(pf), false));
         pPBO->setImage(pBmp);
         BitmapPtr res = pPBO->getImage();
-        compareFloatArrays(pixels,(float*)res->getPixels(), numFloats);
+        compareFloatArrays(pPixels,(float*)res->getPixels(), numFloats);
 
-        delete[] pixels;
-    }
-
-    void runPBOBitmapTestI32F()
-    {
-        cerr << "    runPBOBitmapTestI32F" << endl;
-        runPBOFloatBitmapTest(I32F);
-        return;
-    }
-    void runPBOBitmapTestR32G32B32A32F()
-    {
-        cerr << "    runPBOBitmapTestR32G32B32A32F" << endl;
-        runPBOFloatBitmapTest(R32G32B32A32F);
-        return;
+        delete[] pPixels;
     }
 
     void runPBOBitmapTestIntFloatExtByte(PixelFormat intPF, PixelFormat extPF)
     {
+        cerr << "    Testing PBO bitmaps (" << Bitmap::getPixelFormatString(intPF) 
+                << "-->" << Bitmap::getPixelFormatString(extPF) << ")" << endl;
         IntPoint size = IntPoint(3,5);
-        unsigned char *pixels = new unsigned char [
+        unsigned char* pPixels = new unsigned char [
             size.x*size.y*Bitmap::getBytesPerPixel(extPF)];
-        fillByteArray(pixels, size.x*size.y*Bitmap::getBytesPerPixel(extPF));
+        fillByteArray(pPixels, size.x*size.y*Bitmap::getBytesPerPixel(extPF));
 
         PBOImagePtr pPBO = PBOImagePtr(new PBOImage(size, intPF, extPF, true, true));
-        BitmapPtr pBmp = BitmapPtr (new Bitmap(size, extPF, pixels,
+        BitmapPtr pBmp = BitmapPtr (new Bitmap(size, extPF, pPixels,
             size.x*Bitmap::getBytesPerPixel(extPF), false));
         pPBO->setImage(pBmp);
         BitmapPtr res = pPBO->getImage();
-        compareByteArrays(pixels, res->getPixels(),
+        compareByteArrays(pPixels, res->getPixels(),
             size.x*size.y*Bitmap::getBytesPerPixel(extPF));
 
-        delete[] pixels;
-    }
-
-    void runPBOBitmapTestR32G32B32A32FextR8G8B8A8()
-    {
-        cerr << "    runPBOFloatbufTestR32G32B32A32FextR8G8B8A8" << endl;
-        runPBOBitmapTestIntFloatExtByte(R32G32B32A32F, R8G8B8A8);
-    }
-    
-    void runPBOBitmapTestI32FextI8()
-    {
-        cerr << "    runPBOBitmapTestI32FextI8" << endl;
-        runPBOBitmapTestIntFloatExtByte(I32F, I8);
+        delete[] pPixels;
     }
 
     void runPBOImageTest(PBOImage& pbo, BitmapPtr pBmp, const string& sFName)
@@ -201,6 +169,40 @@ private:
         testEqual(*pNewBmp, *pBmp, sFName);
     }
 
+};
+*/
+
+class PBOTest: public GraphicsTest {
+public:
+    PBOTest()
+        : GraphicsTest("PBOTest", 2)
+    {
+    }
+
+    void runTests() 
+    {
+        runImageTest("rgb24-64x64");
+        runImageTest("rgb24alpha-64x64");
+    }
+
+private:
+    void runImageTest(const string& sFName)
+    {
+        cerr << "    Testing " << sFName << endl;
+        BitmapPtr pOrigBmp = loadTestBmp(sFName);
+        GLTexturePtr pTex = GLTexturePtr(new GLTexture(pOrigBmp->getSize(), 
+                pOrigBmp->getPixelFormat()));
+        PBOPtr pWritePBO = PBOPtr(new PBO(pOrigBmp->getSize(), pOrigBmp->getPixelFormat(),
+                GL_DYNAMIC_DRAW));
+        TEST(!pWritePBO->isReadPBO());
+        pWritePBO->moveBmpToTexture(pOrigBmp, pTex);
+        PBOPtr pReadPBO = PBOPtr(new PBO(pOrigBmp->getSize(), pOrigBmp->getPixelFormat(), 
+                GL_DYNAMIC_READ));
+        TEST(pReadPBO->isReadPBO());
+        BitmapPtr pDestBmp = pReadPBO->moveTextureToBmp(pTex);
+        testEqual(*pDestBmp, *pOrigBmp, "pbo", 0.01, 0.1);
+    }
+
 };
 
 class BrightnessFilterTest: public GraphicsTest {
@@ -222,11 +224,47 @@ private:
         cerr << "    Testing " << sFName << endl;
         BitmapPtr pBmp = loadTestBmp(sFName);
         BitmapPtr pDestBmp;
-        pDestBmp = GPUBrightnessFilter(pBmp->getSize(), pBmp->getPixelFormat(), 1).apply(pBmp);
+        pDestBmp = GPUBrightnessFilter(pBmp->getSize(), pBmp->getPixelFormat(), 1)
+                .apply(pBmp);
         testEqual(*pDestBmp, *pBmp, string("brightness_")+sFName, 0.2, 0.5);
     }
 };
 
+class ChromaKeyFilterTest: public GraphicsTest {
+public:
+    ChromaKeyFilterTest()
+        : GraphicsTest("ChromaKeyFilterTest", 2)
+    {
+    }
+
+    void runTests()
+    {
+        BitmapPtr pBmp = loadTestBmp("chromakey");
+        BitmapPtr pDestBmp;
+        GPUChromaKeyFilter filter(pBmp->getSize(), pBmp->getPixelFormat());
+        for (int erosion = 0; erosion < 3; ++erosion) {
+            filter.setParams(Pixel32(0,255,0), 0.1, 0.2, 0.1, 0.1, erosion, 0);
+            pDestBmp = filter.apply(pBmp);
+            testEqual(*pDestBmp, "ChromaKeyResult"+toString(erosion), R8G8B8X8, 0.3, 
+                    0.7);
+        }
+        filter.setParams(Pixel32(0,255,0), 0.0, 0.0, 0.0, 0.0, 0, 0.1);
+        pDestBmp = filter.apply(pBmp);
+        testEqual(*pDestBmp, "ChromaKeySpillResult1", R8G8B8X8, 0.3, 0.7);
+        filter.setParams(Pixel32(0,255,0), 0.1, 0.1, 0.1, 0.0, 0, 0.1);
+        pDestBmp = filter.apply(pBmp);
+        testEqual(*pDestBmp, "ChromaKeySpillResult2", R8G8B8X8, 0.3, 0.7);
+        filter.setParams(Pixel32(0,255,0), 0.1, 0.1, 0.1, 0.0, 0, 0.2);
+        pDestBmp = filter.apply(pBmp);
+        testEqual(*pDestBmp, "ChromaKeySpillResult3", R8G8B8X8, 0.3, 0.7);
+
+        pBmp = loadTestBmp("chromakey-median");
+        filter.setParams(Pixel32(0,255,0), 0.1, 0.1, 0.1, 0.0, 0, 0.0);
+        pDestBmp = filter.apply(pBmp);
+        testEqual(*pDestBmp, "ChromaKeyMedianResult", R8G8B8X8, 1, 6);
+    }
+};
+
 class BlurFilterTest: public GraphicsTest {
 public:
     BlurFilterTest()
@@ -239,31 +277,36 @@ public:
         BitmapPtr pBmp;
         BitmapPtr pDestBmp;
 /*
-        // This has the effect of printing out all the brightness differences for different
-        // kernel sizes.
+        // This has the effect of printing out all the brightness differences for
+        //different kernel sizes.
         pBmp = loadTestBmp("spike");
         for (double stddev = 0.5; stddev < 5; stddev += 0.25) {
-            pDestBmp = GPUBlurFilter(pBmp->getSize(), pBmp->getPixelFormat(), stddev).apply(pBmp);
+            pDestBmp = GPUBlurFilter(pBmp->getSize(), pBmp->getPixelFormat(), stddev)
+                    .apply(pBmp);
             testEqualBrightness(*pDestBmp, *pBmp, 1);
         }
 */
         cerr << "    Testing spike, stddev 0.5" << endl;
         pBmp = loadTestBmp("spike");
-        pDestBmp = GPUBlurFilter(pBmp->getSize(), pBmp->getPixelFormat(), 0.5).apply(pBmp);
+        pDestBmp = GPUBlurFilter(pBmp->getSize(), pBmp->getPixelFormat(), R32G32B32A32F,
+                0.5).apply(pBmp);
         testEqualBrightness(*pDestBmp, *pBmp, 0.0004);
         testEqual(*pDestBmp, "blur05_spike", B8G8R8X8, 0.01, 0.1);
         cerr << "    Testing spike, stddev 1" << endl;
-        pDestBmp = GPUBlurFilter(pBmp->getSize(), pBmp->getPixelFormat(), 1).apply(pBmp);
+        pDestBmp = GPUBlurFilter(pBmp->getSize(), pBmp->getPixelFormat(), R32G32B32A32F,
+                1).apply(pBmp);
 //        testEqualBrightness(*pDestBmp, *pBmp, 5);
         testEqual(*pDestBmp, "blur1_spike", B8G8R8X8, 0.01, 0.1);
         cerr << "    Testing spike, stddev 3" << endl;
-        pDestBmp = GPUBlurFilter(pBmp->getSize(), pBmp->getPixelFormat(), 3).apply(pBmp);
+        pDestBmp = GPUBlurFilter(pBmp->getSize(), pBmp->getPixelFormat(), R32G32B32A32F,
+                3).apply(pBmp);
 //        testEqualBrightness(*pDestBmp, *pBmp, 5);
         testEqual(*pDestBmp, "blur5_spike", B8G8R8X8, 0.01, 0.1);
 
         cerr << "    Testing flat, stddev 5" << endl;
         pBmp = loadTestBmp("flat");
-        pDestBmp = GPUBlurFilter(pBmp->getSize(), pBmp->getPixelFormat(), 5).apply(pBmp);
+        pDestBmp = GPUBlurFilter(pBmp->getSize(), pBmp->getPixelFormat(), R32G32B32A32F,
+                5).apply(pBmp);
         testEqualBrightness(*pDestBmp, *pBmp, 1);
         testEqual(*pDestBmp, *pBmp, "blur05_flat");
 
@@ -277,7 +320,8 @@ private:
         cerr << "    Testing " << sFName << endl;
         BitmapPtr pBmp = loadTestBmp(sFName);
         BitmapPtr pDestBmp;
-        pDestBmp = GPUBlurFilter(pBmp->getSize(), pBmp->getPixelFormat(), 10).apply(pBmp);
+        pDestBmp = GPUBlurFilter(pBmp->getSize(), pBmp->getPixelFormat(), R32G32B32A32F,
+                10).apply(pBmp);
         testEqual(*pDestBmp, string("blur_")+sFName, pBmp->getPixelFormat(), 0.2, 0.5);
     }
 };
@@ -302,7 +346,6 @@ private:
         BitmapPtr pBmp = loadTestBmp(sFName, pf);
         GPUBandpassFilter f(pBmp->getSize(), pf, 0.5, 1.5, 1, false);
         BitmapPtr pDestBmp = f.apply(pBmp);
-        cerr << "        " << pDestBmp->getAvg() << endl;
         TEST(fabs(pDestBmp->getAvg() -128) < 0.06);
         testEqual(*pDestBmp, "bandpass_"+sFName, pf, 0.2, 0.5);
         TEST(pDestBmp->getPixelFormat() == pf);
@@ -310,74 +353,21 @@ private:
 };
 
 
-class IteratingGPUTestFilter: public IteratingGPUFilter 
-{
-public:
-    IteratingGPUTestFilter(const IntPoint& size)
-        : IteratingGPUFilter(size, 1)
-    {
-        if (!s_pShader) {
-            initShader();
-        }
-    }
-
-protected:
-    void initShader()
-    {
-        string sCode =
-            "#extension GL_ARB_texture_rectangle : enable\n" 
-            "uniform sampler2DRect Texture;\n"
-            "void main(void)\n"
-            "{\n"
-            "    gl_FragColor = texture2DRect(Texture,\n"
-            "           vec2(gl_TexCoord[0].s, gl_TexCoord[0].t-10.0));\n"
-            "}\n";
-        s_pShader = OGLShaderPtr(new OGLShader(sCode));
-    }
-
-    void applyOnce(PBOImagePtr pSrc)
-    {
-        s_pShader->activate();
-        s_pShader->setUniformIntParam("Texture", 0);
-        pSrc->draw();
-    }
-
-private:
-    OGLShaderPtr s_pShader;
-};
-
-
-class IteratingGPUFilterTest: public GraphicsTest {
-public:
-    IteratingGPUFilterTest()
-        : GraphicsTest("IteratingGPUFilterTest", 2)
-    {
-    }
-
-    void runTests() 
-    {
-        BitmapPtr pBmp = loadTestBmp("spike", R8G8B8A8);
-        BitmapPtr pSrcBmp(new Bitmap(pBmp->getSize(), R32G32B32A32F));
-        pSrcBmp->copyPixels(*pBmp); 
-        IteratingGPUTestFilter f(pBmp->getSize());
-        BitmapPtr pDestBmp = f.apply(pSrcBmp);
-        BitmapPtr pByteDestBmp(new Bitmap(pBmp->getSize(), R8G8B8A8));
-        pByteDestBmp->copyPixels(*pDestBmp);
-        testEqual(*pByteDestBmp, "iteratingGPUFilter", R8G8B8A8);
-    }
-};
-
-
 class GPUTestSuite: public TestSuite {
 public:
     GPUTestSuite() 
         : TestSuite("GPUTestSuite")
     {
-        addTest(TestPtr(new FBOTest));
+        addTest(TestPtr(new PBOTest));
         addTest(TestPtr(new BrightnessFilterTest));
-        addTest(TestPtr(new BlurFilterTest));
-        addTest(TestPtr(new BandpassFilterTest));
-        addTest(TestPtr(new IteratingGPUFilterTest));
+        if (GLTexture::isFloatFormatSupported()) {
+            addTest(TestPtr(new ChromaKeyFilterTest));
+            addTest(TestPtr(new BlurFilterTest));
+            addTest(TestPtr(new BandpassFilterTest));
+        } else {
+            cerr << "Skipping some GPU tests since float textures are not supported by "
+                    << endl << "the OpenGL configuration." << endl;
+        }
     }
 };
 
@@ -386,15 +376,15 @@ int main(int nargs, char** args)
 {
     bool bOK = true;
     try {
-        OGLImagingContext context(IntPoint(64, 64));
+        OGLImagingContext context;
         try {
             if (!queryOGLExtension("GL_ARB_fragment_shader")) {
                 throw Exception(AVG_ERR_UNSUPPORTED, 
                         "Fragment shaders not supported on this Machine. ");
             }
-            GPUTestSuite Suite;
-            Suite.runTests();
-            bOK = Suite.isOk();
+            GPUTestSuite suite;
+            suite.runTests();
+            bOK = suite.isOk();
         } catch (Exception& ex) {
             cerr << "Exception: " << ex.GetStr() << endl;
         }
