@@ -32,7 +32,6 @@
 
 #include "../base/Point.h"
 
-#include <assert.h>
 #include <vector>
 
 #include <boost/shared_ptr.hpp>
@@ -51,10 +50,10 @@ typedef std::vector<IntPoint> ContourSeq;
 class AVG_API Blob
 {
     public:
-        Blob(const Run & run);
+        Blob(const Run& run);
         ~Blob();
 
-        void addRun(const Run & run);
+        void addRun(const Run& run);
         void merge(const BlobPtr& other);
         RunArray* getRuns();
         void render(BitmapPtr pSrcBmp, BitmapPtr pDestBmp, Pixel32 Color, 
@@ -113,7 +112,8 @@ class AVG_API Blob
         ContourSeq m_Contour;
 };
 
-BlobVectorPtr findConnectedComponents(BitmapPtr image, unsigned char object_threshold);
+BlobVectorPtr AVG_API findConnectedComponents(BitmapPtr pBmp, 
+        unsigned char threshold);
 
 }
 
