@@ -55,8 +55,8 @@ Camera::Camera(PixelFormat camPF, PixelFormat destPF)
     : m_CamPF(camPF),
       m_DestPF(destPF)
 {
-//    cerr << "Camera: " << Bitmap::getPixelFormatString(camPF) << "-->" 
-//        << Bitmap::getPixelFormatString(destPF) << endl;
+//    cerr << "Camera: " << getPixelFormatString(camPF) << "-->" 
+//        << getPixelFormatString(destPF) << endl;
 }
 
 PixelFormat Camera::getCamPF() const
@@ -74,7 +74,7 @@ PixelFormat Camera::getDestPF() const
     return m_DestPF;
 }
 
-static ProfilingZone CameraConvertProfilingZone("Camera format conversion");
+static ProfilingZoneID CameraConvertProfilingZone("Camera format conversion");
 
 BitmapPtr Camera::convertCamFrameToDestPF(BitmapPtr pCamBmp)
 {
@@ -103,20 +103,14 @@ PixelFormat Camera::fwBayerStringToPF(unsigned long reg)
     } else if (sBayerFormat == "YYYY") {
         return I8;
     } else {
-        assert(false);
+        AVG_ASSERT(false);
         return I8;
     }
+}
 
-}
-/*
-void Camera::fatalError(const string & sMsg)
+string cameraFeatureToString(CameraFeature feature)
 {
-    throw Exception(AVG_ERR_CAMERA, sMsg);
-}
-*/
-string cameraFeatureToString(CameraFeature Feature)
-{
-    switch(Feature) {
+    switch (feature) {
         case CAM_FEATURE_BRIGHTNESS:
             return "brightness";
         case CAM_FEATURE_EXPOSURE:
@@ -188,13 +182,14 @@ CameraPtr createCamera(const string& sDriver, const string& sDevice, int unit,
             pCamera = CameraPtr(new CMUCamera(guid, bFW800, captureSize, camPF, destPF, 
                     frameRate));
 #else
+            guid = 0; // Silence compiler warning
             AVG_TRACE(Logger::WARNING, "Firewire camera specified, but firewire "
                     "support not compiled in.");
 #endif
         } else if (sDriver == "video4linux") {
 #if defined(AVG_ENABLE_V4L2)
             pCamera = CameraPtr(new V4LCamera(sDevice, unit, captureSize, camPF, 
-                    destPF));
+                    destPF, frameRate));
 #else
             AVG_TRACE(Logger::WARNING, "Video4Linux camera specified, but "
                     "Video4Linux support not compiled in.");
@@ -215,7 +210,7 @@ CameraPtr createCamera(const string& sDriver, const string& sDevice, int unit,
             throw Exception(AVG_ERR_INVALID_ARGS,
                     "Unable to set up camera. Camera source '"+sDriver+"' unknown.");
         }
-    } catch (const Exception &e) {
+    } catch (const Exception& e) {
         if (e.GetCode() == AVG_ERR_CAMERA_NONFATAL) {
             AVG_TRACE(Logger::WARNING, e.GetStr());
         } else {
@@ -223,7 +218,7 @@ CameraPtr createCamera(const string& sDriver, const string& sDevice, int unit,
         }
 
     }
-    if (!pCamera){
+    if (!pCamera) {
         pCamera = CameraPtr(new FakeCamera(camPF, destPF));
     }
     return pCamera;
