@@ -25,12 +25,11 @@
 #include "KsMedia.h"
 
 #include "../base/Logger.h"
+#include "../base/Exception.h"
 #include "../base/ScopeTimer.h"
-#include "../base/TimeSource.h"
 #include "../graphics/FilterFlip.h"
 #include "../graphics/Filtergrayscale.h"
 
-#include <assert.h>
 #include <oleauto.h>
 
 #include <math.h>
@@ -134,13 +133,17 @@ void DSCamera::open()
 
 void DSCamera::close()
 {
-    m_pAMCameraControl->Release();
+    if (m_pAMCameraControl) {
+        m_pAMCameraControl->Release();
+    }
     m_pMediaControl->Stop();
     RemoveGraphFromRot(m_GraphRegisterID);
     m_pGraph->Release();
     m_pCapture->Release();
     m_pMediaControl->Release();
-    m_pCameraPropControl->Release();
+    if (m_pCameraPropControl) {
+        m_pCameraPropControl->Release();
+    }
     m_pSrcFilter->Release();
     m_pGrabFilter->Release();
     m_pSampleGrabber->Release();
@@ -188,7 +191,7 @@ bool DSCamera::selectMediaType(bool bColor, bool bForce)
     hr = pSC->GetNumberOfCapabilities(&Count, &Size);
     checkForDShowError(hr, "DSCamera::dumpMediaTypes::GetNumberOfCapabilities");
 
-    assert(Size == sizeof(VIDEO_STREAM_CONFIG_CAPS));
+    AVG_ASSERT(Size == sizeof(VIDEO_STREAM_CONFIG_CAPS));
     bool bFormatFound = false;
     bool bCloseFormatFound = false;
     AM_MEDIA_TYPE *pmtConfig;
@@ -553,7 +556,7 @@ void DSCamera::getUnconnectedPin(IBaseFilter *pFilter, PIN_DIRECTION PinDir, IPi
     }
     pEnum->Release();
     // Did not find a matching pin.
-    assert(false);
+    AVG_ASSERT(false);
 }
 
 #pragma warning(disable : 4995)
