@@ -61,29 +61,28 @@ DeDistort::DeDistort()
     m_RescaleFactor = calc_rescale();
 }
 
-DeDistort::DeDistort(const DPoint& CamExtents, const DPoint& DisplayExtents)
+DeDistort::DeDistort(const DPoint& camExtents, const DPoint& displayExtents)
     : m_Angle(0.0),
       m_TrapezoidFactor(0),
       m_DisplayOffset(0,0)
 {
-    m_CamExtents = CamExtents; 
+    m_CamExtents = camExtents; 
     m_DistortionParams.push_back(0);
     m_DistortionParams.push_back(0);
-    m_DisplayScale.x = DisplayExtents.x/CamExtents.x;
-    m_DisplayScale.y = DisplayExtents.y/CamExtents.y;
+    m_DisplayScale.x = displayExtents.x/camExtents.x;
+    m_DisplayScale.y = displayExtents.y/camExtents.y;
     m_RescaleFactor = calc_rescale();
 }
 
-DeDistort::DeDistort(const DPoint &CamExtents,
-        const std::vector<double>& DistortionParams,
-        double Angle, double TrapezoidFactor,
-        const DPoint& DisplayOffset, const DPoint& DisplayScale)
-    : m_CamExtents(CamExtents),
-      m_DistortionParams(DistortionParams),
-      m_Angle(Angle),
-      m_TrapezoidFactor(TrapezoidFactor),
-      m_DisplayOffset(DisplayOffset),
-      m_DisplayScale(DisplayScale)
+DeDistort::DeDistort(const DPoint& camExtents, const vector<double>& distortionParams,
+        double angle, double trapezoidFactor, const DPoint& displayOffset, 
+        const DPoint& displayScale)
+    : m_CamExtents(camExtents),
+      m_DistortionParams(distortionParams),
+      m_Angle(angle),
+      m_TrapezoidFactor(trapezoidFactor),
+      m_DisplayOffset(displayOffset),
+      m_DisplayScale(displayScale)
 {
     m_RescaleFactor = calc_rescale();
 }
@@ -92,69 +91,74 @@ DeDistort::~DeDistort()
 {
 }
 
-DRect DeDistort::getActiveBlobArea(const DPoint& DisplayExtents)
+DRect DeDistort::getDisplayArea(const DPoint& displayExtents)
 {
-    DRect ActiveRect;
-    ActiveRect.tl = transformScreenToBlob(DPoint(0, 0));
-    ActiveRect.br = transformScreenToBlob(DPoint(DisplayExtents.x, DisplayExtents.y));
-    if (ActiveRect.height() < 1) {
-        double temp = ActiveRect.tl.y;
-        ActiveRect.tl.y = ActiveRect.br.y;
-        ActiveRect.br.y = temp;
-    } 
-    if (ActiveRect.width() < 1) {
-        double temp = ActiveRect.tl.x;
-        ActiveRect.tl.x = ActiveRect.br.x;
-        ActiveRect.br.x = temp;
-    } 
-    return ActiveRect;
+    return getActiveBlobArea(DRect(DPoint(0,0), displayExtents));
 }
 
-void DeDistort::load(const DPoint &CameraExtents, const TrackerConfig& Config)
+DRect DeDistort::getActiveBlobArea(const DRect& displayROI)
 {
-    m_CamExtents = CameraExtents;
+    DRect activeRect;
+    activeRect.tl = transformScreenToBlob(DPoint(displayROI.tl));
+    activeRect.br = transformScreenToBlob(DPoint(displayROI.br));
+    if (activeRect.height() < 1) {
+        double temp = activeRect.tl.y;
+        activeRect.tl.y = activeRect.br.y;
+        activeRect.br.y = temp;
+    } 
+    if (activeRect.width() < 1) {
+        double temp = activeRect.tl.x;
+        activeRect.tl.x = activeRect.br.x;
+        activeRect.br.x = temp;
+    } 
+    return activeRect;
+}
+
+void DeDistort::load(const DPoint& camExtents, const TrackerConfig& config)
+{
+    m_CamExtents = camExtents;
     m_DistortionParams.clear();
-    m_DistortionParams.push_back(Config.getDoubleParam
+    m_DistortionParams.push_back(config.getDoubleParam
             ("/transform/distortionparams/@p2"));
-    m_DistortionParams.push_back(Config.getDoubleParam
+    m_DistortionParams.push_back(config.getDoubleParam
             ("/transform/distortionparams/@p3"));
-    m_TrapezoidFactor = Config.getDoubleParam("/transform/trapezoid/@value");
-    m_Angle = Config.getDoubleParam("/transform/angle/@value");
-    m_DisplayOffset = Config.getPointParam("/transform/displaydisplacement/");
-    m_DisplayScale = Config.getPointParam("/transform/displayscale/");
+    m_TrapezoidFactor = config.getDoubleParam("/transform/trapezoid/@value");
+    m_Angle = config.getDoubleParam("/transform/angle/@value");
+    m_DisplayOffset = config.getPointParam("/transform/displaydisplacement/");
+    m_DisplayScale = config.getPointParam("/transform/displayscale/");
 
     m_RescaleFactor = calc_rescale();
 }
 
-void DeDistort::save(TrackerConfig& Config)
+void DeDistort::save(TrackerConfig& config)
 {
-    Config.setParam("/transform/distortionparams/@p2", 
+    config.setParam("/transform/distortionparams/@p2", 
             toString(m_DistortionParams[0]));
-    Config.setParam("/transform/distortionparams/@p3", 
+    config.setParam("/transform/distortionparams/@p3", 
             toString(m_DistortionParams[1]));
-    Config.setParam("/transform/trapezoid/@value", 
+    config.setParam("/transform/trapezoid/@value", 
             toString(m_TrapezoidFactor));
-    Config.setParam("/transform/angle/@value", 
+    config.setParam("/transform/angle/@value", 
             toString(m_Angle));
-    Config.setParam("/transform/displaydisplacement/@x", 
+    config.setParam("/transform/displaydisplacement/@x", 
             toString(m_DisplayOffset.x));
-    Config.setParam("/transform/displaydisplacement/@y", 
+    config.setParam("/transform/displaydisplacement/@y", 
             toString(m_DisplayOffset.y));
-    Config.setParam("/transform/displayscale/@x", 
+    config.setParam("/transform/displayscale/@x", 
             toString(m_DisplayScale.x));
-    Config.setParam("/transform/displayscale/@y", 
+    config.setParam("/transform/displayscale/@y", 
             toString(m_DisplayScale.y));
 }
 
 bool DeDistort::operator ==(const DeDistort& other) const
 {
     return (m_CamExtents == other.m_CamExtents &&
-        m_DistortionParams == other.m_DistortionParams &&
-        m_Angle == other.m_Angle &&
-        m_TrapezoidFactor == other.m_TrapezoidFactor &&
-        m_DisplayOffset == other.m_DisplayOffset &&
-        m_DisplayScale == other.m_DisplayScale &&
-        m_RescaleFactor == other.m_RescaleFactor);
+            m_DistortionParams == other.m_DistortionParams &&
+            m_Angle == other.m_Angle &&
+            m_TrapezoidFactor == other.m_TrapezoidFactor &&
+            m_DisplayOffset == other.m_DisplayOffset &&
+            m_DisplayScale == other.m_DisplayScale &&
+            m_RescaleFactor == other.m_RescaleFactor);
 }
         
 void DeDistort::dump() const
@@ -169,7 +173,7 @@ void DeDistort::dump() const
     cerr << "    DisplayScale: " << m_DisplayScale << endl;
 }
 
-DPoint DeDistort::transformScreenToBlob(const DPoint &pt)
+DPoint DeDistort::transformScreenToBlob(const DPoint& pt)
 {
     // scale to blob image resolution and translate 0,0 to upper left corner.
     DPoint DestPt = pt-m_DisplayOffset;
@@ -177,54 +181,54 @@ DPoint DeDistort::transformScreenToBlob(const DPoint &pt)
     return DestPt;
 }
 
-DPoint DeDistort::inverse_transform_point(const DPoint &pt)
+DPoint DeDistort::inverse_transform_point(const DPoint& pt)
 {
-    DPoint DestPt = pt-m_CamExtents/2;
-    DestPt = DPoint(2*DestPt.x/m_CamExtents.x, 2*DestPt.y/m_CamExtents.y);
-    DestPt = inv_trapezoid(m_TrapezoidFactor, DestPt);
-    DestPt = DestPt.getRotated(-m_Angle);
-    DestPt *= m_RescaleFactor;
-    DestPt = inverse_undistort(m_DistortionParams, DestPt);
-    DestPt = DPoint(DestPt.x*m_CamExtents.x/2, DestPt.y*m_CamExtents.y/2);
-    DestPt += m_CamExtents/2;
-    return DestPt;
+    DPoint destPt = pt-m_CamExtents/2;
+    destPt = DPoint(2*destPt.x/m_CamExtents.x, 2*destPt.y/m_CamExtents.y);
+    destPt = inv_trapezoid(m_TrapezoidFactor, destPt);
+    destPt = destPt.getRotated(-m_Angle);
+    destPt *= m_RescaleFactor;
+    destPt = inverse_undistort(m_DistortionParams, destPt);
+    destPt = DPoint(destPt.x*m_CamExtents.x/2, destPt.y*m_CamExtents.y/2);
+    destPt += m_CamExtents/2;
+    return destPt;
 }
 
-DPoint DeDistort::transformBlobToScreen(const DPoint &pt)
+DPoint DeDistort::transformBlobToScreen(const DPoint& pt)
 {
-    DPoint DestPt = DPoint(m_DisplayScale.x*pt.x, m_DisplayScale.y*pt.y);
-    DestPt += m_DisplayOffset;
-    return DestPt;
+    DPoint destPt = DPoint(m_DisplayScale.x*pt.x, m_DisplayScale.y*pt.y);
+    destPt += m_DisplayOffset;
+    return destPt;
 }
 
-DPoint DeDistort::transform_point(const DPoint &pt)
+DPoint DeDistort::transform_point(const DPoint& pt)
 {
-    DPoint DestPt = pt-m_CamExtents/2;
-    DestPt = DPoint(2*DestPt.x/m_CamExtents.x, 2*DestPt.y/m_CamExtents.y);
-    DestPt = undistort(m_DistortionParams, DestPt);
-    DestPt /= m_RescaleFactor;
-    DestPt = DestPt.getRotated(m_Angle);
-    DestPt = trapezoid(m_TrapezoidFactor, DestPt);
-    DestPt = DPoint(DestPt.x*m_CamExtents.x/2, DestPt.y*m_CamExtents.y/2);
-    DestPt += m_CamExtents/2;
-    return DestPt;
+    DPoint destPt = pt-m_CamExtents/2;
+    destPt = DPoint(2*destPt.x/m_CamExtents.x, 2*destPt.y/m_CamExtents.y);
+    destPt = undistort(m_DistortionParams, destPt);
+    destPt /= m_RescaleFactor;
+    destPt = destPt.getRotated(m_Angle);
+    destPt = trapezoid(m_TrapezoidFactor, destPt);
+    destPt = DPoint(destPt.x*m_CamExtents.x/2, destPt.y*m_CamExtents.y/2);
+    destPt += m_CamExtents/2;
+    return destPt;
 }
 
-DPoint DeDistort::inv_trapezoid(const double trapezoid_factor, const DPoint &pt)
+DPoint DeDistort::inv_trapezoid(const double trapezoid_factor, const DPoint& pt)
 {
-    //stretch x coord
+    // stretch x coord
     double yn = pt.y;
     return DPoint(pt.x/(1+yn*trapezoid_factor), pt.y);
 }
 
-DPoint DeDistort::trapezoid(const double trapezoid_factor, const DPoint &pt)
+DPoint DeDistort::trapezoid(const double trapezoid_factor, const DPoint& pt)
 {
-    //stretch x coord
+    // stretch x coord
     double yn = pt.y;
-    return DPoint(pt.x * (1 + yn*trapezoid_factor), pt.y);
+    return DPoint(pt.x*(1+yn*trapezoid_factor), pt.y);
 }
 
-double distort_map(const std::vector<double> &params, double r) 
+double distort_map(const vector<double>& params, double r) 
 {
     double S = 0;
     int counter = 2;
@@ -243,27 +247,27 @@ double DeDistort::calc_rescale()
     return scale/sqrt(2.0);
 }
 
-double inv_distort_map(const std::vector<double> &params, double r) 
+double inv_distort_map(const vector<double>& params, double r) 
 {
-        double r1,r2,r3,f1,f2;
-        r1 = r;
-        r2 = r+.001;
-        f1 = distort_map(params, r1)-r;
+    double r1,r2,r3,f1,f2;
+    r1 = r;
+    r2 = r+.001;
+    f1 = distort_map(params, r1)-r;
+    f2 = distort_map(params, r2)-r;
+    while (fabs(f2) > 0.0001) {
+        r3 = (r1*f2-r2*f1)/(f2-f1);
+        r1 = r2;
+        r2 = r3;
+        f1 = f2;
         f2 = distort_map(params, r2)-r;
-        while (fabs(f2) > 0.0001) {
-            r3 = (r1*f2-r2*f1)/(f2-f1);
-            r1 = r2;
-            r2 = r3;
-            f1 = f2;
-            f2 = distort_map(params, r2)-r;
-        }
-        return r2;
+    }
+    return r2;
 }
 
 #define EPSILON 0.00001
-DPoint DeDistort::inverse_undistort(const std::vector<double> &params, const DPoint &pt)
+DPoint DeDistort::inverse_undistort(const vector<double> &params, const DPoint &pt)
 {
-    if ( params.empty() ) {
+    if (params.empty()) {
         return pt;
     }
     DPoint pt_norm = pt;
@@ -278,10 +282,10 @@ DPoint DeDistort::inverse_undistort(const std::vector<double> &params, const DPo
     return result;
 }
 
-DPoint DeDistort::undistort(const std::vector<double> &params, const DPoint &pt) 
+DPoint DeDistort::undistort(const vector<double>& params, const DPoint &pt) 
 {
     std::vector<double>::const_iterator v = params.begin();
-    if ( v == params.end() ) {
+    if (v == params.end()) {
         return pt;
     }
     DPoint pt_norm = pt;
