@@ -25,8 +25,8 @@
 #endif
 
 #include "../base/Logger.h"
+#include "../base/Exception.h"
 #include "../base/ScopeTimer.h"
-#include "../base/TimeSource.h"
 #include "../base/StringHelper.h"
 
 #include <sstream>
@@ -36,17 +36,17 @@ namespace avg {
 
 using namespace std;
 
-FWCamera::FWCamera(uint64_t guid, int unit, bool bFW800, IntPoint Size, 
-        PixelFormat camPF, PixelFormat destPF, double FrameRate)
+FWCamera::FWCamera(uint64_t guid, int unit, bool bFW800, IntPoint size, 
+        PixelFormat camPF, PixelFormat destPF, double frameRate)
     : Camera(camPF, destPF),
-      m_Size(Size),
-      m_FrameRate(FrameRate),
+      m_Size(size),
+      m_FrameRate(frameRate),
       m_WhitebalanceU(-1),
       m_WhitebalanceV(-1)
 {
 #ifdef AVG_ENABLE_1394_2
     m_FrameRateConstant = getFrameRateConst(m_FrameRate);
-    m_Mode = getCamMode(Size, camPF);
+    m_Mode = getCamMode(size, camPF);
     dc1394camera_list_t * pCameraList;
 
     m_pDC1394 = dc1394_new();
@@ -54,16 +54,16 @@ FWCamera::FWCamera(uint64_t guid, int unit, bool bFW800, IntPoint Size,
         throw Exception(AVG_ERR_CAMERA_NONFATAL, 
                 "Failed to initialize firewire subsystem");
     }
-    int err=dc1394_camera_enumerate(m_pDC1394, &pCameraList);
+    int err = dc1394_camera_enumerate(m_pDC1394, &pCameraList);
 
     if (err != DC1394_SUCCESS) {
         AVG_TRACE(Logger::ERROR, "Unable to look for cameras");
 #ifdef linux
         AVG_TRACE(Logger::ERROR, "Please check");
         AVG_TRACE(Logger::ERROR,
-                "  - if the kernel modules `ieee1394',`raw1394' and `ohci1394' are loaded");
+              "  - if the kernel modules `ieee1394',`raw1394' and `ohci1394' are loaded");
         AVG_TRACE(Logger::ERROR,
-                "  - if you have read/write access to /dev/raw1394.");
+              "  - if you have read/write access to /dev/raw1394.");
 #endif
         dc1394_free(m_pDC1394);
         throw Exception(AVG_ERR_CAMERA_NONFATAL,"Firewire failure");
@@ -76,7 +76,7 @@ FWCamera::FWCamera(uint64_t guid, int unit, bool bFW800, IntPoint Size,
     }
     int id_to_use = -1;
     if (guid != 0) {
-        for (unsigned i=0; i<pCameraList->num;++i) {
+        for (unsigned i = 0; i < pCameraList->num; ++i) {
             if (pCameraList->ids[i].guid == guid) {
                 id_to_use = i;
             }       
@@ -110,16 +110,16 @@ FWCamera::FWCamera(uint64_t guid, int unit, bool bFW800, IntPoint Size,
     } else {
         err = dc1394_video_set_iso_speed(m_pCamera, DC1394_ISO_SPEED_400);
     }
-    assert(err == DC1394_SUCCESS);
+    AVG_ASSERT(err == DC1394_SUCCESS);
     err = dc1394_video_set_mode(m_pCamera, m_Mode);
-    assert(err == DC1394_SUCCESS);
+    AVG_ASSERT(err == DC1394_SUCCESS);
 
-    dc1394framerates_t FrameRates;
-    err = dc1394_video_get_supported_framerates(m_pCamera, m_Mode, &FrameRates);
-    assert(err == DC1394_SUCCESS);
+    dc1394framerates_t frameRates;
+    err = dc1394_video_get_supported_framerates(m_pCamera, m_Mode, &frameRates);
+    AVG_ASSERT(err == DC1394_SUCCESS);
     bool bFrameRateSupported = false;
-    for (unsigned int i=0; i<FrameRates.num; i++) {
-        if (FrameRates.framerates[i] == m_FrameRateConstant) {
+    for (unsigned int i = 0; i < frameRates.num; i++) {
+        if (frameRates.framerates[i] == m_FrameRateConstant) {
             bFrameRateSupported = true;
             break;
         }
@@ -137,7 +137,7 @@ FWCamera::FWCamera(uint64_t guid, int unit, bool bFW800, IntPoint Size,
     }
 
     err = dc1394_video_set_framerate(m_pCamera, m_FrameRateConstant);
-    assert(err == DC1394_SUCCESS);
+    AVG_ASSERT(err == DC1394_SUCCESS);
 
     err = dc1394_capture_setup(m_pCamera,8, DC1394_CAPTURE_FLAGS_DEFAULT);
     if (err != DC1394_SUCCESS) {
@@ -152,19 +152,19 @@ FWCamera::FWCamera(uint64_t guid, int unit, bool bFW800, IntPoint Size,
         throw Exception(AVG_ERR_CAMERA_NONFATAL, "Failed to initialize camera");
     }
     err = dc1394_video_set_transmission(m_pCamera, DC1394_ON);
-    assert(err == DC1394_SUCCESS);
+    AVG_ASSERT(err == DC1394_SUCCESS);
 
     dc1394switch_t status = DC1394_OFF;
 
     int i = 0;
-    while( status == DC1394_OFF && i++ < 5 ) {
+    while (status == DC1394_OFF && i++ < 5) {
         usleep(50000);
         err = dc1394_video_get_transmission(m_pCamera, &status);
-        assert(err == DC1394_SUCCESS);
+        AVG_ASSERT(err == DC1394_SUCCESS);
     }
 
-    if( i == 5 ) {
-        assert(false);
+    if (i == 5) {
+        AVG_ASSERT(false);
     }
     // Default to turning off any camera sharpness manipulation.
     setFeature(CAM_FEATURE_SHARPNESS, 0);
@@ -181,15 +181,17 @@ FWCamera::FWCamera(uint64_t guid, int unit, bool bFW800, IntPoint Size,
     
     if (camPF == BAYER8) {
         if (strcmp(m_pCamera->model, "DFx 31BF03") == 0) {
-            AVG_TRACE(Logger::CONFIG, "Applying bayer pattern fixup for IS DFx31BF03 camera");
+            AVG_TRACE(Logger::CONFIG,
+                    "Applying bayer pattern fixup for IS DFx31BF03 camera");
             setCamPF(BAYER8_GRBG);
         } else if (strcmp(m_pCamera->vendor, "Point Grey Research") == 0) {
-            AVG_TRACE(Logger::CONFIG, "Applying bayer pattern fixup for PointGrey cameras");
+            AVG_TRACE(Logger::CONFIG,
+                    "Applying bayer pattern fixup for PointGrey cameras");
             enablePtGreyBayer();
         }
     }
 #else
-    assert(false);
+    AVG_ASSERT(false);
 #endif
 }
 
@@ -214,7 +216,7 @@ IntPoint FWCamera::getImgSize()
 }
 
 
-static ProfilingZone CameraConvertProfilingZone("FW Camera format conversion");
+static ProfilingZoneID CameraConvertProfilingZone("FW Camera format conversion");
 
 BitmapPtr FWCamera::getImage(bool bWait)
 {
@@ -242,8 +244,8 @@ BitmapPtr FWCamera::getImage(bool bWait)
         BitmapPtr pCamBmp(new Bitmap(m_Size, getCamPF(), pCaptureBuffer, lineLen, false,
                 "TempCameraBmp"));
         BitmapPtr pDestBmp = convertCamFrameToDestPF(pCamBmp);
-//        cerr << "CamBmp: " << pCamBmp->getPixelFormatString() << ", DestBmp: " 
-//                << pDestBmp->getPixelFormatString() << endl;
+//        cerr << "CamBmp: " << pCamBmp->getPixelFormat() << ", DestBmp: " 
+//                << pDestBmp->getPixelFormat() << endl;
         dc1394_capture_enqueue(m_pCamera, pFrame);
         return pDestBmp;
     } else {
@@ -260,7 +262,8 @@ const string& FWCamera::getDevice() const
     static string deviceInfo;
     stringstream ss;
 #ifdef AVG_ENABLE_1394_2
-    ss<<m_pCamera->vendor<<" "<<m_pCamera->model<<" (guid="<<m_pCamera->guid<<", unit="<<m_pCamera->unit<<")";
+    ss << m_pCamera->vendor << " " << m_pCamera->model << " (guid=" << m_pCamera->guid 
+            << ", unit=" << m_pCamera->unit << ")";
 #endif
     deviceInfo = ss.str();
     return deviceInfo;
@@ -281,10 +284,10 @@ double FWCamera::getFrameRate() const
     return m_FrameRate;
 }
 
-int FWCamera::getFeature(CameraFeature Feature) const
+int FWCamera::getFeature(CameraFeature feature) const
 {
 #ifdef AVG_ENABLE_1394_2
-    FeatureMap::const_iterator it = m_Features.find(Feature);
+    FeatureMap::const_iterator it = m_Features.find(feature);
     if (it == m_Features.end()) {
         return 0;
     } else {
@@ -295,36 +298,36 @@ int FWCamera::getFeature(CameraFeature Feature) const
 #endif
 }
 
-void FWCamera::setFeature(CameraFeature Feature, int Value, bool bIgnoreOldValue)
+void FWCamera::setFeature(CameraFeature feature, int value, bool bIgnoreOldValue)
 {
 #ifdef AVG_ENABLE_1394_2
-    if (bIgnoreOldValue || m_Features[Feature] != Value) {
-        m_Features[Feature] = Value;
-        if (Feature == CAM_FEATURE_STROBE_DURATION) {
+    if (bIgnoreOldValue || m_Features[feature] != value) {
+        m_Features[feature] = value;
+        if (feature == CAM_FEATURE_STROBE_DURATION) {
             try {
-                setStrobeDuration(Value);
+                setStrobeDuration(value);
             } catch (Exception& e) {
                 AVG_TRACE(Logger::WARNING, 
                         string("Camera: Setting strobe duration failed. ")+e.GetStr());
             }
         } else {
-            dc1394feature_t FeatureID = getFeatureID(Feature);
-            setFeature(FeatureID, Value);
+            dc1394feature_t FeatureID = getFeatureID(feature);
+            setFeature(FeatureID, value);
             //        dumpCameraInfo();
         }
     }
 #endif
 }
 
-void FWCamera::setFeatureOneShot(CameraFeature Feature)
+void FWCamera::setFeatureOneShot(CameraFeature feature)
 {
 #ifdef AVG_ENABLE_1394_2
-    dc1394feature_t FeatureID = getFeatureID(Feature);
+    dc1394feature_t FeatureID = getFeatureID(feature);
     dc1394error_t err = dc1394_feature_set_mode(m_pCamera, FeatureID, 
             DC1394_FEATURE_MODE_ONE_PUSH_AUTO);
     if (err != DC1394_SUCCESS) {
         AVG_TRACE(Logger::WARNING, "Camera: Unable to set one-shot for " 
-                << cameraFeatureToString(Feature) << ". Error was " << err);
+                << cameraFeatureToString(feature) << ". Error was " << err);
     }
 #endif
 }
@@ -368,25 +371,25 @@ void FWCamera::setWhitebalance(int u, int v, bool bIgnoreOldValue)
 #endif
 }
 
-void FWCamera::setFeature(dc1394feature_t Feature, int Value)
+void FWCamera::setFeature(dc1394feature_t feature, int value)
 {
 #ifdef AVG_ENABLE_1394_2
     dc1394error_t err;
-    if (Value == -1) {
-        err = dc1394_feature_set_mode(m_pCamera, Feature, DC1394_FEATURE_MODE_AUTO);
-        err = dc1394_feature_set_power(m_pCamera, Feature, DC1394_OFF);
+    if (value == -1) {
+        err = dc1394_feature_set_mode(m_pCamera, feature, DC1394_FEATURE_MODE_AUTO);
+        err = dc1394_feature_set_power(m_pCamera, feature, DC1394_OFF);
     } else {
-        dc1394_feature_set_mode(m_pCamera, Feature, DC1394_FEATURE_MODE_MANUAL);
-        err = dc1394_feature_set_power(m_pCamera, Feature, DC1394_ON);
-        err = dc1394_feature_set_value(m_pCamera, Feature, Value);
+        dc1394_feature_set_mode(m_pCamera, feature, DC1394_FEATURE_MODE_MANUAL);
+        err = dc1394_feature_set_power(m_pCamera, feature, DC1394_ON);
+        err = dc1394_feature_set_value(m_pCamera, feature, value);
     }
     if (err != DC1394_SUCCESS) {
-        AVG_TRACE(Logger::WARNING, "Camera: Unable to set " << Feature << 
+        AVG_TRACE(Logger::WARNING, "Camera: Unable to set " << feature << 
                 ". Error was " << err);
     }
 /*
     dc1394feature_info_t featureInfo;
-    featureInfo.id = Feature;
+    featureInfo.id = feature;
     err = dc1394_feature_get(m_pCamera, &featureInfo);
     dc1394_feature_print(&featureInfo, stdout);
 */
@@ -420,19 +423,19 @@ void FWCamera::setStrobeDuration(int microsecs)
                 {0x400, 0x600, 0x800, 0x900, 0xA00, 0xB00, 0xC00, 0xD00, 
                  0xE00, 0xF00, 0xFFF};
             int len = sizeof(regValues)/sizeof(*regValues);
-            assert(len == sizeof(realTimes)/sizeof(*realTimes));
+            AVG_ASSERT(len == sizeof(realTimes)/sizeof(*realTimes));
             int i;
-            for (i=1; realTimes[i] < targetMillisecs; ++i); 
+            for (i = 1; realTimes[i] < targetMillisecs; ++i); 
             double ratio = (targetMillisecs-realTimes[i])/(realTimes[i-1]-realTimes[i]);
             durationRegValue = ratio*regValues[i-1]+(1-ratio)*regValues[i];
         } 
 
         err = dc1394_set_PIO_register(m_pCamera, 0x08, 0xC0000000);
-        assert(err == DC1394_SUCCESS);
+        AVG_ASSERT(err == DC1394_SUCCESS);
         
         uint32_t strobeRegValue = 0x83001000+durationRegValue;
         err = dc1394_set_strobe_register(m_pCamera, 0x200, strobeRegValue);
-        assert(err == DC1394_SUCCESS);
+        AVG_ASSERT(err == DC1394_SUCCESS);
     }
 #endif
 }
@@ -455,13 +458,13 @@ void FWCamera::enablePtGreyBayer()
     dc1394error_t err; 
     uint32_t imageDataFormat;
     err = dc1394_get_adv_control_register(m_pCamera, 0x48, &imageDataFormat);
-    assert(err == DC1394_SUCCESS);
+    AVG_ASSERT(err == DC1394_SUCCESS);
     if (imageDataFormat & 0x80000000) {
         err = dc1394_set_adv_control_register(m_pCamera, 0x48, 0x80000081);
-        assert(err == DC1394_SUCCESS);
+        AVG_ASSERT(err == DC1394_SUCCESS);
         uint32_t bayerFormat;
         err = dc1394_get_adv_control_register(m_pCamera, 0x40, &bayerFormat);
-        assert(err == DC1394_SUCCESS);
+        AVG_ASSERT(err == DC1394_SUCCESS);
         PixelFormat exactPF = fwBayerStringToPF(bayerFormat);
         if (exactPF == I8) {
             throw(Exception(AVG_ERR_CAMERA_NONFATAL, 
@@ -478,7 +481,7 @@ void FWCamera::dumpCameraInfo()
     dc1394error_t err;
     dc1394featureset_t FeatureSet;
     err = dc1394_feature_get_all(m_pCamera, &FeatureSet);
-    assert(err == DC1394_SUCCESS);
+    AVG_ASSERT(err == DC1394_SUCCESS);
     // TODO: do this using AVG_TRACE
     dc1394_feature_print_all(&FeatureSet, stderr);
 
