@@ -35,9 +35,9 @@
 
 namespace avg {
 
-dc1394video_mode_t getCamMode(IntPoint Size, PixelFormat pf);
-dc1394framerate_t getFrameRateConst(double FrameRate);
-dc1394feature_t getFeatureID(CameraFeature Feature);
+dc1394video_mode_t getCamMode(IntPoint size, PixelFormat pf);
+dc1394framerate_t getFrameRateConst(double frameRate);
+dc1394feature_t getFeatureID(CameraFeature feature);
 
 }
 
