@@ -23,16 +23,13 @@
 
 #include "Run.h"
 
-#include <assert.h>
-
 namespace avg {
 
-Run::Run(int row, int start_col, int end_col)
+Run::Run(int row, int startCol, int endCol)
 {
     m_Row = row;
-//    assert(end_col>=start_col);
-    m_StartCol = start_col;
-    m_EndCol = end_col;
+    m_StartCol = startCol;
+    m_EndCol = endCol;
     m_Center = DPoint((m_StartCol + m_EndCol-1)/2., m_Row);
 }
  
