@@ -23,30 +23,23 @@
 #define _AVGNode_H_
 
 #include "../api.h"
-#include "DivNode.h"
-#include "KeyEvent.h"
+#include "CanvasNode.h"
 
 #include <string>
 
 namespace avg {
 
-class AVG_API AVGNode : public DivNode
+class AVG_API AVGNode : public CanvasNode
 {
     public:
         static NodeDefinition createDefinition();
         
-        AVGNode (const ArgList& Args);
-        virtual ~AVGNode ();
-
-        virtual std::string getEffectiveMediaDir();
-        bool getCropSetting();
-        void setAngle(double angle);
-        
-    private:
-        bool m_bEnableCrop;
-
+        AVGNode(const ArgList& args);
+        virtual ~AVGNode();
 };
 
+typedef boost::shared_ptr<AVGNode> AVGNodePtr;
+
 }
 
-#endif //_AVGNode_H_
+#endif
