@@ -26,7 +26,7 @@
 
 #include "../api.h"
 #include "../base/Point.h"
-#include "../base/IntTriple.h"
+#include "../base/Triple.h"
 
 #include "ArgBase.h"
 
@@ -35,7 +35,7 @@
 
 namespace avg {
 
-class Node;
+class VisibleNode;
 
 template<class T>
 class AVG_TEMPLATE_API Arg: public ArgBase
@@ -47,7 +47,7 @@ public:
 
     void setValue(const T& Value);
     const T& getValue() const;
-    virtual void setMember(Node * pNode) const;
+    virtual void setMember(VisibleNode * pNode) const;
     virtual ArgBase* createCopy() const;
 
 private:
@@ -81,7 +81,7 @@ void Arg<T>::setValue(const T& Value)
 }
 
 template<class T>
-void Arg<T>::setMember(Node * pNode) const
+void Arg<T>::setMember(VisibleNode * pNode) const
 {
     if (getMemberOffset() != -1) {
         T* pMember = (T*)((char*)pNode+getMemberOffset());
@@ -107,6 +107,7 @@ extern template class Arg<double>;
 extern template class Arg<std::string>;
 extern template class Arg<DPoint>;
 extern template class Arg<IntTriple>;
+extern template class Arg<DTriple>;
 extern template class Arg<std::vector<double> >;
 extern template class Arg<std::vector<DPoint> >;
 extern template class Arg<std::vector<IntTriple> >;
