@@ -39,23 +39,28 @@ typedef boost::shared_ptr<class CursorEvent> CursorEventPtr;
 class AVG_API CursorEvent: public Event 
 {
     public:
-        CursorEvent(int id, Type eventType, const IntPoint& Position, Source source);
+        CursorEvent(int id, Type eventType, const IntPoint& position, Source source);
         virtual ~CursorEvent();
-        virtual CursorEventPtr cloneAs(Type EventType) const;
+        virtual CursorEventPtr cloneAs(Type eventType) const;
         DPoint getPos() const;
         int getXPosition() const;
         int getYPosition() const;
+        void setCursorID(int id);
         int getCursorID() const;
 
         DPoint getLastDownPos() const;
         void setLastDownPos(const IntPoint& pos);
 
+        friend bool operator ==(const CursorEvent& event1, const CursorEvent& event2);
+
     protected:
         IntPoint m_Position;
         int m_ID;
         IntPoint m_LastDownPos;
 };
 
+bool operator ==(const CursorEvent& event1, const CursorEvent& event2);
+
 }
 
 #endif
