@@ -23,6 +23,7 @@
 
 #include "../base/Logger.h"
 #include "../base/ScopeTimer.h"
+#include "../base/TimeSource.h"
 #include "../base/Exception.h"
 #include "../base/ObjectCounter.h"
 
@@ -56,6 +57,8 @@ void DisplayEngine::initRender()
     m_bInitialized = true;
     if (m_VBRate != 0) {
         setVBlankRate(m_VBRate);
+    } else {
+        setFramerate(m_Framerate);
     }
 }
 
@@ -85,7 +88,6 @@ void DisplayEngine::deinitRender()
 void DisplayEngine::setFramerate(double rate)
 {
     if (rate != 0 && m_bInitialized) {
-        // TODO: Is this nessesary?
         initVBlank(0);
     }
     m_Framerate = rate;
@@ -121,7 +123,7 @@ bool DisplayEngine::wasFrameLate()
     return m_bFrameLate;
 }
 
-static ProfilingZone WaitProfilingZone("Render - wait");
+static ProfilingZoneID WaitProfilingZone("Render - wait");
 
 void DisplayEngine::frameWait()
 {
