@@ -22,20 +22,22 @@
 
 #include "../base/ObjectCounter.h"
 
+#include <iostream>
+
+using namespace std;
+
 namespace avg {
 
 DisplayParams::DisplayParams()
-    : m_x(-1),
-      m_y(-1),
-      m_Width(0),
-      m_Height(0),
+    : m_Pos(-1, -1),
+      m_Size(0, 0),
       m_bFullscreen(false),
       m_BPP(24),
-      m_WindowWidth(0),
-      m_WindowHeight(0),
+      m_WindowSize(0, 0),
       m_bShowCursor(true),
       m_VBRate(1),
-      m_Framerate(0)
+      m_Framerate(0),
+      m_bHasWindowFrame(true)
 { 
     ObjectCounter::get()->incRef(&typeid(*this));
     m_Gamma[0] = -1.0;
@@ -48,5 +50,19 @@ DisplayParams::~DisplayParams()
     ObjectCounter::get()->decRef(&typeid(*this));
 }
 
+void DisplayParams::dump() const
+{
+    cerr << "DisplayParams: " << endl;
+    cerr << "  pos: " << m_Pos << endl;
+    cerr << "  size: " << m_Size << endl;
+    cerr << "  fullscreen: " << m_bFullscreen << endl;
+    cerr << "  bpp: " << m_BPP << endl;
+    cerr << "  window size: " << m_WindowSize << endl;
+    cerr << "  show cursor: " << m_bShowCursor << endl;
+    cerr << "  vbrate: " << m_VBRate << endl;
+    cerr << "  framerate: " << m_Framerate << endl;
+    cerr << "  has window frame: " << m_bHasWindowFrame << endl;
+}
+
 }
 
