@@ -24,13 +24,14 @@
 
 #include "../api.h"
 #include <functional>
+#include <string>
 #include <boost/shared_ptr.hpp>
 #undef _POSIX_C_SOURCE
 
 namespace avg {
 
-class Node;
-typedef boost::shared_ptr<class Node> NodePtr;
+class VisibleNode;
+typedef boost::shared_ptr<class VisibleNode> VisibleNodePtr;
 
 class AVG_API Event {
     public:
@@ -45,7 +46,7 @@ class AVG_API Event {
             RESIZE,
             QUIT 
         };
-        enum Source {MOUSE=1, TOUCH=2, TRACK=4, NONE=8};
+        enum Source {MOUSE=1, TOUCH=2, TRACK=4, CUSTOM=8, NONE=16};
     
         Event(Type type, Source source=NONE, int when=-1);
         Event(const Event& e);
@@ -56,14 +57,17 @@ class AVG_API Event {
         long long getWhen() const;
         Type getType() const;
         Event::Source getSource() const;
-        NodePtr getElement() const;
-        void setElement(NodePtr pNode);
+        VisibleNodePtr getElement() const;
+        void setElement(VisibleNodePtr pNode);
         
+        std::string typeStr() const;
+        static std::string typeStr(Event::Type type);
+
         friend struct isEventAfter;
         
     protected:
         Type m_Type;
-        NodePtr m_pNode;
+        VisibleNodePtr m_pNode;
         long long m_When;
 
     private:
