@@ -28,53 +28,52 @@ using namespace std;
 
 namespace avg {
 
-    EventDispatcher::EventDispatcher()
-    {
+EventDispatcher::EventDispatcher()
+{
+}
+
+EventDispatcher::~EventDispatcher() 
+{
+}
+
+void EventDispatcher::dispatch() 
+{
+    vector<EventPtr> events;
+
+    for (unsigned int i = 0; i < m_EventSources.size(); ++i) {
+        vector<EventPtr> curEvents = m_EventSources[i]->pollEvents();
+        events.insert(events.end(), curEvents.begin(), curEvents.end());
     }
 
-    EventDispatcher::~EventDispatcher() 
-    {
+    vector<EventPtr>::iterator it;
+    for (it = events.begin(); it != events.end(); ++it) {
+        handleEvent(*it);
     }
+}
 
-    void EventDispatcher::dispatch() 
-    {
-        vector<EventPtr> Events;
+void EventDispatcher::addSource(IEventSource * pSource)
+{
+    m_EventSources.push_back(pSource);
+}
 
-        for (unsigned int i = 0; i<m_EventSources.size(); ++i) {
-            vector<EventPtr> curEvents = m_EventSources[i]->pollEvents();
-            Events.insert(Events.end(), curEvents.begin(), curEvents.end());
-        }
+void EventDispatcher::addSink(IEventSink * pSink)
+{
+    m_EventSinks.push_back(pSink);
+}
 
-        vector<EventPtr>::iterator it;
-        for (it=Events.begin(); it != Events.end(); ++it) {
-            handleEvent(*it);
-        }
-    }
-
-    void EventDispatcher::addSource(IEventSource * pSource)
-    {
-        m_EventSources.push_back(pSource);
-        pSource->initEventSource();
-    }
-
-    void EventDispatcher::addSink(IEventSink * pSink)
-    {
-        m_EventSinks.push_back(pSink);
-    }
-
-    void EventDispatcher::sendEvent(EventPtr pEvent)
-    {
-        handleEvent(pEvent);
-    }
-
-    void EventDispatcher::handleEvent(EventPtr pEvent)
-    {
-        for (unsigned int i = 0; i < m_EventSinks.size(); ++i) {
-            if (m_EventSinks[i]->handleEvent(pEvent)) {
-                break;
-            }
+void EventDispatcher::sendEvent(EventPtr pEvent)
+{
+    handleEvent(pEvent);
+}
+
+void EventDispatcher::handleEvent(EventPtr pEvent)
+{
+    for (unsigned int i = 0; i < m_EventSinks.size(); ++i) {
+        if (m_EventSinks[i]->handleEvent(pEvent)) {
+            break;
         }
     }
+}
 
 }
 
