@@ -31,7 +31,7 @@ namespace avg {
 class AVG_API IEventSource {
     public:
         virtual ~IEventSource() {};
-        virtual void initEventSource() {};
+        virtual void start() {};
         virtual std::vector<EventPtr> pollEvents()=0;
 };
 
