@@ -23,7 +23,6 @@
 #define _Image_H_
 
 #include "../api.h"
-#include "OGLTexture.h"
 
 #include "../base/Point.h"
 #include "../graphics/Bitmap.h"
@@ -34,46 +33,61 @@
 namespace avg {
 
 class OGLSurface;
-class OGLTiledSurface;
 class SDLDisplayEngine;
+class OffscreenCanvas;
+typedef boost::shared_ptr<OffscreenCanvas> OffscreenCanvasPtr;
 
 class AVG_API Image
 {
     public:
-        enum State {NOT_AVAILABLE, CPU, GPU};
+        enum State {CPU, GPU};
+        enum Source {NONE, FILE, BITMAP, SCENE};
+        enum TextureCompression {
+            TEXTURECOMPRESSION_NONE,
+            TEXTURECOMPRESSION_B5G6R5
+        };
 
-        Image(OGLSurface * pSurface, const std::string& sFilename, bool bTiled);
-        Image(OGLSurface * pSurface, const Bitmap* pBmp, bool bTiled);
+        Image(OGLSurface * pSurface);
         virtual ~Image();
 
-        void setBitmap(const Bitmap * pBmp);
-
         virtual void moveToGPU(SDLDisplayEngine* pEngine);
         virtual void moveToCPU();
 
-        void setFilename(const std::string& sFilename);
+        void discard();
+        void setEmpty();
+        void setFilename(const std::string& sFilename,
+                TextureCompression comp = TEXTURECOMPRESSION_NONE);
+        void setBitmap(const Bitmap * pBmp, 
+                TextureCompression comp = TEXTURECOMPRESSION_NONE);
+        void setCanvas(OffscreenCanvasPtr pCanvas);
+        OffscreenCanvasPtr getCanvas() const;
         const std::string& getFilename() const;
-        
+
         BitmapPtr getBitmap();
         IntPoint getSize();
         PixelFormat getPixelFormat();
         OGLSurface* getSurface();
-        OGLTiledSurface* getTiledSurface();
         State getState();
+        Source getSource();
         SDLDisplayEngine* getEngine();
 
+        static TextureCompression string2compression(const std::string& s);
+        static std::string compression2String(TextureCompression compression);
+
     private:
-        void load();
         void setupSurface();
         PixelFormat calcSurfacePF(const Bitmap& Bmp);
+        bool changeSource(Source newSource);
+        void assertValid() const;
 
         std::string m_sFilename;
         BitmapPtr m_pBmp;
         OGLSurface * m_pSurface;
         SDLDisplayEngine * m_pEngine;
+        OffscreenCanvasPtr m_pCanvas;
 
         State m_State;
-        bool m_bTiled;
+        Source m_Source;
 };
 
 typedef boost::shared_ptr<Image> ImagePtr;
