@@ -25,7 +25,7 @@
 #include "../api.h"
 #include "Event.h"
 #include "CursorEvent.h"
-#include "Node.h"
+#include "VisibleNode.h"
 
 namespace avg {
 
@@ -33,7 +33,7 @@ class AVG_API MouseEvent : public CursorEvent {
     public:
         MouseEvent(Event::Type eventType,
                 bool leftButtonState, bool middleButtonState, bool rightButtonState,
-                const IntPoint& Position, int button, const DPoint& speed);
+                const IntPoint& pos, int button, const DPoint& speed);
         virtual ~MouseEvent();
         
         const DPoint& getSpeed() const;
