@@ -34,8 +34,8 @@ NodeDefinition::NodeDefinition() :
 {
 }
 
-NodeDefinition::NodeDefinition(const string& Name, NodeBuilder pBuilder)
-    : m_sName(Name),
+NodeDefinition::NodeDefinition(const string& sName, NodeBuilder pBuilder)
+    : m_sName(sName),
       m_pBuilder(pBuilder)
 {
 }
@@ -64,7 +64,7 @@ const string& NodeDefinition::getDTDElements() const
     return m_sDTDElements;
 }
 
-string NodeDefinition::getChildren() const
+string NodeDefinition::getDTDChildrenString() const
 {
     if (m_sChildren.empty()) {
         return "EMPTY";
@@ -89,6 +89,11 @@ bool NodeDefinition::isChildAllowed(const string& sChild) const
     return false;
 }
 
+bool NodeDefinition::hasChildren() const
+{
+    return !m_sChildren.empty();
+}
+
 NodeDefinition& NodeDefinition::extendDefinition(const NodeDefinition& Def)
 {
     m_Args.copyArgsFrom(Def.m_Args);
