@@ -26,7 +26,7 @@
 
 #include "../api.h"
 
-#include "Node.h"
+#include "VisibleNode.h"
 #include "ArgList.h"
 
 #include <map>
@@ -41,15 +41,16 @@ class AVG_API NodeDefinition
 {
 public:
     NodeDefinition();
-    NodeDefinition(const std::string& Name, NodeBuilder pBuilder = 0);
+    NodeDefinition(const std::string& sName, NodeBuilder pBuilder = 0);
     virtual ~NodeDefinition();
     
     const std::string& getName() const;
     NodeBuilder getBuilder() const;
     const ArgList& getDefaultArgs() const;
     const std::string& getDTDElements() const;
-    std::string getChildren() const;
+    std::string getDTDChildrenString() const;
     bool isChildAllowed(const std::string& sChild) const;
+    bool hasChildren() const;
     
     NodeDefinition& extendDefinition(const NodeDefinition& Def);
     NodeDefinition& addArg(const ArgBase& newArg);
