@@ -23,41 +23,50 @@
 #define _Player_H_
 
 #include "../api.h"
+#include "Timeout.h"
+#include "DisplayEngine.h"
+#include "NodeRegistry.h"
+#include "MouseEvent.h"
+#include "DisplayParams.h"
+#include "GLConfig.h"
 #include "IEventSink.h"
 #include "EventDispatcher.h"
-#include "Timeout.h"
 #include "KeyEvent.h"
 #include "MouseEvent.h"
-#include "DisplayEngine.h"
-#include "TestHelper.h"
-#include "NodeRegistry.h"
-#include "DisplayParams.h"
 #include "CursorState.h"
 #include "MouseState.h"
 
-#include "../base/IFrameEndListener.h"
-#include "../base/IPlaybackEndListener.h"
-#include "../base/IPreRenderListener.h"
-#include "../base/Signal.h"
-
 #include "../audio/AudioParams.h"
 
 #include <libxml/parser.h>
 
-#include <map>
 #include <string>
 #include <vector>
 
 namespace avg {
 
-class TrackerEventSource;
 class AudioEngine;
 class Node;
+class VisibleNode;
+class TestHelper;
+class Canvas;
+class MainCanvas;
+class OffscreenCanvas;
+class TrackerEventSource;
+class MultitouchEventSource;
+class IFrameEndListener;
+class IPlaybackEndListener;
+class IPreRenderListener;
 
 typedef boost::shared_ptr<Node> NodePtr;
 typedef boost::weak_ptr<Node> NodeWeakPtr;
+typedef boost::shared_ptr<VisibleNode> VisibleNodePtr;
+typedef boost::weak_ptr<VisibleNode> VisibleNodeWeakPtr;
+typedef boost::shared_ptr<Canvas> CanvasPtr;
+typedef boost::shared_ptr<MainCanvas> MainCanvasPtr;
+typedef boost::shared_ptr<OffscreenCanvas> OffscreenCanvasPtr;
 
-class AVG_API Player : IEventSink
+class AVG_API Player: IEventSink
 {
     public:
         Player();
@@ -67,16 +76,28 @@ class AVG_API Player : IEventSink
 
         void setResolution(bool bFullscreen,
                 int width=0, int height=0, int bpp=0);
+        void setWindowFrame(bool bHasWindowFrame);
         void setWindowPos(int x=0, int y=0);
-        void setOGLOptions(bool bUsePOW2Textures, bool bUseShaders, 
-                bool bUsePixelBuffers, int MultiSampleSamples);
-        void setMultiSampleSamples(int MultiSampleSamples);
+        void setOGLOptions(bool bUsePOTTextures, bool bUseShaders, 
+                bool bUsePixelBuffers, int multiSampleSamples);
+        void setMultiSampleSamples(int multiSampleSamples);
         void enableAudio(bool bEnable);
         void setAudioOptions(int samplerate, int channels);
-        void loadFile(const std::string& sFilename);
-        void loadString(const std::string& sAVG);
+        DPoint getScreenResolution();
+
+        CanvasPtr loadFile(const std::string& sFilename);
+        CanvasPtr loadString(const std::string& sAVG);
+
+        OffscreenCanvasPtr loadCanvasFile(const std::string& sFilename);
+        OffscreenCanvasPtr loadCanvasString(const std::string& sAVG);
+        void deleteCanvas(const std::string& sID);
+        CanvasPtr getMainCanvas() const;
+        OffscreenCanvasPtr getCanvas(const std::string& sID) const;
+        void newCanvasDependency(const OffscreenCanvasPtr pCanvas);
+
         void play();
         void stop();
+        bool isStopping();
         void initPlayback();
         void cleanup();
         bool isPlaying();
@@ -86,52 +107,49 @@ class AVG_API Player : IEventSink
         TestHelper * getTestHelper();
         void setFakeFPS(double fps);
         long long getFrameTime();
+        double getFrameDuration();
 
         void registerNodeType(NodeDefinition Def, const char* pParentNames[] = 0);
         
         NodePtr createNode(const std::string& sType, const boost::python::dict& PyDict);
         NodePtr createNodeFromXmlString(const std::string& sXML);
-        void addEventSource(IEventSource * pSource);
-        TrackerEventSource * addTracker();
-        TrackerEventSource * getTracker();
+        
         int setInterval(int time, PyObject * pyfunc);
         int setTimeout(int time, PyObject * pyfunc);
         int setOnFrameHandler(PyObject * pyfunc);
         bool clearInterval(int id);
 
-        EventPtr getCurEvent() const;
+        void addEventSource(IEventSource* pSource);
         MouseEventPtr getMouseState() const;
+        TrackerEventSource * addTracker();
+        TrackerEventSource * getTracker();
+        void enableMultitouch();
+        bool isMultitouchAvailable() const;
+        void setEventCapture(VisibleNodePtr pNode, int cursorID);
+        void releaseEventCapture(int cursorID);
+
+        EventPtr getCurEvent() const;
         void setMousePos(const IntPoint& pos);
         int getKeyModifierState() const;
-        Bitmap * screenshot();
+        BitmapPtr screenshot();
         void setCursor(const Bitmap* pBmp, IntPoint hotSpot);
         void showCursor(bool bShow);
-        void setEventCapture(NodePtr pNode, int cursorID=MOUSECURSORID);
-        void releaseEventCapture(int cursorID=MOUSECURSORID);
 
-        NodePtr getElementByID(const std::string& id);
-        void registerNode(NodePtr pNode);
-        void addNodeID(NodePtr pNode);
-        void removeNodeID(const std::string& id);
+        VisibleNodePtr getElementByID(const std::string& id);
         AVGNodePtr getRootNode();
-        void doFrame();
+        void doFrame(bool bFirstFrame);
         double getFramerate();
         double getVideoRefreshRate();
-        void setGamma(double Red, double Green, double Blue);
-        virtual bool handleEvent(EventPtr pEvent);
+        bool isUsingShaders();
+        void setGamma(double red, double green, double blue);
         DisplayEngine * getDisplayEngine() const;
-        void useFakeCamera(bool bFake);
-        void stopOnEscape(bool bStop);
+        void setStopOnEscape(bool bStop);
+        bool getStopOnEscape() const;
         void setVolume(double volume);
         double getVolume() const;
-        long long getGPUMemoryUsage();
 
-        void registerFrameEndListener(IFrameEndListener* pListener);
-        void unregisterFrameEndListener(IFrameEndListener* pListener);
-        void registerPlaybackEndListener(IPlaybackEndListener* pListener);
-        void unregisterPlaybackEndListener(IPlaybackEndListener* pListener);
-        void registerPreRenderListener(IPreRenderListener* pListener);
-        void unregisterPreRenderListener(IPreRenderListener* pListener);
+        OffscreenCanvasPtr getCanvasFromURL(const std::string& sURL);
+
         std::string getCurDirName();
         std::string getRootMediaDir();
         const NodeDefinition& getNodeDef(const std::string& sType);
@@ -142,39 +160,56 @@ class AVG_API Player : IEventSink
         void loadPlugin(const std::string& name);
         void setPluginPath(const std::string& newPath);
         std::string getPluginPath() const;
+        
+        void setEventHook(PyObject * pyfunc);
+        PyObject * getEventHook() const;
 
+        void registerFrameEndListener(IFrameEndListener* pListener);
+        void unregisterFrameEndListener(IFrameEndListener* pListener);
+        void registerPlaybackEndListener(IPlaybackEndListener* pListener);
+        void unregisterPlaybackEndListener(IPlaybackEndListener* pListener);
+        void registerPreRenderListener(IPreRenderListener* pListener);
+        void unregisterPreRenderListener(IPreRenderListener* pListener);
+
+        virtual bool handleEvent(EventPtr pEvent);
+        
     private:
         void initConfig();
         void initGraphics();
         void initAudio();
 
         void updateDTD();
-        void internalLoad(const std::string& sAVG);
 
-        NodePtr createNodeFromXml(const xmlDocPtr xmlDoc, 
-                const xmlNodePtr xmlNode, DivNodeWeakPtr pParent);
+        NodePtr loadMainNodeFromFile(const std::string& sFilename);
+        NodePtr loadMainNodeFromString(const std::string& sAVG);
+        NodePtr internalLoad(const std::string& sAVG);
 
-        void render (bool bRenderEverything);
+        NodePtr createNodeFromXml(const xmlDocPtr xmlDoc,
+                const xmlNodePtr xmlNode);
+        OffscreenCanvasPtr registerOffscreenCanvas(NodePtr pNode);
+        OffscreenCanvasPtr findCanvas(const std::string& sID) const;
+        void endFrame();
 
         void sendFakeEvents();
-        void sendOver(CursorEventPtr pOtherEvent, Event::Type Type, NodePtr pNode);
+        void sendOver(CursorEventPtr pOtherEvent, Event::Type type, VisibleNodePtr pNode);
         void handleCursorEvent(CursorEventPtr pEvent, bool bOnlyCheckCursorOver=false);
-        std::vector<NodeWeakPtr> getElementsByPos(const DPoint& Pos) const;
 
-        AVGNodePtr m_pRootNode;
+        void dispatchOffscreenRendering(OffscreenCanvas* pOffscreenCanvas);
+
+        void errorIfPlaying(const std::string& sFunc) const;
+
+        MainCanvasPtr m_pMainCanvas;
+
         DisplayEngine * m_pDisplayEngine;
         AudioEngine * m_pAudioEngine;
-        IEventSource * m_pEventSource;
         TestHelper * m_pTestHelper;
        
         bool m_bAudioEnabled;
         std::string m_CurDirName;
         bool m_bStopping;
-        typedef std::map<std::string, NodePtr> NodeIDMap;
-        NodeIDMap m_IDMap;
         NodeRegistry m_NodeRegistry;
 
-        TrackerEventSource * m_pTracker;
+        IEventSource* m_pMultitouchEventSource;
 
         int addTimeout(Timeout* pTimeout);
         void removeTimeout(Timeout* pTimeout);
@@ -185,25 +220,12 @@ class AVG_API Player : IEventSink
         std::vector<Timeout *> m_PendingTimeouts;
         std::vector<Timeout *> m_NewTimeouts; // Timeouts to be added this frame.
 
-        EventDispatcherPtr m_pEventDispatcher;
-        MouseState m_MouseState;
-
-        // These are maps for each cursor id.
-        std::map<int, CursorStatePtr> m_pLastCursorStates;
-        std::map<int, NodeWeakPtr> m_pEventCaptureNode;
-
         // Configuration variables.
         DisplayParams m_DP;
         AudioParams m_AP;
-        bool m_bUsePOW2Textures;
-        bool m_bUseShaders;
-        bool m_bUsePixelBuffers;
-        int m_MultiSampleSamples;
-        bool m_bUseFakeCamera;
-        VSyncMode m_VSyncMode;
+        GLConfig m_GLConfig;
 
         bool m_bStopOnEscape;
-
         bool m_bIsPlaying;
 
         // Time calculation
@@ -215,17 +237,33 @@ class AVG_API Player : IEventSink
 
         double m_Volume;
 
-        Signal<IFrameEndListener> m_FrameEndSignal;
-        Signal<IPlaybackEndListener> m_PlaybackEndSignal;
-        Signal<IPreRenderListener> m_PreRenderSignal;
         bool m_bDirtyDTD;
         xmlDtdPtr m_dtd;
 
         bool m_bPythonAvailable;
 
+        std::vector<OffscreenCanvasPtr> m_pCanvases;
+
         static Player * s_pPlayer;
         friend void deletePlayer();
+        
+        EventDispatcherPtr m_pEventDispatcher;
+        struct EventCaptureInfo {
+            EventCaptureInfo(const VisibleNodeWeakPtr& pNode);
+
+            VisibleNodeWeakPtr m_pNode;
+            int m_CaptureCount;
+        };
+        typedef boost::shared_ptr<EventCaptureInfo> EventCaptureInfoPtr;
+        
+        std::map<int, EventCaptureInfoPtr> m_EventCaptureInfoMap;
+        
+        MouseState m_MouseState;
+
+        // These are maps for each cursor id.
+        std::map<int, CursorStatePtr> m_pLastCursorStates;
+        PyObject * m_EventHookPyFunc;
 };
 
 }
-#endif //_Player_H_
+#endif
