@@ -25,25 +25,32 @@
 #include "../api.h"
 #include "AreaNode.h"
 #include "DisplayEngine.h"
-#include "OGLTiledSurface.h"
+#include "PBOTexture.h"
+#include "FXNode.h"
 
 #include "../avgconfigwrapper.h"
 #include "../base/Point.h"
+#include "../base/Triple.h"
 #include "../base/UTF8String.h"
+#include "../graphics/FBO.h"
 
 #include <string>
 
 namespace avg {
 
+class OGLSurface;
+
+typedef std::vector<std::vector<DPoint> > VertexGrid;
+
 class AVG_API RasterNode: public AreaNode
 {
     public:
         static NodeDefinition createDefinition();
         
         virtual ~RasterNode ();
-        virtual void setRenderingEngines(DisplayEngine * pDisplayEngine, 
-                AudioEngine * pAudioEngine);
-        virtual void setArgs(const ArgList& Args);
+        virtual void setRenderingEngines(DisplayEngine* pDisplayEngine, 
+                AudioEngine* pAudioEngine);
+        virtual void setArgs(const ArgList& args);
         virtual void disconnect(bool bKill);
         virtual void checkReload();
         
@@ -61,7 +68,7 @@ class AVG_API RasterNode: public AreaNode
         DisplayEngine::BlendMode getBlendMode() const;
 
         const UTF8String& getMaskHRef() const;
-        void setMaskHRef(const UTF8String& href);
+        void setMaskHRef(const UTF8String& sHref);
 
         const DPoint& getMaskPos() const;
         void setMaskPos(const DPoint& pos);
@@ -69,23 +76,47 @@ class AVG_API RasterNode: public AreaNode
         const DPoint& getMaskSize() const;
         void setMaskSize(const DPoint& size);
 
-        NodePtr getElementByPos(const DPoint & pos);
+        void getElementsByPos(const DPoint& pos, 
+                std::vector<VisibleNodeWeakPtr>& pElements);
 
+        DTriple getGamma() const;
+        void setGamma(const DTriple& gamma);
+        DTriple getIntensity() const;
+        void setIntensity(const DTriple& intensity);
+        DTriple getContrast() const;
+        void setContrast(const DTriple& contrast);
+
+        void setEffect(FXNodePtr pFXNode);
         virtual BitmapPtr getBitmap();
         
+        void blt32(const DPoint& destSize, double opacity, DisplayEngine::BlendMode mode,
+                bool bPremultipliedAlpha = false);
+        void blta8(const DPoint& destSize, double opacity, 
+                const Pixel32& color, DisplayEngine::BlendMode mode);
+
     protected:
         RasterNode();
-        virtual OGLTiledSurface * getSurface();
+        virtual OGLSurface * getSurface();
         const MaterialInfo& getMaterial() const;
-        void calcMaskPos();
+        bool hasMask() const;
+        void setMaskCoords();
+        void bind();
 
     private:
         void setMaterial(const MaterialInfo& material);
-        virtual void setMaterialMask(MaterialInfo& material, const DPoint& pos, 
-                const DPoint& size, const DPoint& mediaSize);
+        virtual void calcMaskCoords(MaterialInfo& material);
         void downloadMask();
         void checkDisplayAvailable(std::string sMsg);
-        OGLTiledSurface * m_pSurface;
+        void setupFX();
+        void blt(const DPoint& destSize, DisplayEngine::BlendMode mode, 
+                double opacity, const Pixel32& color, bool bPremultipliedAlpha);
+
+        IntPoint getNumTiles();
+        void calcVertexGrid(VertexGrid& grid);
+        void calcTileVertex(int x, int y, DPoint& Vertex);
+        void calcTexCoords();
+
+        OGLSurface * m_pSurface;
         
         IntPoint m_MaxTileSize;
         std::string m_sBlendMode;
@@ -97,6 +128,21 @@ class AVG_API RasterNode: public AreaNode
         BitmapPtr m_pMaskBmp;
         DPoint m_MaskPos;
         DPoint m_MaskSize;
+        
+        bool m_bBound;
+
+        IntPoint m_TileSize;
+        VertexGrid m_TileVertices;
+        bool m_bVertexArrayDirty;
+        VertexArray * m_pVertexes;
+        std::vector<std::vector<DPoint> > m_TexCoords;
+
+        DTriple m_Gamma;
+        DTriple m_Intensity;
+        DTriple m_Contrast;
+
+        FBOPtr m_pFBO;
+        FXNodePtr m_pFXNode;
 };
 
 }
