@@ -25,11 +25,12 @@
 #include "../api.h"
 #include "IEventSource.h"
 #include "DisplayEngine.h"
+#include "GLConfig.h"
+
 #include "../graphics/Bitmap.h"
 #include "../graphics/Pixel32.h"
 #include "../graphics/OGLHelper.h"
-#include "../graphics/OGLShader.h"
-#include "../graphics/VertexArray.h"
+#include "../graphics/FBO.h"
 
 #include <string>
 #include <vector>
@@ -39,6 +40,8 @@ union SDL_Event;
 
 namespace avg {
 
+class XInput21MTEventSource;
+
 class AVG_API SDLDisplayEngine: public DisplayEngine, public IEventSource
 {
     public:
@@ -46,33 +49,29 @@ class AVG_API SDLDisplayEngine: public DisplayEngine, public IEventSource
         virtual ~SDLDisplayEngine();
 
         // From DisplayEngine
-        virtual void init(const DisplayParams& DP);
+        virtual void init(const DisplayParams& dp);
         virtual void teardown();
         virtual double getRefreshRate();
-        virtual void setGamma(double Red, double Green, double Blue);
+        virtual void setGamma(double red, double green, double blue);
         virtual void setMousePos(const IntPoint& pos);
         virtual int getKeyModifierState() const;
 
-        virtual void render(AVGNodePtr pRootNode);
-        
         virtual bool pushClipRect(const DRect& rc);
         virtual void popClipRect();
         virtual void pushTransform(const DPoint& translate, double angle, 
                 const DPoint& pivot);
         virtual void popTransform();
 
-        virtual int getWidth();
-        virtual int getHeight();
-        virtual int getBPP();
+        virtual IntPoint getSize();
 
         virtual bool isUsingShaders() const; 
-        OGLShaderPtr getShader();
         
         virtual void showCursor(bool bShow);
         virtual BitmapPtr screenshot();
 
         // From IEventSource
         virtual std::vector<EventPtr> pollEvents();
+        void setXIMTEventSource(XInput21MTEventSource* pEventSource);
 
         // Texture config.
         void initTextureMode();
@@ -82,25 +81,25 @@ class AVG_API SDLDisplayEngine: public DisplayEngine, public IEventSource
         // OpenGL state setting.
         void enableTexture(bool bEnable);
         void enableGLColorArray(bool bEnable);
-        void setBlendMode(BlendMode mode);
+        void setBlendMode(BlendMode mode, bool bPremultipliedAlpha = false);
         
-        int getOGLDestMode(PixelFormat pf);
-        int getOGLSrcMode(PixelFormat pf);
-        int getOGLPixelType(PixelFormat pf);
         OGLMemoryMode getMemoryModeSupported();
 
-        void setOGLOptions(bool bUsePOW2Textures, bool bUseShaders, 
-                bool bUsePixelBuffers, int MultiSampleSamples, 
-                VSyncMode DesiredVSyncMode);
-        
+        void setOGLOptions(const GLConfig& glConfig);
+        const GLConfig& getOGLOptions() const;
+        const IntPoint& getWindowSize() const;
+        bool isFullscreen() const;
+        IntPoint getScreenResolution() const;
+
+        void setMainFBO(FBOPtr pFBO);
+        FBOPtr getMainFBO() const;
+
     private:
         void initSDL(int width, int height, bool isFullscreen, int bpp);
         void initTranslationTable();
         void logConfig(); 
         virtual void swapBuffers();
         void clip(bool forward);
-        void setClipPlane(double Eqn[4], int WhichPlane);
-        static bool isParallels();
 
         EventPtr createMouseEvent
                 (Event::Type Type, const SDL_Event & SDLEvent, long Button);
@@ -109,20 +108,14 @@ class AVG_API SDLDisplayEngine: public DisplayEngine, public IEventSource
         EventPtr createKeyEvent
                 (Event::Type Type, const SDL_Event & SDLEvent);
         
-        int m_Width;
-        int m_Height;
-        bool m_IsFullscreen;
-        int m_bpp;
-        int m_WindowWidth;
-        int m_WindowHeight;
+        IntPoint m_Size;
+        bool m_bIsFullscreen;
+        IntPoint m_WindowSize;
         std::vector<DRect> m_ClipRects;
-        bool m_bEnableCrop;
 
         SDL_Surface * m_pScreen;
 
         void checkShaderSupport();
-        bool m_bUseShaders;
-        OGLShaderPtr m_pShader;
 
         // Vertical blank stuff.
         virtual bool initVBlank(int rate);
@@ -140,24 +133,24 @@ class AVG_API SDLDisplayEngine: public DisplayEngine, public IEventSource
         bool m_bMouseOverApp;
         IntPoint m_LastMousePos;
         static std::vector<long> KeyCodeTranslationTable;
+        XInput21MTEventSource * m_pXIMTEventSource;
 
-        // Texture config.
-        bool m_bUsePOTTextures;
         int m_MaxTexSize;
 
         // OpenGL state
         bool m_bEnableTexture;
         bool m_bEnableGLColorArray;
         BlendMode m_BlendMode;
+        bool m_bPremultipliedAlpha;
 
-        bool m_bShouldUsePOW2Textures;
-        bool m_bShouldUseShaders;
-        bool m_bShouldUsePixelBuffers;
-        int m_MultiSampleSamples;
-        VSyncMode m_DesiredVSyncMode;
-
+        GLConfig m_GLConfig;
+        
         bool m_bCheckedMemoryMode;
         OGLMemoryMode m_MemoryMode;
+
+        FBOPtr m_pFBO;
+
+        double m_Gamma[3];
 };
 
 }
