@@ -25,17 +25,20 @@
 #include "TouchEvent.h"
 #include "KeyEvent.h"
 
+#include "../base/Exception.h"
 #include "../base/ObjectCounter.h"
 
 #include <iostream>
+#ifdef WIN32
+#undef max
+#endif
 #include <limits>
 
 using namespace std;
 
 namespace avg {
     
-TestHelper::TestHelper(Player * pPlayer)
-    : m_pPlayer(pPlayer)
+TestHelper::TestHelper()
 {
 }
 
@@ -43,19 +46,16 @@ TestHelper::~TestHelper()
 {
 }
 
-void TestHelper::useFakeCamera(bool bFake)
-{
-    m_pPlayer->useFakeCamera(bFake);
-}
-
 void TestHelper::fakeMouseEvent(Event::Type eventType,
         bool leftButtonState, bool middleButtonState, 
         bool rightButtonState,
-        int xPosition, int yPosition, int button)
+        int xPosition, int yPosition, int button, 
+        const DPoint& speed)
 {
+    checkEventType(eventType);
     MouseEventPtr pEvent(new MouseEvent(eventType, leftButtonState, 
             middleButtonState, rightButtonState, IntPoint(xPosition, yPosition), button,
-            DPoint(0,0)));
+            speed));
     m_Events.push_back(pEvent);
 }
 
@@ -63,10 +63,12 @@ void TestHelper::fakeTouchEvent(int id, Event::Type eventType,
         Event::Source source, const DPoint& pos, const DPoint& lastDownPos,
         const DPoint& speed)
 {
-    BlobPtr pBlob(new Blob(Run(int(pos.y), int(pos.x), int(pos.x)+1)));
+    checkEventType(eventType);
+    BlobPtr pBlob(new Blob(Run(int(pos.y), int(pos.x-1), int(pos.x)+2)));
+    pBlob->addRun(Run(int(pos.y+1),  int(pos.x-1), int(pos.x)+2));
     pBlob->calcStats();
     // The id is modified to avoid collisions with real touch events.
-    TouchEventPtr pEvent(new TouchEvent(id+numeric_limits<int>::max()/2, eventType, 
+    TouchEventPtr pEvent(new TouchEvent(id+std::numeric_limits<int>::max()/2, eventType, 
             pBlob, IntPoint(pos), source, speed, IntPoint(lastDownPos)));
 
     m_Events.push_back(pEvent);
@@ -95,6 +97,14 @@ std::vector<EventPtr> TestHelper::pollEvents()
     return TempEvents;
 }
 
+void TestHelper::checkEventType(Event::Type eventType)
+{
+    if (eventType == Event::CURSOROVER || eventType == Event::CURSOROUT) {
+        throw Exception(AVG_ERR_UNSUPPORTED, "TestHelper::fakeXxxEvent: Can't send "
+                "CURSOROVER and CURSOROUT events directly. They are generated "
+                "internally.");
+    }
+}
     
 }
     
