@@ -26,7 +26,7 @@
 
 #include "../api.h"
 #include "CursorEvent.h"
-#include "Node.h"
+#include "VisibleNode.h"
 
 #include "../imaging/Blob.h"
 #include "../graphics/Bitmap.h"
@@ -44,22 +44,25 @@ typedef boost::weak_ptr<class TouchEvent> TouchEventWeakPtr;
 class AVG_API TouchEvent: public CursorEvent 
 {
     public:
-        TouchEvent(int id, Type EventType, BlobPtr pBlob, const IntPoint& Pos, 
+        TouchEvent(int id, Type eventType, BlobPtr pBlob, const IntPoint& pos, 
                 Source source, const DPoint& speed, const IntPoint& lastDownPos);
+        TouchEvent(int id, Type eventType, const IntPoint& pos, Source source, 
+                const DPoint& speed, double orientation, double area, 
+                double eccentricity, DPoint majorAxis, DPoint minorAxis);
         virtual ~TouchEvent();
-        virtual CursorEventPtr cloneAs(Type EventType) const;
+        virtual CursorEventPtr cloneAs(Type eventType) const;
 
         const DPoint& getSpeed() const;
-        double getOrientation() const {return m_pBlob->getOrientation();};
-        double getArea() const {return m_pBlob->getArea();};
-        double getInertia() const {return m_pBlob->getInertia();};
-        const DPoint & getCenter() const {return m_pBlob->getCenter();};
-        double getEccentricity() const {return m_pBlob->getEccentricity();};
-        const DPoint & getEigenValues() const {return m_pBlob->getEigenValues();};
-        const BlobPtr getBlob() const;
+        double getOrientation() const;
+        double getArea() const;
+        const DPoint & getCenter() const;
+        double getEccentricity() const;
         const DPoint & getMajorAxis() const;
         const DPoint & getMinorAxis() const;
+
+        const BlobPtr getBlob() const;
         ContourSeq getContour();
+        double getHandOrientation() const;
 
         void addRelatedEvent(TouchEventPtr pEvent);
         std::vector<TouchEventPtr> getRelatedEvents() const;
@@ -69,7 +72,15 @@ class AVG_API TouchEvent: public CursorEvent
     private:
         BlobPtr m_pBlob;
         DPoint m_Speed;
-        std::vector<TouchEventWeakPtr> m_RelatedEvents; 
+        double m_Orientation;
+        double m_Area;
+        DPoint m_Center;
+        double m_Eccentricity;
+        DPoint m_MajorAxis;
+        DPoint m_MinorAxis;
+        std::vector<TouchEventWeakPtr> m_RelatedEvents;
+        bool m_bHasHandOrientation;
+        double m_HandOrientation; 
 };
 
 }
