@@ -41,19 +41,11 @@ g_log = avg.Logger.get()
 
 class Graph():
     def __init__(self, graph,getValue):
-        self._getValue = getValue
-
-        self._values = []
-        self._xSkip = 2
-        self._lastCurUsage = 0
-        self._maxFrameTime = 0
-        
+        self._getValue = getValue    
+        self._xSkip = 2     
         self._memGraphStartTime = g_player.getFrameTime()
         self._curUsage = 0
-        self._usage = [0]
-        self._maxUsage = [0]
-        self._minutesUsage = [0]
-        self._minutesMaxUsage = [0]
+         
         self._rootNode = g_player.getRootNode()
         size = avg.Point2D(self._rootNode.width-20, self._rootNode.height/6)
         
@@ -79,7 +71,6 @@ class Graph():
         self.__graphText.text = graph
 
         self._setup()
-        self._sampleNum = 0
         avg.fadeIn(self._node, 300)
         
     def _setup(self):
@@ -94,48 +85,68 @@ class Graph():
         avg.LinearAnim(self._node, "opacity", 300, 1, 0, None, kill).start()
         g_player.clearInterval(self._interval)
         self._interval = None
+     
 
-    
-        
 class MemGraph(Graph):
     def _setup(self):
         self._interval = g_player.setInterval(1000, self._nextMemSample)
-
+        self._memSampleNum = 0
+        self._usage = [0]
+        self._maxUsage = [0]
+        self._minutesUsage = [0]
+        self._minutesMaxUsage = [0]
+        
     def _nextMemSample(self):
         curUsage = self._getValue()
         self._usage.append(curUsage)
         maxUsage = self._maxUsage[-1]
+        
         if curUsage>maxUsage:
             maxUsage = curUsage
             lastMaxChangeTime = time.time()
             self._textNode1.text = ("Last increase in maximum: "
-                    +time.strftime("%H:%M:%S", time.localtime(lastMaxChangeTime)))
+                    +time.strftime("%d.%m.%Y %H:%M:%S", 
+                        time.localtime(lastMaxChangeTime)))
         self._maxUsage.append(maxUsage)
-        self._sampleNum += 1
-        if self._sampleNum % 60 == 0:
+        self._memSampleNum += 1
+        
+        if self._memSampleNum % 60 == 0:
             lastMinuteAverage = sum(self._usage[-60:])/60
             self._minutesUsage.append(lastMinuteAverage)
             self._minutesMaxUsage.append(maxUsage)
-
-        if self._sampleNum < 60*60:
+            
+        if self._memSampleNum < 60*60:
             self._plotLine(self._usage, self._lineNode, maxUsage)
-            self._plotLine(self._maxUsage, self._maxLineNode, maxUsage)
-        else:
+            self._plotLine(self._maxUsage, self._maxLineNode, maxUsage)              
+        else:             
             self._plotLine(self._minutesUsage, self._lineNode, maxUsage)
             self._plotLine(self._minutesMaxUsage, self._maxLineNode, maxUsage)
+            
         self._textNode0.text = ("Max. memory usage: %(size).2f MB"
                 %{"size":maxUsage/(1024*1024.)})
-
+        
+        if self._memSampleNum % 3600 == 0:
+            del self._usage[0:3600]
+            del self._maxUsage[0:3599]
+            if self._memSampleNum == 604800:
+                self._memSampleNum == 0
+                       
     def _plotLine(self, data, node, maxy):
         yfactor = self._graphSize.y/float(maxy)
         xfactor = self._graphSize.x/float(len(data)-1)
         node.pos = [(pos[0]*xfactor+10, (maxy-pos[1])*yfactor+10) 
                 for pos in enumerate(data)]
 
+
 class FrameRateGraph(Graph):
     def _setup(self):
-        self._interval = g_player.setOnFrameHandler(self._nextFrameTimeSample)         
-           
+        self._interval = g_player.setOnFrameHandler(self._nextFrameTimeSample) 
+        self._sampleNum = 0        
+        self._memSampleNum = 0
+        self._lastCurUsage = 0
+        self._maxFrameTime = 0
+        self._values = []
+        
     def _nextFrameTimeSample(self):       
         val = self._frameTimeSample()
         self._appendValue(val)
@@ -152,14 +163,15 @@ class FrameRateGraph(Graph):
         diff = frameTime - self._lastCurUsage       
         #if(self._sampleNum % 1800 == 0):
            # self._maxFrameTime = 0
-        if(self._sampleNum<2):
+        if self._sampleNum < 2:
             self._maxFrameTime = 0
-        if(diff>self._maxFrameTime):
+        if diff > self._maxFrameTime:
             lastMaxChangeTime = time.time()     
             self._maxFrameTime = diff
             self._textNode0.text = ("Max FrameTime: %.f" %self._maxFrameTime + " ms" + 
-                "   Time: " +time.strftime("%H:%M:%S", time.localtime(lastMaxChangeTime)))
-        if diff>self._node.y-1:
+                "   Time: " +time.strftime("%d.%m.%Y %H:%M:%S",
+                time.localtime(lastMaxChangeTime)))
+        if diff > self._node.y-1:
             y = self._node.y-1
             
         self._lastCurUsage = frameTime
@@ -171,13 +183,34 @@ class FrameRateGraph(Graph):
         
     def _getCoords(self):
         return zip(xrange(10,len(self._values)*self._xSkip, self._xSkip), self._values)
-    
+   
+
+class TouchVisualization(avg.DivNode):
+    def __init__(self, event, **kwargs):
+        avg.DivNode.__init__(self, **kwargs)
+        self.cursorid = event.cursorid
+        self.pos = event.pos
+        radius = event.majoraxis.getNorm()
+        self.__circle = avg.CircleNode(r=radius, fillcolor="FFFFFF", fillopacity=0.5,
+                strokewidth=0, parent=self)
+        self.__majorAxis = avg.LineNode(pos1=(0,0), pos2=event.majoraxis, color="FFFFFF",
+                parent=self)
+        self.__minorAxis = avg.LineNode(pos1=(0,0), pos2=event.minoraxis, color="FFFFFF",
+                parent=self)
+
+    def move(self, event):
+        self.pos = event.pos
+        self.__circle.r = event.majoraxis.getNorm()+1
+        self.__majorAxis.pos2 = event.majoraxis
+        self.__minorAxis.pos2 = event.minoraxis
+
+
 class AVGAppStarter(object):
     """Starts an AVGApp"""
     def __init__(self, appClass, resolution, debugWindowSize = None):
         self._AppClass = appClass
         resolution = Point2D(resolution)
-        testMode = os.getenv("AVG_DEPLOY") == None
+        testMode = self._AppClass.avg_deploy == None
         if testMode and debugWindowSize is not None:
             debugWindowSize = Point2D(debugWindowSize)
         else:
@@ -204,9 +237,20 @@ class AVGAppStarter(object):
         self._appNode.size = rootNode.size
         rootNode.appendChild(self._appNode)
 
+        self.__showMTEvents = False
+        self.__touchViss = {} 
+        self.__touchVisOverlay = avg.DivNode(sensitive=False, size=resolution,
+                parent=rootNode)
+
         g_player.showCursor(testMode)
+
+        if self._AppClass.fakeFullscreen:
+            fullscreen = False
+        else:
+            fullscreen = not testMode
+
         g_player.setResolution(
-                not testMode, # fullscreen
+                fullscreen,
                 int(debugWindowSize.x), int(debugWindowSize.y),
                 0 # color depth
                 )
@@ -216,17 +260,21 @@ class AVGAppStarter(object):
         self.__unicodeBindDown = {}
         self.__unicodeBindUp = {}
         
+        self.__notifyNode = None
+        
         rootNode.setEventHandler(avg.KEYDOWN, avg.NONE, self.__onKeyDown)
         rootNode.setEventHandler(avg.KEYUP, avg.NONE, self.__onKeyUp)
         
-        self.bindKey('o', self.__dumpObjects, 'dump objects')
-        self.bindKey('m', self.__showMemoryUsage, 'show memory usage')
-        self.bindKey('f', self.__showFrameRateUsage, 'show frameTime usage')
-        self.bindKey('.', self.__switchClickTest, 'start clicktest', 'up')
-        self.bindKey('t', self.__switchMtemu, 'activate multitouch emulation')  
+        self.bindKey('o', self.__dumpObjects, 'Dump objects')
+        self.bindKey('m', self.__showMemoryUsage, 'Show memory usage')
+        self.bindKey('f', self.__showFrameRateUsage, 'Show frameTime usage')
+        self.bindKey('.', self.__switchClickTest, 'Start clicktest')
+        self.bindKey('t', self.__switchMtemu, 'Activate multitouch emulation')  
+        self.bindKey('e', self.__switchShowMTEvents, 'Show multitouch events')  
+        self.bindKey('s', self.__screenshot, 'Take screenshot')  
         self.bindUnicode('?', self.activateHelp, 'HELP')  
         
-         
+
         self.helpInstance = MThelp(self)
         self.showingHelp = False
         self.__showingMemGraph = False
@@ -240,6 +288,7 @@ class AVGAppStarter(object):
         self._appInstance = self._AppClass(self._appNode)
         self._appInstance.setStarter(self)
         g_player.play()
+        self._appInstance.exit()
 
     def _onBeforePlay(self):
         pass
@@ -333,7 +382,7 @@ class AVGAppStarter(object):
         return x
           
     def __onKeyDown(self, event):
-        handledByApp = self._activeApp.onKey(event)
+        handledByApp = self._activeApp.onKeyDown(event)
         if handledByApp:
             return
         elif event.keystring in self.__keyBindDown:
@@ -344,9 +393,11 @@ class AVGAppStarter(object):
         elif self.__checkUnicode(event, self.__unicodeBindDown) == 2:
             self.__unicodeBindDown[unichr(event.unicode).encode("utf-8")][0]()
             return
-        
-                        
+
     def __onKeyUp(self, event):
+        handledByApp = self._activeApp.onKeyUp(event)
+        if handledByApp:
+            return
         if event.keystring in self.__keyBindUp:
             if event.unicode == event.keycode:
                 self.__keyBindUp[event.keystring][0]()
@@ -359,8 +410,7 @@ class AVGAppStarter(object):
         elif self.__checkUnicode(event, self.__unicodeBindUp) == 2:
             self.__unicodeBindUp[unichr(event.unicode).encode("utf-8")][0]()
             return
-            
-    
+
     def __dumpObjects(self):
         gc.collect()
         testHelper = g_player.getTestHelper()
@@ -376,7 +426,7 @@ class AVGAppStarter(object):
             if(self.__graphs == 1 ):
                 self.__frGraph.setYpos(10)
         else:
-            self.__memGraph = MemGraph("Memory Graph", getValue = lambda: avg.getMemoryUsage())         
+            self.__memGraph = MemGraph("Memory Graph", getValue = avg.getMemoryUsage)         
             self.__graphs = self.__graphs +1          
             if(self.__graphs > 1 ):
                 self.__memGraph.setYpos(190)       
@@ -391,7 +441,8 @@ class AVGAppStarter(object):
             if(self.__graphs == 1 ):
                 self.__memGraph.setYpos(10)
         else:      
-            self.__frGraph = FrameRateGraph("FrameTime Graph",getValue = lambda: g_player.getFrameTime())
+            self.__frGraph = FrameRateGraph("FrameTime Graph",
+                    getValue = g_player.getFrameTime)
             self.__graphs = self.__graphs +1 
             if(self.__graphs >1):               
                 self.__frGraph.setYpos(190)           
@@ -425,7 +476,67 @@ class AVGAppStarter(object):
             self.unbindKey('right shift')
             self._mtEmu.delete()
             self._mtEmu = None
-    
+   
+    def __switchShowMTEvents(self):
+        self.__showMTEvents = not(self.__showMTEvents)
+        if self.__showMTEvents:
+            self.__oldEventHook = g_player.getEventHook()
+            g_player.setEventHook(self.__showMTEventHook)
+        else:
+            g_player.setEventHook(self.__oldEventHook)
+            for id, touchVis in self.__touchViss.items():
+                touchVis.unlink(True)
+            self.__touchViss = {}
+
+    def __showMTEventHook(self, event):
+        if (isinstance(event, avg.TouchEvent) and event.source == avg.TOUCH and
+                (event.type == avg.CURSORDOWN or event.type == avg.CURSORMOTION or
+                 event.type == avg.CURSORUP)):
+            try:
+                touchVis = self.__touchViss[event.cursorid]
+            except KeyError:
+                touchVis = TouchVisualization(event, 
+                        parent=self.__touchVisOverlay)
+                self.__touchViss[event.cursorid] = touchVis
+            if event.type == avg.CURSORDOWN:
+                pass
+            elif event.type == avg.CURSORMOTION:
+                touchVis.move(event)
+            elif event.type == avg.CURSORUP:
+                touchVis.unlink(True)
+                del self.__touchViss[event.cursorid]
+        if self.__oldEventHook:
+            return self.__oldEventHook()
+        else:
+            return False
+
+    def __killNotifyNode(self):
+        if self.__notifyNode:
+            self.__notifyNode.unlink()
+            self.__notifyNode = None
+            
+    def __screenshot(self):
+        fnum = 0
+        fnameTemplate = 'screenshot-%03d.png'
+        while os.path.exists(fnameTemplate % fnum):
+            fnum += 1
+        
+        try:
+            g_player.screenshot().save('screenshot-%03d.png' % fnum)
+        except RuntimeError:
+            text = 'Cannot save snapshot file'
+        else:
+            text='Screenshot saved as ' + fnameTemplate % fnum
+        
+        self.__killNotifyNode()
+        
+        self.__notifyNode = avg.WordsNode(
+            text=text, x=g_player.getRootNode().width - 50,
+            y=g_player.getRootNode().height - 50, alignment='right', fontsize=20,
+            sensitive=False, parent=g_player.getRootNode())
+            
+        g_player.setTimeout(2000, self.__killNotifyNode)
+        
     def activateHelp(self):
         if self.showingHelp == False:
             self.showingHelp = True
