@@ -22,26 +22,12 @@
 
 import unittest
 
-import sys, os, platform
-
-# Import the correct version of libavg. Since it should be possible to
-# run the tests without installing libavg, we add the location of the 
-# uninstalled libavg to the path.
-# TODO: This is a mess.
-sys.path += ['../wrapper/.libs', '../python']
-if platform.system() == 'Darwin':
-    sys.path += ['../..']     # Location of libavg in a mac installation. 
-
-if platform.system() == 'Windows':
-    from libavg import avg    # Under windows, there is no uninstalled version.
-else:
-    import avg
-
+from libavg import avg
 from testcase import *
 
 class AVTestCase(AVGTestCase):
     def __init__(self, testFuncName):
-        AVGTestCase.__init__(self, testFuncName, 24)
+        AVGTestCase.__init__(self, testFuncName)
 
     def setUp(self):
         AVGTestCase.setUp(self)
@@ -54,16 +40,18 @@ class AVTestCase(AVGTestCase):
         def onNoEOF():
             self.assert_(False)
 
-        self._loadEmpty()
+        self.loadEmptyScene()
         Player.getRootNode().appendChild(node)
         node.play()
         node.setEOFCallback(onEOF)
         Player.setTimeout(10000, onNoEOF)
         Player.play()
-
+        
     def testVideoInfo(self):
         def checkInfo():
             node.pause()
+            self.assert_(node.getCurFrame() == 0)
+            self.assert_(node.getCurTime() == 0)
             self.assert_(node.getDuration() == 1000)
             self.assert_(node.getBitrate() == 224064)
             self.assert_(node.getVideoCodec() == "mpeg4")
@@ -74,9 +62,8 @@ class AVTestCase(AVGTestCase):
                 self.assert_(node.getNumAudioChannels() == 2)
 
         def checkExceptions():
-            node = Player.createNode("video",
-                {"href": "../video/testfiles/mpeg1-48x48.mpg",
-                        "threaded": isThreaded})
+            node = avg.VideoNode(href="../video/testfiles/mpeg1-48x48.mpg",
+                    threaded=isThreaded)
             self.assertException(node.getDuration)
             self.assertException(node.getBitrate)
             self.assertException(node.getVideoCodec)
@@ -88,18 +75,14 @@ class AVTestCase(AVGTestCase):
             Player.getRootNode().appendChild(node)
 
         def checkAudioFile():
-            node = Player.createNode("video",
-                {"href": "../video/testfiles/44.1kHz_16bit_stereo.wav",
-                        "threaded": isThreaded})
-            Player.getRootNode().appendChild(node)
+            node = avg.VideoNode(href="../video/testfiles/44.1kHz_16bit_stereo.wav",
+                    threaded=isThreaded, parent=Player.getRootNode())
             self.assertException(node.pause)
 
         for isThreaded in (False, True):
-            self._loadEmpty()
-            node = Player.createNode("video",
-                {"href": "../video/testfiles/mpeg1-48x48-sound.avi",
-                        "threaded": isThreaded})
-            Player.getRootNode().appendChild(node)
+            self.loadEmptyScene()
+            node = avg.VideoNode(href="../video/testfiles/mpeg1-48x48-sound.avi",
+                        threaded=isThreaded, parent=Player.getRootNode())
             checkInfo()
             checkExceptions()
             self.start(None,
@@ -107,6 +90,10 @@ class AVTestCase(AVGTestCase):
                      checkExceptions,
                      checkAudioFile,
                     ))
+        self.loadEmptyScene()
+        node = avg.VideoNode(href="../video/testfiles/mpeg1-48x48-sound.avi",
+                    queuelength=23, parent=Player.getRootNode())
+        self.assert_(node.queuelength == 23)
 
     def testVideoFiles(self):
         def testVideoFile(filename, isThreaded):
@@ -120,16 +107,18 @@ class AVTestCase(AVGTestCase):
                 if not(isThreaded):
                     self.compareImage("testVideo-"+filename+"1", False)
 
-            def testHasAudio():
+            def testInfo():
                 if filename == "mpeg1-48x48-sound.avi" and isThreaded:
                     self.assert_(node.hasAudio())
                 else:
                     self.assert_(not(node.hasAudio()))
+                self.assert_((filename == "rgba-48x48.mov" or 
+                        filename == "vp6a-yuva-48x48.flv") == node.hasAlpha())
 
-            self._loadEmpty()
-            node = Player.createNode("video",
-                {"href": "../video/testfiles/"+filename, "volume":0.8,
-                        "threaded": isThreaded})
+            self.loadEmptyScene()
+            node = avg.VideoNode(href="../video/testfiles/"+filename, volume=0.8,
+                        threaded=isThreaded)
+            self.assert_(node.threaded == isThreaded)
             setVolume(0.6)
             Player.getRootNode().appendChild(node)
             self.assertException(node.hasAudio)
@@ -140,20 +129,30 @@ class AVTestCase(AVGTestCase):
                      lambda: checkImage(filename),
                      lambda: setVolume(0.3),
                      lambda: testGetVolume(0.3),
-                     testHasAudio,
+                     testInfo,
                      lambda: node.stop()
                     ))
-
-        for filename in ["mjpeg-48x48.avi", "mpeg1-48x48.mpg", "mpeg1-48x48-sound.avi", 
-                "rgba-48x48.mov", "h264-48x48.h264"]:
+        videoFiles = ["mjpeg-48x48.avi", "mpeg1-48x48.mpg", "mpeg1-48x48-sound.avi", 
+                "rgba-48x48.mov", "h264-48x48.h264", "vp6a-yuva-48x48.flv"]
+        for filename in videoFiles:
             for isThreaded in [False, True]:
                 testVideoFile(filename, isThreaded)
 
+    def testPlayBeforeConnect(self):
+        node = avg.VideoNode(href="../video/testfiles/mpeg1-48x48.mpg", threaded=False)
+        node.play()
+        self.loadEmptyScene()
+        Player.getRootNode().insertChild(node, 0)
+        Player.setFakeFPS(25)
+        self.start(None,
+                (lambda: self.assert_(node.size == (48, 48)),
+                 lambda: self.compareImage("testPlayBeforeConnect", False),
+                )) 
+
     def testVideoState(self):
-        self._loadEmpty()
-        node = Player.createNode("video",
-            {"href": "../video/testfiles/mpeg1-48x48.mpg", "threaded": False})
-        Player.getRootNode().appendChild(node)
+        self.loadEmptyScene()
+        node = avg.VideoNode(href="../video/testfiles/mpeg1-48x48.mpg", threaded=False,
+                parent=Player.getRootNode())
         Player.setFakeFPS(25)
         self.start(None,
                 (lambda: node.play(),
@@ -179,10 +178,9 @@ class AVTestCase(AVGTestCase):
         def activate():
             node.active=1
         
-        self._loadEmpty()
-        node = Player.createNode("video",
-            {"href": "../video/testfiles/mpeg1-48x48.mpg", "threaded": False})
-        Player.getRootNode().appendChild(node)
+        self.loadEmptyScene()
+        node = avg.VideoNode(href="../video/testfiles/mpeg1-48x48.mpg", threaded=False,
+                parent=Player.getRootNode())
         Player.setFakeFPS(25)
         self.start(None,
                 (lambda: node.play(),
@@ -200,21 +198,20 @@ class AVTestCase(AVGTestCase):
             node.href = "../video/testfiles/h264-48x48.h264"
 
         def setHRefUnloaded():
-            node = Player.createNode("video", {})
+            node = avg.VideoNode()
             node.href = "../video/testfiles/h264-48x48.h264"
             node.play()
 
         def testVideoNotFound():
             # Missing file, but no play() or pause(): Should just work.
-            node = Player.createNode("video", {"href":"MissingFile.mov"})
+            node = avg.VideoNode(href="MissingFile.mov")
             node.href = "SecondMissingFile.mov"
             # Now libavg notices the missing file.
             self.assertException(node.play)
 
-        self._loadEmpty()
-        node = Player.createNode("video",
-            {"href": "../video/testfiles/mpeg1-48x48.mpg", "threaded": False})
-        Player.getRootNode().appendChild(node)
+        self.loadEmptyScene()
+        node = avg.VideoNode(href="../video/testfiles/mpeg1-48x48.mpg", threaded=False,
+                parent=Player.getRootNode())
         Player.setFakeFPS(25)
         testVideoNotFound()
         setHRefUnloaded()
@@ -260,18 +257,18 @@ class AVTestCase(AVGTestCase):
 
         for useCustomFPS in [False, True]:
             Player.setFakeFPS(25)
-            self._loadEmpty()
+            self.loadEmptyScene()
             if useCustomFPS:
-                videoNode = Player.createNode("video", 
-                        {"loop":True, "fps":25, "threaded":False, 
-                         "href":"../video/testfiles/mjpeg-48x48.avi"})
+                videoNode = avg.VideoNode(parent=Player.getRootNode(), loop=True, fps=25,
+                        threaded=False, href="../video/testfiles/mjpeg-48x48.avi")
             else:
-                videoNode = Player.createNode("video",
-                        {"loop":True, "href":"../video/testfiles/mjpeg-48x48.avi",
-                         "threaded":False})
-            Player.getRootNode().appendChild(videoNode)
+                videoNode = avg.VideoNode(parent=Player.getRootNode(), loop=True, 
+                        href="../video/testfiles/mjpeg-48x48.avi", threaded=False)
+
+            videoNode.play()
+            seek(26)
             self.start(None,
-                    (lambda: videoNode.play(),
+                    (lambda: self.compareImage("testVideoSeek0", False),
                      lambda: seek(100),
                      lambda: self.compareImage("testVideoSeek1", False),
                      lambda: videoNode.pause(),
@@ -291,6 +288,26 @@ class AVTestCase(AVGTestCase):
                  lambda: self.compareImage("testVideoFPS", False)
                 ))
 
+    def testVideoLoop(self):
+        def onEOF():
+            self.eof = True
+
+        def onFrame():
+            if self.eof:
+                self.compareImage("testVideoLoop", False)
+                Player.stop()
+
+        for threaded in [False, True]:
+            self.eof = False
+            Player.setFakeFPS(25)
+            self.loadEmptyScene()
+            videoNode = avg.VideoNode(parent=Player.getRootNode(), loop=True, fps=25,
+                    threaded=threaded, href="../video/testfiles/mpeg1-48x48.mpg")
+            videoNode.setEOFCallback(onEOF)
+            videoNode.play()
+            Player.setOnFrameHandler(onFrame)
+            Player.play()
+
     def testVideoMask(self):
         def testWithFile(filename, testImgName):
             def setMask(href):
@@ -330,12 +347,40 @@ class AVTestCase(AVGTestCase):
             testWithFile("../video/testfiles/mjpeg-48x48.avi", "testVideoMaskYUVJ")
             testWithFile("../video/testfiles/rgba-48x48.mov", "testVideoMaskRGBA")
 
+    def testException(self):
+        class TestException(Exception):
+            pass
+        
+        def throwException():
+            raise TestException
+        
+        Player.setFakeFPS(0.1)
+        videoNode = libavg.VideoNode(threaded = False)
+        videoNode.href = "./testmediadir/mjpeg-48x48.avi"
+        videoNode.setEOFCallback(throwException)
+        
+        self.loadEmptyScene()
+        libavg.Player.get().getRootNode().appendChild(videoNode)
+        
+        self.__exceptionThrown = False
+        try:
+            self.start(None,
+                (videoNode.pause,
+                 lambda: videoNode.seekToFrame(videoNode.getNumFrames()),
+                 videoNode.play,
+                 lambda: None))
+        except TestException:
+            self.__exceptionThrown = True
+            
+        self.assert_(self.__exceptionThrown)
+        
     def testVideoEOF(self):
         Player.setFakeFPS(25)
         for filename in ["mpeg1-48x48.mpg", "mpeg1-48x48-sound.avi"]:
-            node = Player.createNode("video",
-                    {"href": "../video/testfiles/"+filename})
+            node = avg.VideoNode(href="../video/testfiles/"+filename)
             self.testEOF(node)
+        node = avg.VideoNode(href="../video/testfiles/mpeg1-48x48.mpg", opacity=0)
+        self.testEOF(node)
 
         Player.loadString("""
             <avg width="160" height="120">
@@ -361,10 +406,9 @@ class AVTestCase(AVGTestCase):
             def testGetVolume(volume):
                 self.assert_(node.volume == volume)
 
-            self._loadEmpty()
-            node = Player.createNode("sound",
-                    {"href": "../video/testfiles/"+filename})
-            Player.getRootNode().appendChild(node)
+            self.loadEmptyScene()
+            node = avg.SoundNode(href="../video/testfiles/"+filename, 
+                    parent=Player.getRootNode())
             self.start(None,
                     (
                      lambda: setVolume(0.5),
@@ -398,22 +442,19 @@ class AVTestCase(AVGTestCase):
             self.assert_(node.getNumAudioChannels() == 2)
 
         def checkExceptions():
-            node = Player.createNode("sound",
-                {"href": "../video/testfiles/44.1kHz_16bit_stereo.wav"})
+            node = avg.SoundNode(href="../video/testfiles/44.1kHz_16bit_stereo.wav")
             self.assertException(node.getAudioCodec)
             self.assertException(node.getAudioSampleRate)
             self.assertException(node.getNumAudioChannels)
 
         def checkVideoFile():
-            node = Player.createNode("sound",
-                {"href": "../video/testfiles/mpeg1-48x48.mpg"})
-            Player.getRootNode().appendChild(node)
+            node = avg.SoundNode(href="../video/testfiles/mpeg1-48x48.mpg",
+                    parent=Player.getRootNode())
             self.assertException(node.pause)
 
-        self._loadEmpty()
-        node = Player.createNode("sound",
-            {"href": "../video/testfiles/44.1kHz_16bit_stereo.wav"})
-        Player.getRootNode().appendChild(node)
+        self.loadEmptyScene()
+        node = avg.SoundNode(href="../video/testfiles/44.1kHz_16bit_stereo.wav",
+                    parent=Player.getRootNode())
         checkInfo()
         checkExceptions()
         self.start(None,
@@ -424,20 +465,18 @@ class AVTestCase(AVGTestCase):
 
     def testBrokenSound(self):
         def openSound():
-            node = Player.createNode("sound",
-                    {"href": "../video/testfiles/44.1kHz_16bit_6Chan.ogg"})
-            Player.getRootNode().appendChild(node)
+            node = avg.SoundNode(href="../video/testfiles/44.1kHz_16bit_6Chan.ogg",
+                    parent=Player.getRootNode())
             self.assertException(node.play)
 
-        self._loadEmpty()
+        self.loadEmptyScene()
         self.start(None,
                 [openSound])
 
     def testSoundEOF(self):
         Player.setFakeFPS(-1)
         Player.volume = 0 
-        node = Player.createNode("sound",
-                {"href": "../video/testfiles/44.1kHz_16bit_mono.wav"})
+        node = avg.SoundNode(href="../video/testfiles/44.1kHz_16bit_mono.wav")
         self.testEOF(node)
 
 
@@ -449,15 +488,18 @@ def AVTestSuite(tests):
             "testSoundEOF",
             "testVideoInfo",
             "testVideoFiles",
+            "testPlayBeforeConnect",
             "testVideoState",
             "testVideoActive",
             "testVideoHRef",
             "testVideoOpacity",
             "testVideoSeek",
             "testVideoFPS",
+            "testVideoLoop",
             "testVideoMask",
             "testVideoEOF",
+            "testException",
             )
-    return AVGTestSuite(availableTests, AVTestCase, tests)
+    return createAVGTestSuite(availableTests, AVTestCase, tests)
 
 Player = avg.Player.get()
