@@ -22,26 +22,12 @@
 
 import unittest
 
-import sys, platform
-
-# Import the correct version of libavg. Since it should be possible to
-# run the tests without installing libavg, we add the location of the 
-# uninstalled libavg to the path.
-# TODO: This is a mess.
-sys.path += ['../wrapper/.libs', '../python']
-if platform.system() == 'Darwin':
-    sys.path += ['../..']     # Location of libavg in a mac installation. 
-
-if platform.system() == 'Windows':
-    from libavg import avg    # Under windows, there is no uninstalled version.
-else:
-    import avg
-
+from libavg import avg
 from testcase import *
 
 class DynamicsTestCase(AVGTestCase):
     def __init__(self, testFuncName):
-        AVGTestCase.__init__(self, testFuncName, 24)
+        AVGTestCase.__init__(self, testFuncName)
 
     def __runDynamicsTest(self, createFunc, testName, isVideo = False, 
             warnOnImageDiff = False):
@@ -99,11 +85,10 @@ class DynamicsTestCase(AVGTestCase):
             self.assert_(gone == None)
         
         def runTest(useXml):
-            self._loadEmpty()
+            self.loadEmptyScene()
             createNode1(useXml)
             Player.stop()
-            setUpVideo(Player)
-            self._loadEmpty()
+            self.loadEmptyScene()
             Player.setFakeFPS(25)
             self.start(None,
                     (lambda: createNode1(useXml),
@@ -187,13 +172,35 @@ class DynamicsTestCase(AVGTestCase):
                     </div>
                     """)
             else:
-                imgNode = Player.createNode("image", {"href":"rgb24-64x64.png"})
-                node = Player.createNode("div", {})
-                node.appendChild(imgNode)
+                node = avg.DivNode()
+                imgNode = avg.ImageNode(href="rgb24-64x64.png", parent=node)
             return node
 
         self.__runDynamicsTest(createDiv, "testDivDynamics")
 
+    def testDuplicateID(self):
+        self.loadEmptyScene()
+        root = Player.getRootNode()
+        avg.ImageNode(href="rgb24-64x64.png", id="testdup", parent=root)
+        self.assertException(lambda: avg.ImageNode(href="rgb24-64x64.png", 
+                id="testdup", parent=root))
+        self.start(None,
+                (self.assertException(lambda: avg.ImageNode(href="rgb24-64x64.png", 
+                        id="testdup", parent=root)),
+                ))
+       
+    def testChangeParentError(self):
+        def changeParent():
+            div = avg.DivNode()
+            img = avg.ImageNode(href="additive/rgb24-64x64.png", parent=div)
+            Player.getRootNode().appendChild(img)
+
+        self.loadEmptyScene()
+        self.assertException(changeParent)
+        self.start(None,
+                (self.assertException(changeParent),
+                ))
+
     def testDynamicEventCapture(self):
         # Tests if deleting a node that has events captured works.
         def createImg():
@@ -220,7 +227,7 @@ class DynamicsTestCase(AVGTestCase):
         Helper = Player.getTestHelper()
         self.captureMouseDownCalled = False
         self.mainMouseUpCalled = False
-        self._loadEmpty()
+        self.loadEmptyScene()
         self.start(None,
                 (createImg,
                  setEventCapture,
@@ -265,7 +272,7 @@ class DynamicsTestCase(AVGTestCase):
         def resetEventString():
             self.__eventString = ''
 
-        self._loadEmpty()
+        self.loadEmptyScene()
         self.start(None, (
                 createNodes,
                 resetEventString,
@@ -277,9 +284,7 @@ class DynamicsTestCase(AVGTestCase):
                 resetEventString,
                 lambda: click (65,55),
                 lambda: self.assert_(self.__eventString=='d'),
-                )
-                )
-
+                ))
 
     def testComplexDiv(self):
         def setImageID(imgNode):
@@ -304,12 +309,11 @@ class DynamicsTestCase(AVGTestCase):
             node.appendChild(imgNode)
             self.assertException(lambda: setImageID(imgNode))
 
-        self._loadEmpty()
+        self.loadEmptyScene()
         createDiv()
         removeDiv()
         Player.stop()
-        setUpVideo(Player)
-        self._loadEmpty()
+        self.loadEmptyScene()
         Player.setFakeFPS(25)
         self.start(None,
                 (createDiv,
@@ -318,11 +322,46 @@ class DynamicsTestCase(AVGTestCase):
                  lambda: self.compareImage("testComplexDiv1", False),
                 ))
 
+    def testNodeCustomization(self):
+        def testNodePythonAttribute():
+            node1 = Player.createNode("image", {"id":"foo", "pos":(23, 42)})
+            Player.getRootNode().appendChild(node1)
+            node1.customAttribute = "bbb"
+            node2 = Player.getElementByID("foo")
+            self.assert_(node1==node2)
+            self.assert_(node2.customAttribute == "bbb")
+            node1.unlink(True)
+
+        def testNodePythonSubclass():
+
+            class CustomImageNode(avg.ImageNode):
+                def __init__(self, p, parent=None, **kwargs):
+                    avg.ImageNode.__init__(self, pos=p, href="rgb24-64x64.png", **kwargs)
+                    if parent:
+                        parent.appendChild(self)
+
+                def customMethod(self):
+                    pass
+
+            customNode = avg.ImageNode(id="foo")
+            self.assert_(customNode.id == "foo")
+            CustomImageNode((23, 42), parent=Player.getRootNode())
+            retrievedImage = Player.getRootNode().getChild(0)
+            self.assert_(type(retrievedImage) == CustomImageNode)
+            self.assert_(retrievedImage.pos == (23,42))
+            self.assert_(retrievedImage.href == "rgb24-64x64.png")
+            retrievedImage.customMethod()
+            
+
+        self.loadEmptyScene()
+        testNodePythonAttribute()
+        testNodePythonSubclass()
+
     def testDynamicMediaDir(self):
         def attachNode():
             Player.getRootNode().appendChild(imageNode1)
 
-        self._loadEmpty()
+        self.loadEmptyScene()
         Player.getRootNode().mediadir="testmediadir"
         imageNode1 = Player.createNode("image", {"href": "rgb24-64x64a.png"})
         imageNode2 = Player.createNode("image", {"href": "rgb24-64x64a.png", "x":30})
@@ -342,11 +381,14 @@ def dynamicsTestSuite(tests):
         #   "testPanoDynamics",
             "testDivDynamics",
             "testEventBubbling",
+            "testDuplicateID",
+            "testChangeParentError",
             "testDynamicEventCapture",
             "testComplexDiv",
+            "testNodeCustomization",
             "testDynamicMediaDir"
             )
 
-    return AVGTestSuite (availableTests, DynamicsTestCase, tests)
+    return createAVGTestSuite(availableTests, DynamicsTestCase, tests)
 
 Player = avg.Player.get()
