@@ -22,29 +22,17 @@
 
 import unittest
 
-import sys, time, platform, os.path, shutil
+import shutil
 import math
 
-# Import the correct version of libavg. Since it should be possible to
-# run the tests without installing libavg, we add the location of the 
-# uninstalled libavg to the path.
-# TODO: This is a mess. 
-sys.path += ['../wrapper/.libs', '../python']
-if platform.system() == 'Darwin':
-    sys.path += ['../..']     # Location of libavg in a mac installation. 
-
-if platform.system() == 'Windows':
-    from libavg import avg    # Under windows, there is no uninstalled version.
-else:    
-    import avg
-
+from libavg import avg
 from testcase import *
 
 g_IsMaskSupported = None
 
 class ImageTestCase(AVGTestCase):
     def __init__(self, testFuncName):
-        AVGTestCase.__init__(self, testFuncName, 24)
+        AVGTestCase.__init__(self, testFuncName)
 
     def testImageHRef(self):
         def createXmlNode(pos):
@@ -53,8 +41,8 @@ class ImageTestCase(AVGTestCase):
             self.assert_(node.getMediaSize() == avg.Point2D(32, 32))
             return node
 
-        def createDictNode(pos):
-            node = Player.createNode("image", {"pos":pos, "href":"rgb24-32x32.png"})
+        def createDictNode(root, p):
+            node = avg.ImageNode(pos=p, href="rgb24-32x32.png", parent=root)
             self.assert_(node.getMediaSize() == avg.Point2D(32, 32))
             self.assert_(node.size == avg.Point2D(32, 32))
             return node
@@ -65,8 +53,7 @@ class ImageTestCase(AVGTestCase):
             xmlNode = createXmlNode((16, y))
             root.appendChild(xmlNode)
             
-            dictNode = createDictNode((48, y))
-            root.appendChild(dictNode)
+            createDictNode(root, (48, y))
             
             noAttachNode = createXmlNode((80, y))
             noAttachNode.href = "rgb24alpha-32x32.png"
@@ -81,7 +68,7 @@ class ImageTestCase(AVGTestCase):
             self.assert_(attachNode.size == avg.Point2D(32,32))
 
         def setUnicodeHref():
-            if isDirWritable():
+            if self._isCurrentDirWriteable():
                 root = Player.getRootNode()
                 # Can't check unicode filenames into svn or the windows client breaks.
                 # So we rename the file locally.
@@ -92,10 +79,10 @@ class ImageTestCase(AVGTestCase):
                 os.remove(u"ö.png")
 
         def compareUnicode():
-            if isDirWritable():
+            if self._isCurrentDirWriteable():
                 self.compareImage("testImgHRef3", False)
 
-        self._loadEmpty()
+        self.loadEmptyScene()
         addNodes(16)
         self.start(None,
                 (lambda: self.compareImage("testImgHRef1", False),
@@ -110,8 +97,8 @@ class ImageTestCase(AVGTestCase):
             return Player.createNode(
                     """<image pos="%s" href="rgb24-32x32.png"/>"""%str(pos))        
 
-        def createDictNode(pos):
-            return Player.createNode("image", {"pos":pos, "href":"rgb24-32x32.png"})
+        def createDictNode(root, p):
+            return avg.ImageNode(pos=p, href="rgb24-32x32.png", parent=root)
 
         def illegalMove(node):
             self.assertException(node.pos.x == 23)
@@ -121,8 +108,7 @@ class ImageTestCase(AVGTestCase):
             root = Player.getRootNode()
             xmlNode = createXmlNode((16, y))
             root.appendChild(xmlNode)
-            dictNode = createDictNode((48, y))
-            root.appendChild(dictNode)
+            createDictNode(root, (48, y))
             noAttachNode = createXmlNode((0, 0))
             noAttachNode.pos = avg.Point2D(80, y)
             illegalMove(noAttachNode)
@@ -132,7 +118,7 @@ class ImageTestCase(AVGTestCase):
             attachNode.pos = avg.Point2D(112, y)
             illegalMove(attachNode)
 
-        self._loadEmpty()
+        self.loadEmptyScene()
         addNodes(16)
         self.start(None,
                 (lambda: self.compareImage("testImgPos1", False),
@@ -146,9 +132,8 @@ class ImageTestCase(AVGTestCase):
                     """<image pos="%s" size="%s" href="rgb24-64x64.png"/>"""
                     %(str(pos), str(size))) 
 
-        def createDictNode(pos, size):
-            return Player.createNode("image", {"pos":pos, "size":size,
-                    "href":"rgb24-64x64.png"}) 
+        def createDictNode(p, s):
+            return avg.ImageNode(pos=p, size=s, href="rgb24-64x64.png")
 
         def addNodes(y):
             root = Player.getRootNode()
@@ -167,7 +152,7 @@ class ImageTestCase(AVGTestCase):
             attachNode.size = avg.Point2D(32, 32)
             self.assert_(attachNode.size == avg.Point2D(32, 32))
 
-        self._loadEmpty()
+        self.loadEmptyScene()
         addNodes(16)
         self.start(None,
                 (lambda: self.compareImage("testImgSize1", False),
@@ -176,9 +161,9 @@ class ImageTestCase(AVGTestCase):
                 ))
        
     def testImageWarp(self):
-        def createNode(pos):
-            return Player.createNode("image", {"pos":pos, "href":"rgb24-32x32.png",
-                    "maxtilewidth":16, "maxtileheight":8}) 
+        def createNode(p):
+            return avg.ImageNode(pos=p, href="rgb24-32x32.png",
+                    maxtilewidth=16, maxtileheight=8) 
 
         def moveVertex(node):
             grid = node.getWarpedVertexCoords()
@@ -197,7 +182,7 @@ class ImageTestCase(AVGTestCase):
             Player.getRootNode().appendChild(node)
             moveVertex(node)
         
-        self._loadEmpty()
+        self.loadEmptyScene()
         testEarlyAccessException()
         self.start(None,
                 (lambda: addNode(),
@@ -213,9 +198,8 @@ class ImageTestCase(AVGTestCase):
             node.setBitmap(bmp)
             self.assert_(node.getMediaSize() == (65,65))
         
-        def loadFromBitmap(pos, orighref):
-            node = Player.createNode('image',
-                    {'pos':pos, 'size':(32, 32), 'href':orighref})
+        def loadFromBitmap(p, orighref):
+            node = avg.ImageNode(pos=p, size=(32, 32), href=orighref)
             bmp = avg.Bitmap('rgb24-65x65.png')
             self.assert_(bmp.getSize() == (65,65))
             node.setBitmap(bmp)
@@ -225,27 +209,38 @@ class ImageTestCase(AVGTestCase):
         def testStringConversion():
             bmp = avg.Bitmap('rgb24-65x65.png')
             s = bmp.getPixels()
-            bmp1 = avg.Bitmap(bmp.getSize(), avg.R8G8B8X8, "sample")
+            bmp1 = avg.Bitmap(bmp.getSize(), avg.B8G8R8X8, "sample")
             bmp1.setPixels(s)
             self.assert_(self.areSimilarBmps(bmp, bmp1, 0.01, 0.01))
 
         def testUnicode():
-            if isDirWritable():
+            if self._isCurrentDirWriteable():
                 # Can't check unicode filenames into svn or the windows client breaks.
                 # So we rename the file locally.
                 shutil.copyfile("oe.png", u"ö.png")
                 bmp = avg.Bitmap(u"ö.png")
                 os.remove(u"ö.png")
 
+        def testGetPixel():
+            bmp = avg.Bitmap('rgb24-65x65.png')
+            self.assert_(bmp.getPixel((1,1)) == (255,0,0,255))
+            self.assert_(bmp.getPixel((33,1)) == (0,255,0,255))
+            bmp = avg.Bitmap('rgb24alpha-64x64.png')
+            self.assert_(bmp.getPixel((1,1)) == (0,0,0,0))
+            self.assert_(bmp.getPixel((63,1)) == (83,255,83,142))
+            bmp = avg.Bitmap('greyscale.png')
+            self.assert_(bmp.getPixel((1,1)) == (255,255,255,255))
+            self.assert_(bmp.getPixel((1,63)) == (0,0,0,255))
+            self.assertException(lambda: bmp.getPixel((64,0)))
+
         def setNullBitmap():
             node.setBitmap(None)
 
-        node = Player.createNode("image", {"href":"rgb24-65x65.png", "size":(32, 32)})
+        node = avg.ImageNode(href="rgb24-65x65.png", size=(32, 32))
         getBitmap(node)
 
-        self._loadEmpty()
-        node = Player.createNode('image',
-                {'pos':(0,0), 'size':(32, 32), 'href':"rgb24-65x65.png"})
+        self.loadEmptyScene()
+        node = avg.ImageNode(pos=(0,0), size=(32, 32), href="rgb24-65x65.png")
         Player.getRootNode().appendChild(node)
         getBitmap(node)
         self.assert_(node.size == (32,32))
@@ -258,6 +253,7 @@ class ImageTestCase(AVGTestCase):
                  lambda: loadFromBitmap((32,32), ""),
                  lambda: loadFromBitmap((64,32), "rgb24alpha-64x64.png"),
                  lambda: self.compareImage("testBitmap1", False),
+                 testGetPixel,
                  lambda: self.assertException(setNullBitmap)
                 ))
 
@@ -266,14 +262,12 @@ class ImageTestCase(AVGTestCase):
             Player.getElementByID("blend").blendmode="add"
         
         Player.loadString("""
-            <?xml version="1.0"?>
-            <!DOCTYPE avg SYSTEM "../../doc/avg.dtd">
             <avg width="160" height="120">
                 <image x="0" y="0" href="freidrehen.jpg"/>
                 <image id="blend" x="0" y="0" opacity="0.6" href="rgb24-65x65.png"/>
                 <image x="0" y="48" opacity="0.6" href="rgb24-65x65.png" blendmode="add"/>
-                <image x="48" y="0" opacity="0.6" href="rgb24-65x65.png" blendmode="min"/>
-                <image x="48" y="48" opacity="0.6" href="rgb24-65x65.png" 
+                <image x="48" y="0" opacity="1" href="rgb24-65x65.png" blendmode="min"/>
+                <image x="48" y="48" opacity="1" href="rgb24-65x65.png" 
                         blendmode="max"/>
             </avg>
         """)
@@ -286,9 +280,8 @@ class ImageTestCase(AVGTestCase):
     def _isMaskSupported(self):
         global g_IsMaskSupported
         if g_IsMaskSupported == None:
-            self._loadEmpty()
-            node = Player.createNode("image", {"href": "rgb24-65x65.png", 
-                    "maskhref": "mask.png"})
+            self.loadEmptyScene()
+            node = avg.ImageNode(href="rgb24-65x65.png", maskhref="mask.png")
             Player.getRootNode().appendChild(node)
             try:
                 self.start(None, [])
@@ -298,20 +291,18 @@ class ImageTestCase(AVGTestCase):
         return g_IsMaskSupported
 
     def testImageMask(self):
-        def createNode(pos):
-            node = Player.createNode("image", {"href": "rgb24-65x65.png", 
-                    "maskhref": "mask.png", "pos":pos, "size":(32, 32)})
+        def createNode(p):
+            node = avg.ImageNode(href="rgb24-65x65.png", maskhref="mask.png", 
+                    pos=p, size=(32, 32))
             Player.getRootNode().appendChild(node)
 
-        def setNoAttach(pos):
-            node = Player.createNode("image", {"href": "rgb24-65x65.png", 
-                    "pos":pos, "size":(32, 32)})
+        def setNoAttach(p):
+            node = avg.ImageNode(href="rgb24-65x65.png", pos=p, size=(32, 32))
             node.maskhref = "mask.png"
             Player.getRootNode().appendChild(node)
 
-        def setAttach(pos):
-            node = Player.createNode("image", {"href": "rgb24-65x65.png", 
-                    "pos":pos, "size":(32, 32)})
+        def setAttach(p):
+            node = avg.ImageNode(href="rgb24-65x65.png", pos=p, size=(32, 32))
             Player.getRootNode().appendChild(node)
             node.maskhref = "mask.png"
 
@@ -327,7 +318,7 @@ class ImageTestCase(AVGTestCase):
         if not(self._isMaskSupported()):
             print "Skipping testImageMask - no shader support."
             return
-        self._loadEmpty()
+        self.loadEmptyScene()
         createNode((0,0))
         node = Player.getRootNode().getChild(0)
         setNoAttach((32,0))
@@ -344,26 +335,41 @@ class ImageTestCase(AVGTestCase):
                  setMaskNotFound
                 ))
 
+    def testImageMaskCanvas(self):
+        if not(self._isMaskSupported()):
+            print "Skipping testImageMaskCanvas - no shader support."
+            return
+        self.loadEmptyScene()
+        Player.loadCanvasString("""
+            <canvas id="testcanvas" width="64" height="64">
+                <image href="rgb24-64x64.png"/>
+            </canvas>
+        """)
+        node = avg.ImageNode(href="canvas:testcanvas", maskhref="mask.png")
+        Player.getRootNode().appendChild(node)
+        self.start(None,
+                [lambda: self.compareImage("testImgMaskCanvas", False)
+                ])
+
     def testImageMaskPos(self):
-        def createNode(pos):
-            node = Player.createNode("image", {"href": "rgb24-65x65.png", 
-                    "maskhref": "mask.png", "pos":pos, "size":(32, 32), 
-                    "maskpos": (32, 32)})
+        def createNode(p):
+            node = avg.ImageNode(href="rgb24-65x65.png", maskhref="mask.png", 
+                    pos=p, size=(32, 32), maskpos=(32, 32))
             Player.getRootNode().appendChild(node)
             
-        def setNoAttach(pos):
-            node = Player.createNode("image", {"href": "rgb24-65x65.png", 
-                    "maskhref": "mask.png", "pos":pos, "size":(32, 32)})
+        def setNoAttach(p):
+            node = avg.ImageNode(href="rgb24-65x65.png", maskhref="mask.png", 
+                    pos=p, size=(32, 32))
             node.maskpos = (32, 32)
             Player.getRootNode().appendChild(node)
 
-        def setAttach(pos):
-            node = Player.createNode("image", {"href": "rgb24-65x65.png", 
-                    "maskhref": "mask.png", "pos":pos, "size":(32, 32)})
+        def setAttach(p):
+            node = avg.ImageNode(href="rgb24-65x65.png", maskhref="mask.png", 
+                    pos=p, size=(32, 32))
             Player.getRootNode().appendChild(node)
             node.maskpos = (32, 32)
 
-        self._loadEmpty()
+        self.loadEmptyScene()
         if not(self._isMaskSupported()):
             print "Skipping testImageMaskPos - no shader support."
             return
@@ -378,22 +384,19 @@ class ImageTestCase(AVGTestCase):
                 ))
 
     def testImageMaskSize(self):
-        def createNode(pos):
-            node = Player.createNode("image", {"href": "rgb24-65x65.png", 
-                    "maskhref": "mask.png", "pos":pos, "size":(32, 32), 
-                    "masksize": (48, 48)})
-            Player.getRootNode().appendChild(node)
+        def createNode(p):
+            node = avg.ImageNode(href="rgb24-65x65.png", maskhref="mask.png", 
+                    pos=p, size=(32, 32), masksize=(48, 48), parent=Player.getRootNode())
             
-        def setNoAttach(pos):
-            node = Player.createNode("image", {"href": "rgb24-65x65.png", 
-                    "maskhref": "mask.png", "pos":pos, "size":(32, 32)})
+        def setNoAttach(p):
+            node = avg.ImageNode(href="rgb24-65x65.png", maskhref="mask.png", 
+                    pos=p, size=(32, 32))
             node.masksize = (48, 48)
             Player.getRootNode().appendChild(node)
 
-        def setAttach(pos):
-            node = Player.createNode("image", {"href": "rgb24-65x65.png", 
-                    "maskhref": "mask.png", "pos":pos, "size":(32, 32)})
-            Player.getRootNode().appendChild(node)
+        def setAttach(p):
+            node = avg.ImageNode(href="rgb24-65x65.png", maskhref="mask.png", 
+                    pos=p, size=(32, 32), parent=Player.getRootNode())
             node.masksize = (48, 48)
 
         def setPos():
@@ -403,7 +406,7 @@ class ImageTestCase(AVGTestCase):
             node.maskpos = (0, 0)
             node.masksize = (0, 0)
 
-        self._loadEmpty()
+        self.loadEmptyScene()
         if not(self._isMaskSupported()):
             print "Skipping testImageMaskPos - no shader support."
             return
@@ -424,7 +427,6 @@ class ImageTestCase(AVGTestCase):
 
     def testImageMipmap(self):
         Player.loadString("""
-            <?xml version="1.0"?>
             <avg id="imageavg" width="160" height="120">
                 <image width="64" height="64" href="checker.png"/>
                 <image x="64" width="64" height="64" href="checker.png" mipmap="true"/>
@@ -435,6 +437,35 @@ class ImageTestCase(AVGTestCase):
                 [lambda: self.compareImage("testMipmap", False)
                 ])
 
+    def testImageCompression(self):
+        def loadBitmap():
+            bmp = avg.Bitmap("colorramp.png")
+            self.image.setBitmap(bmp)
+
+        def relink():
+            self.image.unlink(False)
+            Player.getRootNode().appendChild(self.image)
+
+        def checkAlpha():
+            self.image.href="rgb24alpha-64x64.png"
+
+        Player.loadString("""
+            <avg id="imageavg" width="160" height="120">
+                <image id="img" href="rgb24-64x64.png" compression="B5G6R5"/>
+            </avg>
+        
+        """)
+        self.image = Player.getElementByID("img")
+        self.assert_(self.image.compression == "B5G6R5")
+        self.start(None, 
+                [lambda: self.compareImage("testTexCompression1", False),
+                 loadBitmap,
+                 lambda: self.compareImage("testTexCompression2", False),
+                 relink,
+                 lambda: self.compareImage("testTexCompression2", False),
+                 lambda: self.assertException(checkAlpha),
+                ])
+
 
 def imageTestSuite(tests):
     availableTests = (
@@ -445,11 +476,13 @@ def imageTestSuite(tests):
             "testBitmap",
             "testBlendMode",
             "testImageMask",
+            "testImageMaskCanvas",
             "testImageMaskPos",
             "testImageMaskSize",
             "testImageMipmap",
+            "testImageCompression",
             )
-    return AVGTestSuite(availableTests, ImageTestCase, tests)
+    return createAVGTestSuite(availableTests, ImageTestCase, tests)
 
 Player = avg.Player.get()
 
