@@ -21,31 +21,15 @@
 
 import unittest
 
-import sys, time, platform
-
-# Import the correct version of libavg. Since it should be possible to
-# run the tests without installing libavg, we add the location of the 
-# uninstalled libavg to the path.
-# TODO: This is a mess. 
-sys.path += ['../wrapper/.libs', '../python']
-if platform.system() == 'Darwin':
-    sys.path += ['../..']     # Location of libavg in a mac installation. 
-
-if platform.system() == 'Windows':
-    from libavg import avg    # Under windows, there is no uninstalled version.
-else:    
-    import avg
-
+from libavg import avg
 from testcase import *
 
 class VectorTestCase(AVGTestCase):
     def __init__(self, testFuncName):
-        AVGTestCase.__init__(self, testFuncName, 24)
+        AVGTestCase.__init__(self, testFuncName)
 
     def makeEmptyCanvas(self):
         Player.loadString("""
-            <?xml version="1.0"?>
-            <!DOCTYPE avg SYSTEM "../../doc/avg.dtd">
             <avg width="160" height="120">
               <div id="canvas" x="0" y="0" width="160" height="120"/>
             </avg>
@@ -98,7 +82,7 @@ class VectorTestCase(AVGTestCase):
         def addLines():
             for i in xrange(500):
                 y = i+2.5
-                line = Player.createNode("line", {"pos1":(2, y), "pos2":(10, y)})
+                line = avg.LineNode(pos1=(2, y), pos2=(10, y))
                 canvas.appendChild(line)
        
         canvas = self.makeEmptyCanvas()
@@ -109,8 +93,8 @@ class VectorTestCase(AVGTestCase):
 
     def testTexturedLine(self):
         def addLine():
-            line = Player.createNode("line", {"pos1":(2, 20), "pos2":(100, 20),
-                    "texhref":"rgb24-64x64.png", "strokewidth":30})
+            line = avg.LineNode(pos1=(2, 20), pos2=(100, 20), texhref="rgb24-64x64.png",
+                    strokewidth=30)
             canvas.appendChild(line)
         
         def removeLine():
@@ -153,8 +137,7 @@ class VectorTestCase(AVGTestCase):
 
     def testLineOpacity(self):
         def addLine():
-            line = Player.createNode("line", 
-                    {"pos1":(2, 2.5), "pos2":(158, 2.5), "opacity":0.5})
+            line = avg.LineNode(pos1=(2, 2.5), pos2=(158, 2.5), opacity=0.5)
             canvas.appendChild(line)
         
         def changeCanvasOpacity():
@@ -171,8 +154,8 @@ class VectorTestCase(AVGTestCase):
 
     def testRect(self):
         def addRect():
-            rect = Player.createNode("rect",
-                    {"pos":(2, 2), "size":(50, 30), "fillopacity":1, "strokewidth":0})
+            rect = avg.RectNode(pos=(2, 2), size=(50, 30), fillopacity=1, 
+                    strokewidth=0)
             canvas.appendChild(rect)
             rect.setEventHandler(avg.CURSORDOWN, avg.MOUSE, onMouseDown)
             return rect
@@ -189,8 +172,8 @@ class VectorTestCase(AVGTestCase):
             rect.angle = 1.57
         
         def addRect2():
-            rect = Player.createNode("rect",
-                    {"pos":(60, 2), "size":(50, 30), "fillopacity":1, "strokewidth":2})
+            rect = avg.RectNode(pos=(60, 2), size=(50, 30), fillopacity=1, 
+                    strokewidth=2)
             rect.color = "FFFF00"
             canvas.insertChild(rect, 0)
         
@@ -222,18 +205,17 @@ class VectorTestCase(AVGTestCase):
 
     def testTexturedRect(self):
         def addRect():
-            self.rect = Player.createNode("rect",
-                    {"pos":(20, 20), "size":(50, 40), "fillopacity":1,
-                     "filltexcoord1": (1,1), "filltexcoord2": (0,0),
-                     "texcoords": (1, 0.75, 0.5, 0.25, 0),
-                     "strokewidth":20, "texhref":"rgb24-64x64.png"})
+            self.rect = avg.RectNode(pos=(20, 20), size=(50, 40), fillopacity=1,
+                     filltexcoord1=(1,1), filltexcoord2=(0,0), strokewidth=20,
+                     texcoords=(1, 0.75, 0.5, 0.25, 0), texhref="rgb24-64x64.png")
             canvas.appendChild(self.rect)
             return self.rect
         
         def newRect():
             self.rect.unlink()
             self.rect = Player.createNode(
-                """<rect pos="(20, 20)" size="(50, 40)" fillopacity="1"                                           filltexcoord1="(1,1)" filltexcoord2="(0,0)"
+                """<rect pos="(20, 20)" size="(50, 40)" fillopacity="1"
+                        filltexcoord1="(1,1)" filltexcoord2="(0,0)"
                         texcoords="(0, 0.25, 0.5, 0.75, 1)"
                         strokewidth="20" texhref="rgb24-64x64.png"/>""")
             canvas.appendChild(self.rect)
@@ -281,20 +263,19 @@ class VectorTestCase(AVGTestCase):
                  lambda: self.compareImage("testTexturedRect7", False),
                  setFillBitmap,
                  lambda: self.compareImage("testTexturedRect6", False),
-                 setTransparentBorder,
-                 lambda: self.compareImage("testTexturedRect8", False),
+#                 setTransparentBorder,
+#                 lambda: self.compareImage("testTexturedRect8", False),
                 ))
 
     def testCurve(self):
         def addCurve():
-            curve = Player.createNode("curve",
-                {"pos1":(10.5, 10), "pos2":(10.5, 80), "pos3":(80.5, 80), 
-                 "pos4":(80.5, 10)})
+            curve = avg.CurveNode(pos1=(10.5, 10), pos2=(10.5, 80), pos3=(80.5, 80), 
+                    pos4=(80.5, 10))
             canvas.appendChild(curve)
             return curve
         
         def changeCurve():
-            curve.strokewidth = 20
+            curve.strokewidth = 19
             curve.color="FFFF00"
         
         def moveCurve():
@@ -302,9 +283,8 @@ class VectorTestCase(AVGTestCase):
             curve.pos3 = (80.5, 120)
         
         def addCurve2():
-            curve = Player.createNode("curve",
-                {"pos1":(30.5, 10), "pos2":(30.5, 120), "pos3":(100.5, 120),
-                 "pos4":(100.5, 10)})
+            curve = avg.CurveNode(pos1=(30.5, 10), pos2=(30.5, 120), pos3=(100.5, 120),
+                 pos4=(100.5, 10))
             curve.color="FF0000"
             canvas.appendChild(curve)
         
@@ -322,9 +302,8 @@ class VectorTestCase(AVGTestCase):
 
     def testTexturedCurve(self):
         def addCurve():
-            curve = Player.createNode("curve",
-                {"pos1":(10.5, 10), "pos2":(10.5, 80), "pos3":(80.5, 80), 
-                 "pos4":(80.5, 10), "strokewidth":20, "texhref":"rgb24-64x64.png"})
+            curve = avg.CurveNode(pos1=(10.5, 10), pos2=(10.5, 80), pos3=(80.5, 80), 
+                 pos4=(80.5, 10), strokewidth=19, texhref="rgb24-64x64.png")
             canvas.appendChild(curve)
             return curve
         
@@ -342,8 +321,8 @@ class VectorTestCase(AVGTestCase):
 
     def testPolyLine(self):
         def addPolyLine():
-            polyline = Player.createNode("polyline", {"strokewidth":2, "color":"FF00FF",
-                    "pos": [(10,10), (50,10), (90,50), (90, 90)]})
+            polyline = avg.PolyLineNode(strokewidth=2, color="FF00FF", 
+                    pos=[(10,10), (50,10), (90,50), (90, 90)])
             canvas.appendChild(polyline)
             return polyline
         
@@ -398,10 +377,9 @@ class VectorTestCase(AVGTestCase):
 
     def testTexturedPolyLine(self):
         def texturePolyLine():
-            polyline = Player.createNode("polyline", 
-                    {"strokewidth":20, "color":"FF00FF", "texhref":"rgb24-64x64.png",
-                     "pos":((10,10), (50,10), (90,50), (90, 90)),
-                     "texcoords":(0, 0.3, 0.7, 1) })
+            polyline = avg.PolyLineNode(strokewidth=20, color="FF00FF", 
+                    texhref="rgb24-64x64.png", pos=((10,10), (50,10), (90,50), (90, 90)),
+                    texcoords=(0, 0.3, 0.7, 1))
             canvas.appendChild(polyline)
             return polyline
         
@@ -429,8 +407,8 @@ class VectorTestCase(AVGTestCase):
 
     def testPolygon(self):
         def addPolygon():
-            polygon = Player.createNode("polygon", {"strokewidth":2, "color":"FF00FF",
-                    "pos": ((10,10), (50,10), (90,50), (90, 90))})
+            polygon = avg.PolygonNode(strokewidth=2, color="FF00FF",
+                    pos=((10,10), (50,10), (90,50), (90, 90)))
             polygon.setEventHandler(avg.CURSORDOWN, avg.MOUSE, onMouseDown)
             canvas.appendChild(polygon)
             return polygon
@@ -454,12 +432,13 @@ class VectorTestCase(AVGTestCase):
         
         def addEmptyPoint():
             pos = polygon.pos
+            pos.insert(1, (10, 10))
             pos.append((40, 40))
             polygon.pos = pos
         
         def addPolygon2():
-            polygon = Player.createNode("polygon", {"strokewidth":3, "color":"FF00FF",
-                    "pos": ((100.5,10.5), (100.5,30.5), (120.5,30.5), (120.5, 10.5))})
+            polygon = avg.PolygonNode(strokewidth=3, color="FF00FF",
+                    pos=((100.5,10.5), (100.5,30.5), (120.5,30.5), (120.5, 10.5)))
             canvas.insertChild(polygon, 0)
         
         def miterPolygons():
@@ -471,8 +450,7 @@ class VectorTestCase(AVGTestCase):
             self.__mouseDownCalled = True
       
         def addEmptyPolygon():
-            polygon = Player.createNode("polygon", {"fillopacity":1})
-            canvas.appendChild(polygon)
+            avg.PolygonNode(parent=canvas, fillopacity=1)
 
         self.__mouseDownCalled = False
         canvas = self.makeEmptyCanvas()
@@ -500,18 +478,19 @@ class VectorTestCase(AVGTestCase):
                 ))
 
     def testSelfIntersectPolygon(self):
+        def addPolygon():
+            polygon = avg.PolygonNode(strokewidth=3, color="FF00FF",
+                    pos=((100.5, 10.5), (100.5, 30.5), (120.5, 10.5), (120.5, 30.5)),
+                    fillcolor="00FFFF", fillopacity=0.5)
+            canvas.insertChild(polygon, 0)
+                
         canvas = self.makeEmptyCanvas()
-        polygon = Player.createNode("polygon", {"strokewidth":3, "color":"FF00FF",
-                "pos": ((100.5,10.5), (100.5,30.5), (120.5, 10.5), (120.5,30.5)),
-                "fillcolor": "00FFFF", "fillopacity": 0.5})
-        canvas.insertChild(polygon, 0)
-        self.assertException(lambda: self.start(None, []))
+        self.assertException(lambda: self.start(None, [addPolygon]))
 
     def testTexturedPolygon(self):
         def texturePolygon():
-            polygon = Player.createNode("polygon", 
-                    {"strokewidth":20, "color":"FF00FF", "texhref":"rgb24-64x64.png",
-                     "pos":((10,10), (50,10), (90,50), (90, 90))})
+            polygon = avg.PolygonNode(strokewidth=20, color="FF00FF", 
+                    texhref="rgb24-64x64.png", pos=((10,10), (50,10), (90,50), (90, 90)))
             canvas.appendChild(polygon)
             return polygon
         
@@ -550,9 +529,14 @@ class VectorTestCase(AVGTestCase):
                  lambda: self.compareImage("testTexturedPolygon6", False)
                 ))
 
+    def testPointInPolygon(self):
+        polygon_pos = [(10, 10), (50, 10), (90, 50), (90, 90)]
+        self.assert_(avg.pointInPolygon((50, 20), polygon_pos))
+        self.assert_(avg.pointInPolygon((10, 20), polygon_pos) == False)
+
     def testCircle(self):
         def addCircle():
-            circle = Player.createNode("circle", {"pos":(30, 30), "r":20})
+            circle = avg.CircleNode(pos=(30, 30), r=20)
             circle.setEventHandler(avg.CURSORDOWN, avg.MOUSE, onMouseDown)
             canvas.appendChild(circle)
             return circle
@@ -607,13 +591,12 @@ class VectorTestCase(AVGTestCase):
         
     def testMesh(self):
         def addMesh():
-            div = Player.createNode("div", {})
-            mesh = Player.createNode("mesh", 
-                    {"texhref":"rgb24-64x64.png",
-                     "vertexcoords":((0,0), (64,0), (0,64), (64, 64),(32, 32)),
-                     "texcoords":((0,0),(1,0),(0,1),(1,1),(0.5,0.5)),
-                     "triangles":((0,1,4),(1,3,4),(3,2,4),(2,0,4))                    
-                     })
+            div = avg.DivNode()
+            mesh = avg.MeshNode(
+                    texhref="rgb24-64x64.png",
+                    vertexcoords=((0,0), (64,0), (0,64), (64, 64),(32, 32)),
+                    texcoords=((0,0),(1,0),(0,1),(1,1),(0.5,0.5)),
+                    triangles=((0,1,4),(1,3,4),(3,2,4),(2,0,4)))
             div.appendChild(mesh)
             div.x = 50
             div.y = 30
@@ -668,6 +651,40 @@ class VectorTestCase(AVGTestCase):
                  lambda: self.compareImage("testMesh6", False)
                 ))
 
+    def testInactiveVector(self):
+        def addVectorNode():
+            node = avg.LineNode(pos1=(2, 2), pos2=(50, 2), strokewidth=2)
+            canvas.appendChild(node)
+            return node
+
+        def addFilledVectorNode():
+            node = avg.RectNode(pos=(2, 6), size=(50, 30), strokewidth=2)
+            node.setEventHandler(avg.CURSORDOWN, avg.MOUSE, onDown)
+            canvas.appendChild(node)
+            return node
+
+        def onDown(Event):
+            vNode.active = False
+            fvNode.active = False
+            self.onDownCalled = not self.onDownCalled
+
+        Helper = Player.getTestHelper()
+        canvas = self.makeEmptyCanvas()
+        vNode = addVectorNode()
+        fvNode = addFilledVectorNode()
+        self.onDownCalled = False
+        self.start(None,
+                (lambda: self.compareImage("testInactiveVector1", False),
+                 lambda: Helper.fakeMouseEvent(avg.CURSORDOWN, True, False, False,
+                        20, 20, 1),
+                 lambda: self.assert_(self.onDownCalled),
+                 lambda: self.compareImage("testInactiveVector2", False),
+                 lambda: Helper.fakeMouseEvent(avg.CURSORDOWN, True, False, False,
+                        20, 20, 1),
+                 lambda: self.assert_(self.onDownCalled)
+                ))
+        
+        
 def vectorTestSuite(tests):
     availableTests = (
             "testLine",
@@ -683,9 +700,11 @@ def vectorTestSuite(tests):
             "testPolygon",
             "testSelfIntersectPolygon",
             "testTexturedPolygon",
+            "testPointInPolygon",
             "testCircle",
             "testMesh",
+            "testInactiveVector"
             )
-    return AVGTestSuite (availableTests, VectorTestCase, tests)
+    return createAVGTestSuite(availableTests, VectorTestCase, tests)
 
 Player = avg.Player.get()
