@@ -22,26 +22,14 @@
 
 import unittest
 
-import sys, time, os, platform
-
-# Import the correct version of libavg. Since it should be possible to
-# run the tests without installing libavg, we add the location of the 
-# uninstalled libavg to the path.
-# TODO: This is a mess. 
-sys.path += ['../wrapper/.libs', '../python']
-if platform.system() == 'Darwin':
-    sys.path += ['../..']     # Location of libavg in a mac installation. 
-
-if platform.system() == 'Windows':
-    from libavg import avg    # Under windows, there is no uninstalled version.
-else:    
-    import avg
+import platform
 
+from libavg import avg
 from testcase import *
 
 class WordsTestCase(AVGTestCase):
     def __init__(self, testFuncName):
-        AVGTestCase.__init__(self, testFuncName, 24)
+        AVGTestCase.__init__(self, testFuncName)
     
     def testSimpleWords(self):
         def checkFont():
@@ -51,14 +39,14 @@ class WordsTestCase(AVGTestCase):
         def checkUnicodeText():
             node = Player.getElementByID("sanstext")
             node.text = u"föa"
-            newNode = Player.createNode("words", {"text":u"öäü"})
+            newNode = avg.WordsNode(text=u"öäü")
         
-        fontList = avg.Words.getFontFamilies()
+        fontList = avg.WordsNode.getFontFamilies()
         try:
             fontList.index("Bitstream Vera Sans")
         except ValueError:
             self.assert_(False)
-        variantList = avg.Words.getFontVariants("Bitstream Vera Sans")
+        variantList = avg.WordsNode.getFontVariants("Bitstream Vera Sans")
         self.assert_(len(variantList) >= 4)
         Player.loadString("""
           <avg width="160" height="120">
@@ -81,7 +69,7 @@ class WordsTestCase(AVGTestCase):
         def posAlmostEqual(pos1, pos2):
             return math.fabs(pos1[0]-pos2[0]) <= 2 and math.fabs(pos1[1]-pos2[1]) <= 2
         
-        node = Player.createNode("words", {"text":"Bold", "font":"Bitstream Vera Sans"})
+        node = avg.WordsNode(text="Bold", font="Bitstream Vera Sans")
         self.assert_(node.getGlyphPos(0) == (0,0))
         size = node.getGlyphSize(0)
         self.assert_(posAlmostEqual(size, (10, 18)))
@@ -97,7 +85,6 @@ class WordsTestCase(AVGTestCase):
 
     def testParaWords(self):
         Player.loadString("""
-          <?xml version="1.0"?>
           <avg width="160" height="120">
               <line pos1="(0.5, 0)" pos2="(0.5, 50)" color="FF0000"/>
               <line pos1="(119.5, 0.5)" pos2="(119.5, 50)" color="FF0000"/>
@@ -176,7 +163,7 @@ class WordsTestCase(AVGTestCase):
             node.opacity = 0.5
 
         def setSize():
-            rect = Player.createNode('rect', {'pos':(39.5, 30.5), 'size':(80, 60)})
+            rect = avg.RectNode(pos=(39.5, 30.5), size=(80, 60))
             Player.getRootNode().appendChild(rect)
             node.masksize = (160, 120)
             node.opacity = 1 
@@ -225,8 +212,15 @@ class WordsTestCase(AVGTestCase):
 #            node0 = root.getChild(0)
 #            for i in range(len(node0.text)):
 #                print node0.getGlyphPos(i)
-            self.assert_(root.getChild(0).getGlyphPos(6) != 
-                root.getChild(1).getGlyphPos(6))
+            noHint = root.getChild(0)
+            hint = root.getChild(1)
+            posNoHint = noHint.getGlyphPos(6)
+            posHint = hint.getGlyphPos(6)
+            self.assert_(posNoHint != posHint)
+            noHint.hint = True
+            hint.hint = False
+            self.assert_(posNoHint == hint.getGlyphPos(6))
+            self.assert_(posHint == noHint.getGlyphPos(6))
 
         if platform.system() == "Linux":
             print "Skipping testHinting - Linux support requires modified font config."
@@ -258,11 +252,8 @@ class WordsTestCase(AVGTestCase):
         
         def createUsingDict():
             Player.getElementByID("words").unlink()
-            node = Player.createNode("words", {
-                    "id":"words", "x":1, "y":1, "fontsize":12, "width":120,
-                    "font":"Bitstream Vera Sans", "variant": "roman",
-                    "text":self.text
-                })
+            node = avg.WordsNode(id="words", pos=(1,1), fontsize=12, width=120,
+                    font="Bitstream Vera Sans", variant="roman", text=self.text)
             Player.getRootNode().appendChild(node)
         
         self.text = """
@@ -345,22 +336,25 @@ class WordsTestCase(AVGTestCase):
         def changeUnicodeText():
             Player.getElementByID("dynamictext").text = "Arabic nonsense: ﯿﭗ"
         
+        def setNBSP():
+            node = Player.getElementByID("dynamictext")
+            node.width=100
+            node.text=(u"blindtext1\u00A0blindtext2\u00Ablindtext3 "+
+                    u"blindtext4\u00A0blindtext\u00A0blindtext\u00A0")
+
         self.start("i18ntext.avg",
                 (lambda: self.compareImage("testI18NWords1", True),
                  changeUnicodeText,
-                 lambda: self.compareImage("testI18NWords2", True)
+                 lambda: self.compareImage("testI18NWords2", True),
+                 setNBSP,
+                 lambda: self.compareImage("testI18NWords3", True),
                 ))
 
     def testRawText(self):
         def createDynNodes():
-            self.dictdnode = Player.createNode("words", 
-                    {'text':'&lt;test dyndict&amp;', 
-                     'rawtextmode':True, 
-                     'x':1, 
-                     'y':65, 
-                     'font':'Bitstream Vera Sans', 
-                     'variant': 'roman', 
-                     'fontsize':12})
+            self.dictdnode = avg.WordsNode(text='&lt;test dyndict&amp;', 
+                    rawtextmode=True, pos=(1,65), font='Bitstream Vera Sans', 
+                    variant='roman', fontsize=12)
             Player.getRootNode().appendChild(self.dictdnode)
 
             self.xmldnode = Player.createNode("""
@@ -508,8 +502,8 @@ class WordsTestCase(AVGTestCase):
                 ))
 
     def testInvalidColor(self):
-        def testColor(color):
-            Player.createNode('words', {'color':color})
+        def testColor(col):
+            avg.WordsNode(color=col)
         
         def assignValidColor():
             testColor('123456')
@@ -534,7 +528,7 @@ class WordsTestCase(AVGTestCase):
                     ))
 
     def testFontDir(self):
-        avg.Words.addFontDir('extrafonts')
+        avg.WordsNode.addFontDir('extrafonts')
         Player.loadString("""
           <avg width="160" height="120">
             <words font="testaddfontdir" fontsize="50" text="ABAAA"/>
@@ -543,6 +537,64 @@ class WordsTestCase(AVGTestCase):
         self.start(None,
                 (lambda: self.compareImage("testFontDir", True),
                 ))
+    
+    def testGetNumLines(self):
+        textNode = avg.WordsNode(text="paragraph 1<br/>paragraph 2<br/>paragraph 3")
+        self.assert_(textNode.getNumLines() == 3)
+    
+    def testGetLineExtents(self):        
+        textNode = avg.WordsNode(fontsize = 100,
+                                font = "Bitstream Vera Sans",
+                                text = "bla <br/> blabli <br/> blabliblabla")
+        self.assert_(textNode.getLineExtents(0) == (184,117))
+        textNode.parent = Player.getRootNode()
+        self.assert_(textNode.getLineExtents(1) == (303,117))
+        
+    def testGetCharIndexFromPos(self):
+        textNode = avg.WordsNode(fontsize=30,
+                      font = "Bitstream Vera Sans",
+                      text = "A B C D E F G H Ä Ö Ü ? Ì Á Í Å Ø ∏ ~ ç Ç Å",
+                      width = 300)
+
+        for k in (1,2,3,23,42):
+            pos = textNode.getGlyphPos(k)
+            char = textNode.getCharIndexFromPos(pos)
+            self.assert_(char == k)
+        
+    def testGetTextAsDisplayed(self):
+        orgText = "A<br/>B C <b>D</b> E F G H <i>Ä</i> Ö Ü ? Ì Á<br/>Í Å Ø ∏ ~ ç Ç Å"
+        orgTextWithout = "A\nB C D E F G H Ä Ö Ü ? Ì Á\nÍ Å Ø ∏ ~ ç Ç Å"
+        textNode = avg.WordsNode(fontsize=30,
+                      font = "Bitstream Vera Sans",
+                      text = orgText,
+                      width = 300)
+        self.assert_(orgTextWithout == textNode.getTextAsDisplayed())
+
+    def testSetWidth(self):
+        Player.loadString("""<avg width="160" height="120"></avg>""")
+        text = "42 " * 42
+        textNode = avg.WordsNode(
+                parent=Player.getRootNode(),
+                fontsize = 10,
+                font = "Bitstream Vera Sans",
+                text = text)
+        
+        def testSize(p1, p2):
+            self.assert_(abs(p1.x - p2.x) < 5)
+            self.assert_(abs(p1.y - p2.y) < 5)
+        
+        testSize(textNode.size, avg.Point2D(630,13))
+        testSize(textNode.getMediaSize(), avg.Point2D(630,13))
+        mediaSize = textNode.getMediaSize()
+
+        def changeSize():
+            textNode.width = 50 
+            testSize(textNode.size, avg.Point2D(50,182))
+            testSize(textNode.getMediaSize(), avg.Point2D(45,182))
+            self.assert_(mediaSize != textNode.getMediaSize())
+
+        self.start(None, [lambda: changeSize()])
+        
 
 def wordsTestSuite(tests):
     availableTests = (
@@ -562,7 +614,12 @@ def wordsTestSuite(tests):
             "testPositioning",
             "testInvalidColor",
             "testFontDir",
+            "testGetNumLines",
+            "testGetLineExtents",
+            "testGetCharIndexFromPos",
+            "testGetTextAsDisplayed",
+            "testSetWidth",
             )
-    return AVGTestSuite (availableTests, WordsTestCase, tests)
+    return createAVGTestSuite(availableTests, WordsTestCase, tests)
 
 Player = avg.Player.get()
