@@ -22,11 +22,9 @@
 //
 
 #include "AudioDecoderThread.h"
-#include "AudioVideoMsg.h"
-#include "SeekDoneVideoMsg.h"
-#include "EOFVideoMsg.h"
 
 #include "../base/Logger.h"
+#include "../base/TimeSource.h"
 
 // In Audio frames.
 #define AUDIO_BUFFER_SIZE 256
@@ -35,12 +33,12 @@ using namespace std;
 
 namespace avg {
 
-AudioDecoderThread::AudioDecoderThread(CmdQueue& CmdQ, VideoMsgQueue& MsgQ, 
-        VideoDecoderPtr pDecoder, const AudioParams& AP)
-    : WorkerThread<AudioDecoderThread>(string("AudioDecoderThread"), CmdQ),
-      m_MsgQ(MsgQ),
+AudioDecoderThread::AudioDecoderThread(CQueue& cmdQ, VideoMsgQueue& msgQ, 
+        VideoDecoderPtr pDecoder, const AudioParams& ap)
+    : WorkerThread<AudioDecoderThread>(string("AudioDecoderThread"), cmdQ),
+      m_MsgQ(msgQ),
       m_pDecoder(pDecoder),
-      m_AP(AP)
+      m_AP(ap)
 {
 }
 
@@ -55,40 +53,40 @@ bool AudioDecoderThread::work()
         msleep(10);
     } else {
         AudioBufferPtr pBuffer(new AudioBuffer(AUDIO_BUFFER_SIZE, m_AP));
-        int FramesWritten = m_pDecoder->fillAudioBuffer(pBuffer);
-        if (FramesWritten != AUDIO_BUFFER_SIZE) {
+        int framesWritten = m_pDecoder->fillAudioBuffer(pBuffer);
+        if (framesWritten != AUDIO_BUFFER_SIZE) {
             AudioBufferPtr pOldBuffer = pBuffer;
-            pBuffer = AudioBufferPtr(new AudioBuffer(FramesWritten, m_AP));
+            pBuffer = AudioBufferPtr(new AudioBuffer(framesWritten, m_AP));
             memcpy(pBuffer->getData(), pOldBuffer->getData(),
-                    FramesWritten*m_AP.m_Channels*sizeof(short));
+                    framesWritten*m_AP.m_Channels*sizeof(short));
         }
-        AudioVideoMsgPtr pVMsg = AudioVideoMsgPtr(new AudioVideoMsg(pBuffer,
-                    m_pDecoder->getCurTime(SS_AUDIO)));
+        VideoMsgPtr pVMsg = VideoMsgPtr(new VideoMsg());
+        pVMsg->setAudio(pBuffer, m_pDecoder->getCurTime(SS_AUDIO));
         m_MsgQ.push(pVMsg);
         if (m_pDecoder->isEOF(SS_AUDIO)) {
-            m_MsgQ.push(VideoMsgPtr(new EOFVideoMsg())); 
+            VideoMsgPtr pVMsg = VideoMsgPtr(new VideoMsg());
+            pVMsg->setEOF();
+            m_MsgQ.push(pVMsg); 
         }
     }
     return true;
 }
 
-void AudioDecoderThread::seek(long long DestTime)
+void AudioDecoderThread::seek(double destTime)
 {
-    try {
-        while (!m_MsgQ.empty()) {
-            m_MsgQ.pop(false);
-        }
-    } catch (Exception&) {
+    while (!m_MsgQ.empty()) {
+        m_MsgQ.pop(false);
     }
     
-    m_pDecoder->seek(DestTime);
-    m_MsgQ.push(VideoMsgPtr(new SeekDoneVideoMsg(-1, 
-            m_pDecoder->getCurTime(SS_AUDIO))));
+    m_pDecoder->seek(destTime);
+    VideoMsgPtr pVMsg = VideoMsgPtr(new VideoMsg());
+    pVMsg->setSeekDone(-1, m_pDecoder->getCurTime(SS_AUDIO));
+    m_MsgQ.push(pVMsg);
 }
 
-void AudioDecoderThread::setVolume(double Volume)
+void AudioDecoderThread::setVolume(double volume)
 {
-    m_pDecoder->setVolume(Volume);
+    m_pDecoder->setVolume(volume);
 }
 
 }
