@@ -51,10 +51,10 @@ using namespace boost;
 
 namespace avg {
 
-bool FFMpegDecoder::m_bInitialized = false;
+bool FFMpegDecoder::s_bInitialized = false;
 mutex FFMpegDecoder::s_OpenMutex;
 
-FFMpegDecoder::FFMpegDecoder ()
+FFMpegDecoder::FFMpegDecoder()
     : m_State(CLOSED),
       m_pFormatContext(0),
       m_PF(NO_PIXELFORMAT),
@@ -62,6 +62,8 @@ FFMpegDecoder::FFMpegDecoder ()
       m_Size(0,0),
       m_bUseStreamFPS(true),
       m_AStreamIndex(-1),
+      m_pSampleBuffer(0),
+      m_pResampleBuffer(0),
       m_pAudioResampleContext(0),
       m_Volume(1.0),
       m_LastVolume(1.0),
@@ -69,20 +71,16 @@ FFMpegDecoder::FFMpegDecoder ()
       m_pVStream(0),
       m_pAStream(0),
       m_VStreamIndex(-1),
-      m_pPacketData(0),
-      m_bFirstPacket(0),
+      m_bFirstPacket(false),
       m_VideoStartTimestamp(-1),
-      m_LastVideoFrameTime(-1000),
+      m_LastVideoFrameTime(-1),
       m_FPS(0)
 {
     ObjectCounter::get()->incRef(&typeid(*this));
     initVideoSupport();
-
-//    m_pRenderToBmpProfilingZone = new ProfilingZone("FFMpeg: renderToBmp");
-//    m_pConvertImageProfilingZone = new ProfilingZone("FFMpeg: convert image");
 }
 
-FFMpegDecoder::~FFMpegDecoder ()
+FFMpegDecoder::~FFMpegDecoder()
 {
     if (m_pFormatContext) {
         close();
@@ -91,7 +89,7 @@ FFMpegDecoder::~FFMpegDecoder ()
 }
 
 
-void avcodecError(const string & sFilename, int err)
+void avcodecError(const string& sFilename, int err)
 {
     switch(err) {
         case AVERROR_NUMEXPECTED:
@@ -127,28 +125,26 @@ void dump_stream_info(AVFormatContext *s)
         fprintf(stderr, "  Genre: %s\n", s->genre);
 }
 
-int openCodec(AVFormatContext *formatContext, int streamIndex)
+int openCodec(AVFormatContext* pFormatContext, int streamIndex)
 {
     AVCodecContext *enc;
 #if LIBAVFORMAT_BUILD < ((49<<16)+(0<<8)+0)
-    enc = &(formatContext->streams[streamIndex]->codec);
+    enc = &(pFormatContext->streams[streamIndex]->codec);
 #else
-    enc = formatContext->streams[streamIndex]->codec;
+    enc = pFormatContext->streams[streamIndex]->codec;
 #endif
 //    enc->debug = 0x0001; // see avcodec.h
 
     AVCodec * codec = avcodec_find_decoder(enc->codec_id);
-    if (!codec ||
-        avcodec_open(enc, codec) < 0)
-    {
+    if (!codec || avcodec_open(enc, codec) < 0) {
         return -1;
     }
     return 0;
 }
 
-void FFMpegDecoder::open(const std::string& sFilename, bool bThreadedDemuxer)
+void FFMpegDecoder::open(const string& sFilename, bool bThreadedDemuxer)
 {
-    mutex::scoped_lock Lock(s_OpenMutex);
+    mutex::scoped_lock lock(s_OpenMutex);
     m_bThreadedDemuxer = bThreadedDemuxer;
     m_bAudioEOF = false;
     m_bVideoEOF = false;
@@ -180,13 +176,13 @@ void FFMpegDecoder::open(const std::string& sFilename, bool bThreadedDemuxer)
     // Find audio and video streams in the file
     m_VStreamIndex = -1;
     m_AStreamIndex = -1;
-    for(unsigned i = 0; i < m_pFormatContext->nb_streams; i++) {
+    for (unsigned i = 0; i < m_pFormatContext->nb_streams; i++) {
 #if LIBAVFORMAT_BUILD < ((49<<16)+(0<<8)+0)
         AVCodecContext *enc = &m_pFormatContext->streams[i]->codec;
 #else         
         AVCodecContext *enc = m_pFormatContext->streams[i]->codec;
 #endif
-        switch(enc->codec_type) {
+        switch (enc->codec_type) {
             case CODEC_TYPE_VIDEO:
                 if (m_VStreamIndex < 0) {
                     m_VStreamIndex = i;
@@ -202,23 +198,13 @@ void FFMpegDecoder::open(const std::string& sFilename, bool bThreadedDemuxer)
                 break;
         }
     }
-    assert(!m_pDemuxer);
 //    dump_format(m_pFormatContext, 0, m_sFilename.c_str(), 0);
 //    dump_stream_info(m_pFormatContext);
     
-    // Create demuxer to handle streams
-    if (bThreadedDemuxer) {
-        m_pDemuxer = new AsyncDemuxer(m_pFormatContext);
-    } else {
-        m_pDemuxer = new FFMpegDemuxer(m_pFormatContext);
-    }
-    
     // Enable video stream demuxing
-    if(m_VStreamIndex >= 0)
-    {
+    if (m_VStreamIndex >= 0) {
         m_pVStream = m_pFormatContext->streams[m_VStreamIndex];
         m_State = OPENED;
-        m_pDemuxer->enableStream(m_VStreamIndex);
         
         // Set video parameters
         m_TimeUnitsPerSecond = 1.0/av_q2d(m_pVStream->time_base);
@@ -231,45 +217,33 @@ void FFMpegDecoder::open(const std::string& sFilename, bool bThreadedDemuxer)
         m_Size = IntPoint(m_pVStream->codec->width, m_pVStream->codec->height);
 #endif
         m_bFirstPacket = true;
-        m_PacketLenLeft = 0;
         m_sFilename = sFilename;
-        m_LastVideoFrameTime = -1000;
+        m_LastVideoFrameTime = -1;
     
         int rc = openCodec(m_pFormatContext, m_VStreamIndex);
         if (rc == -1) {
             m_VStreamIndex = -1;
             char szBuf[256];
-            avcodec_string(szBuf, sizeof(szBuf), m_pAStream->codec, 0);
+            avcodec_string(szBuf, sizeof(szBuf), m_pVStream->codec, 0);
             throw Exception(AVG_ERR_VIDEO_INIT_FAILED, 
                     sFilename + ": unsupported codec ("+szBuf+").");
         }
+        m_PF = calcPixelFormat(true);
     }
-    
     // Enable audio stream demuxing.
-    if (m_AStreamIndex >= 0)
-    {
+    if (m_AStreamIndex >= 0) {
         m_pAStream = m_pFormatContext->streams[m_AStreamIndex];
         
         m_AudioPacket = 0;
         m_AudioPacketData = 0;
         m_AudioPacketSize = 0;
         
-        m_pSampleBuffer = (char*)av_mallocz(SAMPLE_BUFFER_SIZE);
-        m_SampleBufferStart = 0;
-        m_SampleBufferEnd = 0;
-        m_SampleBufferLeft = SAMPLE_BUFFER_SIZE;
-
-        m_ResampleBufferSize = 0;
-        m_pResampleBuffer = 0;
-        m_ResampleBufferStart = 0;
-        m_ResampleBufferEnd = 0;
-        
         m_LastAudioFrameTime = 0;
         m_AudioStartTimestamp = 0;
         
         if (m_pAStream->start_time != AV_NOPTS_VALUE) {
-            m_AudioStartTimestamp = (long long)(1000.0 * av_q2d(m_pAStream->time_base) 
-                    * m_pAStream->start_time);
+            m_AudioStartTimestamp = double(av_q2d(m_pAStream->time_base))
+                    *m_pAStream->start_time;
         }
         m_EffectiveSampleRate = (int)(m_pAStream->codec->sample_rate);
         int rc = openCodec(m_pFormatContext, m_AStreamIndex);
@@ -282,12 +256,13 @@ void FFMpegDecoder::open(const std::string& sFilename, bool bThreadedDemuxer)
                     sFilename + ": unsupported codec ("+szBuf+"). Disabling audio.");
         }
     }
+
     m_State = OPENED;
 }
 
 void FFMpegDecoder::startDecoding(bool bDeliverYCbCr, const AudioParams* pAP)
 {
-    assert(m_State == OPENED);
+    AVG_ASSERT(m_State == OPENED);
     if (m_VStreamIndex >= 0) {
         m_PF = calcPixelFormat(bDeliverYCbCr);
     }
@@ -296,10 +271,13 @@ void FFMpegDecoder::startDecoding(bool bDeliverYCbCr, const AudioParams* pAP)
         m_AP = *pAP;
     } else {
         m_AStreamIndex = -1;
+        if (m_pAStream) {
+            avcodec_close(m_pAStream->codec);
+        }
         m_pAStream = 0;
     }
-    if (m_AStreamIndex >= 0)
-    {
+
+    if (m_AStreamIndex >= 0) {
         if (m_pAStream->codec->channels > m_AP.m_Channels) {
             AVG_TRACE(Logger::WARNING, 
                     m_sFilename << ": unsupported number of channels (" << 
@@ -307,59 +285,78 @@ void FFMpegDecoder::startDecoding(bool bDeliverYCbCr, const AudioParams* pAP)
             m_AStreamIndex = -1;
             m_pAStream = 0; 
         } else {
-            m_pDemuxer->enableStream(m_AStreamIndex);
+            m_pSampleBuffer = (char*)av_mallocz(SAMPLE_BUFFER_SIZE);
+            m_SampleBufferStart = 0;
+            m_SampleBufferEnd = 0;
+            m_SampleBufferLeft = SAMPLE_BUFFER_SIZE;
+
+            m_ResampleBufferSize = 0;
+            m_pResampleBuffer = 0;
+            m_ResampleBufferStart = 0;
+            m_ResampleBufferEnd = 0;
         }
     }
+
     if (m_VStreamIndex < 0 && m_AStreamIndex < 0) {
         throw Exception(AVG_ERR_VIDEO_INIT_FAILED, 
                 m_sFilename + " does not contain any valid audio or video streams.");
     }
+
+    // Create demuxer
+    AVG_ASSERT(!m_pDemuxer);
+    vector<int> streamIndexes;
+    if (m_VStreamIndex >= 0) {
+        streamIndexes.push_back(m_VStreamIndex);
+    }
+    if (m_AStreamIndex >= 0) {
+        streamIndexes.push_back(m_AStreamIndex);
+    }
+    if (m_bThreadedDemuxer) {
+        m_pDemuxer = new AsyncDemuxer(m_pFormatContext, streamIndexes);
+    } else {
+        m_pDemuxer = new FFMpegDemuxer(m_pFormatContext, streamIndexes);
+    }
+    
     m_State = DECODING;
 }
 
 void FFMpegDecoder::close() 
 {
-    mutex::scoped_lock Lock(s_OpenMutex);
-    mutex::scoped_lock Lock2(m_AudioMutex);
+    mutex::scoped_lock lock(s_OpenMutex);
+    mutex::scoped_lock lock2(m_AudioMutex);
     AVG_TRACE(Logger::MEMORY, "Closing " << m_sFilename);
     
     delete m_pDemuxer;
     m_pDemuxer = 0;
     
     // Close audio and video codecs
-    if(m_pVStream)
-    {
+    if (m_pVStream) {
         avcodec_close(m_pVStream->codec);
-        if (!m_bFirstPacket) {
-            av_free_packet(m_pPacket);
-            delete m_pPacket;
-        }
-        m_pPacketData = 0;
         m_pVStream = 0;
         m_VStreamIndex = -1;
     }
 
-    if(m_pAStream)
-    {
+    if (m_pAStream) {
         avcodec_close(m_pAStream->codec);
         if (m_AudioPacket) {
             av_free_packet(m_AudioPacket);
             delete m_AudioPacket;
             m_AudioPacket = 0;
         }
-        if (m_pSampleBuffer) {
-            av_free(m_pSampleBuffer);
-            m_pSampleBuffer = 0;
-        }
-        if(m_pResampleBuffer) {
-            av_free(m_pResampleBuffer);
-            m_pResampleBuffer = 0;
-        }
-        if(m_pAudioResampleContext) {
+        if (m_pAudioResampleContext) {
             audio_resample_close(m_pAudioResampleContext);
             m_pAudioResampleContext = 0;
         }
         
+        if (m_pSampleBuffer) {
+            av_free(m_pSampleBuffer);
+            m_pSampleBuffer = 0;
+        }
+        if (m_pResampleBuffer) {
+            av_free(m_pResampleBuffer);
+            m_pResampleBuffer = 0;
+        }
+
         m_AudioPacketData = 0;
         m_AudioPacketSize = 0;
         
@@ -382,7 +379,7 @@ void FFMpegDecoder::close()
         m_pFormatContext = 0;
     }
     
-    if(m_pSwsContext) {
+    if (m_pSwsContext) {
         sws_freeContext(m_pSwsContext);
         m_pSwsContext = 0;
     }
@@ -396,8 +393,8 @@ IVideoDecoder::DecoderState FFMpegDecoder::getState() const
 
 VideoInfo FFMpegDecoder::getVideoInfo() const
 {
-    assert(m_State != CLOSED);
-    long long duration = 0;
+    AVG_ASSERT(m_State != CLOSED);
+    double duration = 0;
     if (m_pVStream || m_pAStream) {
         duration = getDuration();
     }
@@ -415,25 +412,20 @@ VideoInfo FFMpegDecoder::getVideoInfo() const
     return info;
 }
 
-void FFMpegDecoder::seek(long long DestTime) 
+void FFMpegDecoder::seek(double destTime) 
 {
-    assert(m_State == DECODING);
-/* XXX: Causes audio hangs.
-    if (DestTime == 0 && m_LastVideoFrameTime == -(long long)(1000.0/m_FPS)) {
-        // Hack to improve performance when looping videos
-        return;
-    }
-*/
+    AVG_ASSERT(m_State == DECODING);
     if (m_bFirstPacket && m_pVStream) {
-        AVFrame Frame;
-        long long FrameTime;
-        readFrame(Frame, FrameTime);
+        AVFrame frame;
+        readFrame(frame);
+    }
+    m_pDemuxer->seek(destTime + getStartTime());
+    if (m_pVStream) {
+        m_LastVideoFrameTime = destTime - 1.0/m_FPS;
     }
-    m_pDemuxer->seek(DestTime + getStartTime());
-    m_LastVideoFrameTime = DestTime - (long long)(1000.0/m_FPS);
     if (m_pAStream) {
-        mutex::scoped_lock Lock(m_AudioMutex);
-        m_LastAudioFrameTime = double(DestTime);
+        mutex::scoped_lock lock(m_AudioMutex);
+        m_LastAudioFrameTime = destTime;
         m_SampleBufferStart = m_SampleBufferEnd = 0;
         m_SampleBufferLeft = SAMPLE_BUFFER_SIZE;
         m_ResampleBufferStart = m_ResampleBufferEnd = 0;
@@ -443,16 +435,21 @@ void FFMpegDecoder::seek(long long DestTime)
     m_bAudioEOF = false;
 }
 
+void FFMpegDecoder::loop()
+{
+    seek(0);
+}
+
 IntPoint FFMpegDecoder::getSize() const
 {
-    assert(m_State != CLOSED);
+    AVG_ASSERT(m_State != CLOSED);
     return m_Size;
 }
 
 int FFMpegDecoder::getCurFrame() const
 {
-    assert(m_State == DECODING);
-    return int(getCurTime(SS_VIDEO)*getNominalFPS()/1000.0+0.5);
+    AVG_ASSERT(m_State != CLOSED);
+    return int(m_LastVideoFrameTime*getNominalFPS()+0.5);
 }
 
 int FFMpegDecoder::getNumFramesQueued() const
@@ -460,25 +457,25 @@ int FFMpegDecoder::getNumFramesQueued() const
     return 0;
 }
 
-long long FFMpegDecoder::getCurTime(StreamSelect Stream) const
+double FFMpegDecoder::getCurTime(StreamSelect stream) const
 {
-    assert(m_State == DECODING);
-    switch(Stream) {
+    AVG_ASSERT(m_State != CLOSED);
+    switch(stream) {
         case SS_DEFAULT:
         case SS_VIDEO:
-            assert(m_pVStream);
+            AVG_ASSERT(m_pVStream);
             return m_LastVideoFrameTime;
         case SS_AUDIO:
-            assert(m_pAStream);
-            return (long long)m_LastAudioFrameTime;
+            AVG_ASSERT(m_pAStream);
+            return m_LastAudioFrameTime;
         default:
             return -1;
     }
 }
 
-long long FFMpegDecoder::getDuration() const
+double FFMpegDecoder::getDuration() const
 {
-    assert(m_State != CLOSED);
+    AVG_ASSERT(m_State != CLOSED);
     long long duration;
     AVRational time_base;
     if (m_pVStream) {
@@ -489,15 +486,15 @@ long long FFMpegDecoder::getDuration() const
         time_base=m_pAStream->time_base;
     }
 #if LIBAVFORMAT_BUILD < ((49<<16)+(0<<8)+0)
-    return (long long)(1000*duration/AV_TIME_BASE);
+    return double(duration)/AV_TIME_BASE;
 #else
-    return (long long)(1000*duration*av_q2d(time_base));
+    return double(duration)*av_q2d(time_base);
 #endif 
 }
 
 double FFMpegDecoder::getNominalFPS() const
 {
-    assert(m_State != CLOSED);
+    AVG_ASSERT(m_State != CLOSED);
 #if LIBAVFORMAT_BUILD < ((49<<16)+(0<<8)+0)
     return m_pVStream->r_frame_rate;
 #else
@@ -507,87 +504,89 @@ double FFMpegDecoder::getNominalFPS() const
 
 double FFMpegDecoder::getFPS() const
 {
-    assert(m_State != CLOSED);
+    AVG_ASSERT(m_State != CLOSED);
     return m_FPS;
 }
 
-void FFMpegDecoder::setFPS(double FPS)
+void FFMpegDecoder::setFPS(double fps)
 {
-    m_bUseStreamFPS = (FPS == 0);
-    if (FPS == 0) {
+    m_bUseStreamFPS = (fps == 0);
+    if (fps == 0) {
         m_FPS = calcStreamFPS();
     } else {
-        m_FPS = FPS;
+        m_FPS = fps;
     }
 }
 
 double FFMpegDecoder::getVolume() const
 {
-    assert(m_State != CLOSED);
+    AVG_ASSERT(m_State != CLOSED);
     return m_Volume;
 }
 
-void FFMpegDecoder::setVolume(double Volume)
+void FFMpegDecoder::setVolume(double volume)
 {
-    m_Volume = Volume;
-}
-
-FrameAvailableCode FFMpegDecoder::renderToBmp(BitmapPtr pBmp, long long timeWanted)
-{
-    assert(m_State == DECODING);
-//    ScopeTimer Timer(*m_pRenderToBmpProfilingZone);
-    AVFrame Frame;
-    FrameAvailableCode FrameAvailable = readFrameForTime(Frame, timeWanted);
-    if (!m_bVideoEOF && FrameAvailable == FA_NEW_FRAME) {
-        convertFrameToBmp(Frame, pBmp);
-        return FA_NEW_FRAME;
+    m_Volume = volume;
+    if (m_State != DECODING) {
+        m_LastVolume = volume;
     }
-    return FA_USE_LAST_FRAME;
 }
 
-void copyPlaneToBmp(BitmapPtr pBmp, unsigned char * pData, int Stride)
+void copyPlaneToBmp(BitmapPtr pBmp, unsigned char * pData, int stride)
 {
     unsigned char * pSrc=pData;
     unsigned char * pDest= pBmp->getPixels();
-    int DestStride = pBmp->getStride();
-    int Height = pBmp->getSize().y;
-    int Width = pBmp->getSize().x;
-    for (int y=0; y<Height; y++) {
-        memcpy(pDest, pSrc, Width);
-        pSrc+=Stride;
-        pDest+=DestStride;
+    int destStride = pBmp->getStride();
+    int height = pBmp->getSize().y;
+    int width = pBmp->getSize().x;
+    for (int y = 0; y < height; y++) {
+        memcpy(pDest, pSrc, width);
+        pSrc += stride;
+        pDest += destStride;
     }
-
 }
 
-FrameAvailableCode FFMpegDecoder::renderToYCbCr420p(BitmapPtr pBmpY, BitmapPtr pBmpCb, 
-        BitmapPtr pBmpCr, long long timeWanted)
+static ProfilingZoneID RenderToBmpProfilingZone("FFMpeg: renderToBmp");
+static ProfilingZoneID CopyImageProfilingZone("FFMpeg: copy image");
+
+FrameAvailableCode FFMpegDecoder::renderToBmps(vector<BitmapPtr>& pBmps, 
+        double timeWanted)
 {
-    assert(m_State == DECODING);
-//    ScopeTimer Timer(*m_pRenderToBmpProfilingZone);
-    AVFrame Frame;
-    FrameAvailableCode FrameAvailable = readFrameForTime(Frame, timeWanted);
-    if (!m_bVideoEOF && FrameAvailable == FA_NEW_FRAME) {
-//        ScopeTimer Timer(*m_pConvertImageProfilingZone);
-        copyPlaneToBmp(pBmpY, Frame.data[0], Frame.linesize[0]);
-        copyPlaneToBmp(pBmpCb, Frame.data[1], Frame.linesize[1]);
-        copyPlaneToBmp(pBmpCr, Frame.data[2], Frame.linesize[2]);
+    AVG_ASSERT(m_State == DECODING);
+    ScopeTimer timer(RenderToBmpProfilingZone);
+    AVFrame frame;
+    FrameAvailableCode frameAvailable;
+    if (timeWanted == -1) {
+        readFrame(frame);
+        frameAvailable = FA_NEW_FRAME;
+    } else {
+        frameAvailable = readFrameForTime(frame, timeWanted);
+    }
+    if (!m_bVideoEOF && frameAvailable == FA_NEW_FRAME) {
+        if (pixelFormatIsPlanar(m_PF)) {
+            ScopeTimer timer(CopyImageProfilingZone);
+            for (unsigned i = 0; i < pBmps.size(); ++i) {
+                copyPlaneToBmp(pBmps[i], frame.data[i], frame.linesize[i]);
+            }
+        } else {
+            convertFrameToBmp(frame, pBmps[0]);
+        }
         return FA_NEW_FRAME;
     }
     return FA_USE_LAST_FRAME;
 }
 
-void FFMpegDecoder::throwAwayFrame(long long timeWanted)
+void FFMpegDecoder::throwAwayFrame(double timeWanted)
 {
-    assert(m_State == DECODING);
-    AVFrame Frame;
-    readFrameForTime(Frame, timeWanted);
+    AVG_ASSERT(m_State == DECODING);
+    AVFrame frame;
+    readFrameForTime(frame, timeWanted);
 }
 
-bool FFMpegDecoder::isEOF(StreamSelect Stream) const
+bool FFMpegDecoder::isEOF(StreamSelect stream) const
 {
-    assert(m_State == DECODING);
-    switch(Stream) {
+    AVG_ASSERT(m_State == DECODING);
+    switch(stream) {
         case SS_AUDIO:
             return (!m_pAStream || m_bAudioEOF);
         case SS_VIDEO:
@@ -599,15 +598,14 @@ bool FFMpegDecoder::isEOF(StreamSelect Stream) const
     }
 }
 
-int FFMpegDecoder::copyRawAudio(unsigned char* buf, int size)
+int FFMpegDecoder::copyRawAudio(unsigned char* pBuffer, int size)
 {
     int bytesWritten = min(m_SampleBufferEnd - m_SampleBufferStart, size);
-    memcpy(buf, m_pSampleBuffer + m_SampleBufferStart, bytesWritten);
+    memcpy(pBuffer, m_pSampleBuffer + m_SampleBufferStart, bytesWritten);
     
     m_SampleBufferStart += bytesWritten;
     
-    if(m_SampleBufferStart == m_SampleBufferEnd)
-    {
+    if (m_SampleBufferStart == m_SampleBufferEnd) {
         m_SampleBufferStart = 0;
         m_SampleBufferEnd = 0;
         m_SampleBufferLeft = SAMPLE_BUFFER_SIZE;
@@ -616,29 +614,27 @@ int FFMpegDecoder::copyRawAudio(unsigned char* buf, int size)
     return bytesWritten;
 }
 
-int FFMpegDecoder::copyResampledAudio(unsigned char* buf, int size)
+int FFMpegDecoder::copyResampledAudio(unsigned char* pBuffer, int size)
 {
     int bytesWritten = 0;
                         
     // If there is no buffered resampled data, resample some more
-    if(m_ResampleBufferStart >= m_ResampleBufferEnd)
+    if (m_ResampleBufferStart >= m_ResampleBufferEnd) {
         resampleAudio();
+    }
     
     // If we have some data in the resample buffer, copy it over
-    if(m_ResampleBufferStart < m_ResampleBufferEnd)
-    {
+    if (m_ResampleBufferStart < m_ResampleBufferEnd) {
         bytesWritten = min(m_ResampleBufferEnd - m_ResampleBufferStart, size);
-        memcpy(buf, m_pResampleBuffer + m_ResampleBufferStart, bytesWritten);
+        memcpy(pBuffer, m_pResampleBuffer + m_ResampleBufferStart, bytesWritten);
         
         m_ResampleBufferStart += bytesWritten;
-        if(m_ResampleBufferStart >= m_ResampleBufferEnd)
-        {
+        if (m_ResampleBufferStart >= m_ResampleBufferEnd) {
             m_ResampleBufferStart = 0;
             m_ResampleBufferEnd = 0;
         }
         
-        if(m_SampleBufferStart == m_SampleBufferEnd)
-        {
+        if (m_SampleBufferStart == m_SampleBufferEnd) {
             m_SampleBufferStart = 0;
             m_SampleBufferEnd = 0;
             m_SampleBufferLeft = SAMPLE_BUFFER_SIZE;
@@ -699,12 +695,14 @@ int FFMpegDecoder::decodeAudio()
 #endif
 
     // Skip frame on error
-    if (packetBytesDecoded < 0)
+    if (packetBytesDecoded < 0) {
         return -1;
+    }
     
     // Did not get any data, try again
-    if (packetBytesDecoded == 0)
+    if (packetBytesDecoded == 0) {
         return 0;
+    }
     
     // Adjust audio buffer pointers
     m_SampleBufferEnd += m_SampleBufferLeft;
@@ -718,46 +716,42 @@ int FFMpegDecoder::decodeAudio()
 
 int FFMpegDecoder::fillAudioBuffer(AudioBufferPtr pBuffer)
 {
-    assert(m_State == DECODING);
-    mutex::scoped_lock Lock(m_AudioMutex);
+    AVG_ASSERT(m_State == DECODING);
+    mutex::scoped_lock lock(m_AudioMutex);
 
-    unsigned char* outputAudioBuffer = (unsigned char*)(pBuffer->getData());
+    unsigned char* pOutputBuffer = (unsigned char*)(pBuffer->getData());
     int outputAudioBufferSize = pBuffer->getNumBytes();
 
-    assert (m_pAStream);
+    AVG_ASSERT (m_pAStream);
     if (m_bAudioEOF) {
         return 0;
     }
     
     int packetBytesDecoded;
     int bytesProduced;
-    unsigned char* pCurBufferPos = outputAudioBuffer;
+    unsigned char* pCurBufferPos = pOutputBuffer;
     int bufferLeft = outputAudioBufferSize;
     bool bFormatMatch = (m_EffectiveSampleRate == m_AP.m_SampleRate &&
                          m_pAStream->codec->channels == m_AP.m_Channels);
 
-    while(true)
-    {
-        while(true)
-        {
+    while (true) {
+        while (true) {
             // Consume any data left in the sample buffers
-            while(m_SampleBufferStart < m_SampleBufferEnd ||
+            while (m_SampleBufferStart < m_SampleBufferEnd ||
                   m_ResampleBufferStart < m_ResampleBufferEnd)
             {
                 // If the output format is different from the decoded format,
                 // then convert it, else copy it over
                 if (bFormatMatch) {
-                    bytesProduced =
-                        copyRawAudio(pCurBufferPos, bufferLeft);
+                    bytesProduced = copyRawAudio(pCurBufferPos, bufferLeft);
                 } else {
-                    bytesProduced =
-                        copyResampledAudio(pCurBufferPos, bufferLeft);
+                    bytesProduced = copyResampledAudio(pCurBufferPos, bufferLeft);
                 }
                 
                 pCurBufferPos += bytesProduced;
                 bufferLeft -= bytesProduced;
 
-                m_LastAudioFrameTime += (1000.0 * bytesProduced /
+                m_LastAudioFrameTime += (double(bytesProduced) /
                         (2 * m_AP.m_Channels * m_AP.m_SampleRate));
                 if (bufferLeft == 0) {
                     volumize(pBuffer);
@@ -787,17 +781,12 @@ int FFMpegDecoder::fillAudioBuffer(AudioBufferPtr pBuffer)
         
         // Get a new packet from the audio stream
         m_AudioPacket = m_pDemuxer->getPacket(m_AStreamIndex);
-        
-        if(!m_AudioPacket) {
+        if (!m_AudioPacket) {
             m_bAudioEOF = true;
+            volumize(pBuffer);
             return pBuffer->getNumFrames()-bufferLeft/(pBuffer->getFrameSize());
         }
-/* 
-        if(m_AudioPacket->dts != AV_NOPTS_VALUE) {
-            long long dts = (long long)(1000.0 * av_q2d(m_pAStream->time_base) * 
-                    m_AudioPacket->dts - m_AudioStartTimestamp);
-        }
-*/
+
         // Initialize packet data pointers
         m_AudioPacketData = m_AudioPacket->data;
         m_AudioPacketSize = m_AudioPacket->size;
@@ -817,50 +806,58 @@ PixelFormat FFMpegDecoder::calcPixelFormat(bool bUseYCbCr)
                 return YCbCr420p;
             case PIX_FMT_YUVJ420P:
                 return YCbCrJ420p;
+            case PIX_FMT_YUVA420P:
+                return YCbCrA420p;
             default:
                 break;
         }
     }
-    if (enc->pix_fmt == PIX_FMT_BGRA) {
+    if (enc->pix_fmt == PIX_FMT_BGRA || enc->pix_fmt == PIX_FMT_YUVA420P) {
         return B8G8R8A8;
     }
     return B8G8R8X8;
 }
 
-void FFMpegDecoder::convertFrameToBmp(AVFrame& Frame, BitmapPtr pBmp)
+static ProfilingZoneID ConvertImageLibavgProfilingZone(
+            "FFMpeg: colorspace conv (libavg)");
+static ProfilingZoneID ConvertImageSWSProfilingZone("FFMpeg: colorspace conv (SWS)");
+static ProfilingZoneID SetAlphaProfilingZone("FFMpeg: set alpha channel");
+
+void FFMpegDecoder::convertFrameToBmp(AVFrame& frame, BitmapPtr pBmp)
 {
-    AVPicture DestPict;
+    AVPicture destPict;
     unsigned char * pDestBits = pBmp->getPixels();
-    DestPict.data[0] = pDestBits;
-    DestPict.linesize[0] = pBmp->getStride();
+    destPict.data[0] = pDestBits;
+    destPict.linesize[0] = pBmp->getStride();
 #if LIBAVFORMAT_BUILD >= ((50<<16)+(0<<8)+0)
-    ::PixelFormat DestFmt;
+    ::PixelFormat destFmt;
 #else
-    int DestFmt;
+    int destFmt;
 #endif
     switch(pBmp->getPixelFormat()) {
         case R8G8B8X8:
         case R8G8B8A8:
             // XXX: Unused and broken.
-            DestFmt = PIX_FMT_BGRA;
+            destFmt = PIX_FMT_BGRA;
             break;
         case B8G8R8X8:
         case B8G8R8A8:
-            DestFmt = PIX_FMT_BGRA;
+            destFmt = PIX_FMT_BGRA;
             break;
         case R8G8B8:
-            DestFmt = PIX_FMT_RGB24;
+            destFmt = PIX_FMT_RGB24;
             break;
         case B8G8R8:
-            DestFmt = PIX_FMT_BGR24;
+            destFmt = PIX_FMT_BGR24;
             break;
         case YCbCr422:
-            DestFmt = PIX_FMT_YUYV422;
+            destFmt = PIX_FMT_YUYV422;
             break;
         default:
             AVG_TRACE(Logger::ERROR, "FFMpegDecoder: Dest format " 
-                    << pBmp->getPixelFormatString() << " not supported.");
-            assert(false);
+                    << pBmp->getPixelFormat() << " not supported.");
+            AVG_ASSERT(false);
+            destFmt = PIX_FMT_BGRA;
     }
 #if LIBAVFORMAT_BUILD < ((49<<16)+(0<<8)+0)
     AVCodecContext *enc = &m_pVStream->codec;
@@ -868,32 +865,36 @@ void FFMpegDecoder::convertFrameToBmp(AVFrame& Frame, BitmapPtr pBmp)
     AVCodecContext *enc = m_pVStream->codec;
 #endif
     {
-//            ScopeTimer Timer(*m_pConvertImageProfilingZone);
-        if (DestFmt == PIX_FMT_BGRA && enc->pix_fmt == PIX_FMT_YUV420P) {
-            BitmapPtr pBmpY(new Bitmap(pBmp->getSize(), I8, Frame.data[0],
-                    Frame.linesize[0], false));
-            BitmapPtr pBmpU(new Bitmap(pBmp->getSize(), I8, Frame.data[1],
-                    Frame.linesize[1], false));
-            BitmapPtr pBmpV(new Bitmap(pBmp->getSize(), I8, Frame.data[2],
-                    Frame.linesize[2], false));
-            pBmp->copyYUVPixels(*pBmpY, *pBmpU, *pBmpV);
+        if (destFmt == PIX_FMT_BGRA && (enc->pix_fmt == PIX_FMT_YUV420P || 
+                enc->pix_fmt == PIX_FMT_YUVJ420P))
+        {
+            ScopeTimer timer(ConvertImageLibavgProfilingZone);
+            BitmapPtr pBmpY(new Bitmap(pBmp->getSize(), I8, frame.data[0],
+                    frame.linesize[0], false));
+            BitmapPtr pBmpU(new Bitmap(pBmp->getSize(), I8, frame.data[1],
+                    frame.linesize[1], false));
+            BitmapPtr pBmpV(new Bitmap(pBmp->getSize(), I8, frame.data[2],
+                    frame.linesize[2], false));
+            pBmp->copyYUVPixels(*pBmpY, *pBmpU, *pBmpV, enc->pix_fmt == PIX_FMT_YUVJ420P);
         } else {
             if (!m_pSwsContext) {
                 m_pSwsContext = sws_getContext(enc->width, enc->height, enc->pix_fmt,
-                            enc->width, enc->height, DestFmt, SWS_BICUBIC, 
+                            enc->width, enc->height, destFmt, SWS_BICUBIC, 
                             NULL, NULL, NULL);
-                if(!m_pSwsContext) {
-                    AVG_TRACE(Logger::ERROR, "FFMpegDecoder: sws initialization failed.");
-                }
+                AVG_ASSERT(m_pSwsContext);
+            }
+            {
+                ScopeTimer timer(ConvertImageSWSProfilingZone);
+                sws_scale(m_pSwsContext, frame.data, frame.linesize, 0, 
+                    enc->height, destPict.data, destPict.linesize);
             }
-            sws_scale(m_pSwsContext, Frame.data, Frame.linesize, 0, 
-                enc->height, DestPict.data, DestPict.linesize);
             if (pBmp->getPixelFormat() == B8G8R8X8) {
+                ScopeTimer timer(SetAlphaProfilingZone);
                 // Make sure the alpha channel is white.
                 // TODO: This is slow. Make OpenGL do it.
                 unsigned char * pLine = pBmp->getPixels();
                 IntPoint size = pBmp->getSize();
-                for (int y = 0; y<size.y; ++y) {
+                for (int y = 0; y < size.y; ++y) {
                     unsigned char * pPixel = pLine;
                     for (int x = 0; x < size.x; ++x) {
                         pPixel[3] = 0xFF;
@@ -908,15 +909,15 @@ void FFMpegDecoder::convertFrameToBmp(AVFrame& Frame, BitmapPtr pBmp)
        
 PixelFormat FFMpegDecoder::getPixelFormat() const
 {
-    assert(m_State != CLOSED);
+    AVG_ASSERT(m_State != CLOSED);
     return m_PF;
 }
 
 void FFMpegDecoder::initVideoSupport()
 {
-    if (!m_bInitialized) {
+    if (!s_bInitialized) {
         av_register_all();
-        m_bInitialized = true;
+        s_bInitialized = true;
         // Tune libavcodec console spam.
 //        av_log_set_level(AV_LOG_DEBUG);
         av_log_set_level(AV_LOG_QUIET);
@@ -925,165 +926,122 @@ void FFMpegDecoder::initVideoSupport()
 
 int FFMpegDecoder::getNumFrames() const
 {
-    assert(m_State != CLOSED);
+    AVG_ASSERT(m_State != CLOSED);
     // This is broken for some videos, but the code here is correct.
     // So fix ffmpeg :-).
 #if LIBAVFORMAT_BUILD < ((49<<16)+(0<<8)+0)
     return m_pVStream->r_frame_rate*(m_pVStream->duration/AV_TIME_BASE);
 #else
-    double timeUnitsPerSecond = 1/av_q2d(m_pVStream->time_base);
-    return int((m_pVStream->r_frame_rate.num/m_pVStream->r_frame_rate.den)*
-            (m_pVStream->duration/timeUnitsPerSecond));
+    return int(m_pVStream->nb_frames);
 #endif 
 }
 
-FrameAvailableCode FFMpegDecoder::readFrameForTime(AVFrame& Frame, long long timeWanted)
+FrameAvailableCode FFMpegDecoder::readFrameForTime(AVFrame& frame, double timeWanted)
 {
-    assert(m_State == DECODING);
-    // XXX: This code is sort-of duplicated in AsyncVideoDecoder::getBmpsForTime()
-    long long FrameTime = -1000;
-
-/*
-    bool bDebug = (m_sFilename == "/home/uzadow/wos_videos/c-wars/thumbs/cwars-scene3.avi");
-    if (bDebug) {
-        cerr << m_sFilename << " readFrameForTime " << timeWanted 
-                << ", LastFrameTime= " << m_LastFrameTime << ", diff= " 
-                << timeWanted-m_LastFrameTime << endl;
-    }
-*/    
-    if (timeWanted == -1) {
-        readFrame(Frame, FrameTime);
+    AVG_ASSERT(m_State == DECODING);
+//    cerr << "        readFrameForTime " << timeWanted << ", LastFrameTime= " 
+//            << m_LastVideoFrameTime << ", diff= " << m_LastVideoFrameTime-timeWanted 
+//            << endl;
+    AVG_ASSERT(timeWanted != -1);
+    double timePerFrame = 1.0/m_FPS;
+    if (timeWanted-m_LastVideoFrameTime < 0.5*timePerFrame) {
+//        cerr << "DISPLAY AGAIN." << endl;
+        // The last frame is still current. Display it again.
+        return FA_USE_LAST_FRAME;
     } else {
-        double TimePerFrame = 1000/m_FPS;
-        if (timeWanted-m_LastVideoFrameTime < 0.5*TimePerFrame) {
-/*            
-            if (bDebug) {
-                cerr << "   LastFrameTime = " << m_LastFrameTime << ", display again."
-                        <<  endl;
-            }
-*/            
-            // The last frame is still current. Display it again.
-            return FA_USE_LAST_FRAME;
-        } else {
-            while (FrameTime-timeWanted < -0.5*TimePerFrame && !m_bVideoEOF) {
-                readFrame(Frame, FrameTime);
-/*                
-                if (bDebug) {
-                    cerr << "   readFrame returned time " << FrameTime << "." <<  endl;
-                }
-*/                
-            }
-/*
-            if (bDebug) {
-                cerr << "  frame ok." << endl;
-            }
-*/            
+        double frameTime = -1;
+        while (frameTime-timeWanted < -0.5*timePerFrame && !m_bVideoEOF) {
+            frameTime = readFrame(frame);
+//            cerr << "        readFrame returned time " << frameTime << ", diff= " <<
+//                    frameTime-timeWanted <<  endl;
         }
+//        cerr << "NEW FRAME." << endl;
     }
     return FA_NEW_FRAME;
 }
 
-void FFMpegDecoder::readFrame(AVFrame& Frame, long long& FrameTime)
+static ProfilingZoneID DecodeProfilingZone("FFMpeg: decode");
+
+double FFMpegDecoder::readFrame(AVFrame& frame)
 {
-    assert(m_pDemuxer);
-    if (m_bVideoEOF) {
-        seek(0);
-        return;
-    }
+    AVG_ASSERT(m_State == DECODING);
+    ScopeTimer timer(DecodeProfilingZone); 
+
     if (m_bEOFPending) {
         m_bVideoEOF = true;
         m_bEOFPending = false;
-        return;
+        return m_LastVideoFrameTime;
     }
 #if LIBAVFORMAT_BUILD < ((49<<16)+(0<<8)+0)
     AVCodecContext *enc = &m_pVStream->codec;
 #else
     AVCodecContext *enc = m_pVStream->codec;
 #endif
-    if (enc->codec_id == CODEC_ID_RAWVIDEO) {
-        AVPacket * pPacket;
+    int bGotPicture = 0;
+    AVPacket* pPacket = 0;
+    double frameTime = -1;
+    while (!bGotPicture && !m_bVideoEOF) {
         pPacket = m_pDemuxer->getPacket(m_VStreamIndex);
-        if (!pPacket) {
-            m_bVideoEOF = true;
-            return;
-        }
-        avpicture_fill((AVPicture*)&Frame, pPacket->data, 
-                enc->pix_fmt, 
-                enc->width, enc->height);
-        av_free_packet(pPacket);
-        delete pPacket;
-    } else {
-        int gotPicture = 0;
-        while (!gotPicture) {
-            if (m_PacketLenLeft <= 0) {
-                if (!m_bFirstPacket) {
-                    av_free_packet(m_pPacket);
-                    delete m_pPacket;
-                }
-                m_bFirstPacket = false;
-                m_pPacket = m_pDemuxer->getPacket(m_VStreamIndex);
-                if (!m_pPacket) {
-                    // No more packets -> EOF. Decode the last data we got.
-                    avcodec_decode_video(enc, &Frame, &gotPicture, NULL, 0);
-                    if (gotPicture) {
-                        m_bEOFPending = true;
-                    } else {
-                        m_bVideoEOF = true;
-                    }
-                    // We don't have a timestamp for the last frame, so we'll
-                    // calculate it based on the frame before.
-                    FrameTime = m_LastVideoFrameTime+(long long)(1000.0/m_FPS);
-                    m_LastVideoFrameTime = FrameTime;
-                    return;
-                }
-                m_PacketLenLeft = m_pPacket->size;
-                m_pPacketData = m_pPacket->data;
+        m_bFirstPacket = false;
+        if (pPacket) {
+            int len1 = avcodec_decode_video(enc, &frame, &bGotPicture, pPacket->data,
+                    pPacket->size);
+            if (len1 > 0) {
+                AVG_ASSERT(len1 == pPacket->size);
             }
-            int Len1 = avcodec_decode_video(enc, &Frame,
-                    &gotPicture, m_pPacketData, m_PacketLenLeft);
-            if (Len1 <= 0) {
-//                AVG_TRACE(Logger::WARNING, "Error decoding " <<
-//                        m_sFilename);
-                m_PacketLenLeft = 0;
+            if (bGotPicture) {
+                frameTime = getFrameTime(pPacket->dts);
+            }
+            av_free_packet(pPacket);
+            delete pPacket;
+        } else {
+            // No more packets -> EOF. Decode the last data we got.
+            avcodec_decode_video(enc, &frame, &bGotPicture, 0, 0);
+            if (bGotPicture) {
+                m_bEOFPending = true;
             } else {
-                m_pPacketData += Len1;
-                m_PacketLenLeft -= Len1;
+                m_bVideoEOF = true;
             }
+            // We don't have a timestamp for the last frame, so we'll
+            // calculate it based on the frame before.
+            frameTime = m_LastVideoFrameTime+1.0/m_FPS;
+            m_LastVideoFrameTime = frameTime;
         }
-        FrameTime = getFrameTime(m_pPacket);
-/*
-        cerr << "coded_picture_number: " << Frame.coded_picture_number <<
-                ", display_picture_number: " << Frame.display_picture_number <<
-                ", pts: " << Frame.pts << endl;
-
-        cerr << "key_frame: " << Frame.key_frame << 
-               ", pict_type: " << Frame.pict_type << endl;
-        AVFrac spts = m_pVStream->pts;
-        cerr << "Stream.pts: " << spts.val + double(spts.num)/spts.den << endl;
-*/
     }
+    AVG_ASSERT(frameTime != -1)
+    return frameTime;
+/*
+    cerr << "coded_picture_number: " << frame.coded_picture_number <<
+            ", display_picture_number: " << frame.display_picture_number <<
+            ", pts: " << frame.pts << endl;
+
+    cerr << "key_frame: " << frame.key_frame << 
+           ", pict_type: " << frame.pict_type << endl;
+    AVFrac spts = m_pVStream->pts;
+    cerr << "Stream.pts: " << spts.val + double(spts.num)/spts.den << endl;
+*/
 }
 
-long long FFMpegDecoder::getFrameTime(AVPacket* pPacket)
+double FFMpegDecoder::getFrameTime(long long dts)
 {
     if (m_VideoStartTimestamp == -1) {
-        m_VideoStartTimestamp = (long long)((1000*pPacket->dts)/m_TimeUnitsPerSecond);
+        m_VideoStartTimestamp = double(dts)/m_TimeUnitsPerSecond;
     }
-    long long FrameTime;
+    double frameTime;
     if (m_bUseStreamFPS) {
-        FrameTime = (long long)((1000*pPacket->dts)/m_TimeUnitsPerSecond)-m_VideoStartTimestamp;
+        frameTime = double(dts)/m_TimeUnitsPerSecond-m_VideoStartTimestamp;
     } else {
-        if (m_LastVideoFrameTime == -1000) {
-            FrameTime = 0;
+        if (m_LastVideoFrameTime == -1) {
+            frameTime = 0;
         } else {
-            FrameTime = m_LastVideoFrameTime + (long long)(1000.0/m_FPS);
+            frameTime = m_LastVideoFrameTime + 1.0/m_FPS;
         }
     }
-    m_LastVideoFrameTime = FrameTime;
-    return FrameTime;
+    m_LastVideoFrameTime = frameTime;
+    return frameTime;
 }
 
-long long FFMpegDecoder::getStartTime()
+double FFMpegDecoder::getStartTime()
 {
     if (m_pVStream) {
         return m_VideoStartTimestamp;
@@ -1118,8 +1076,9 @@ void FFMpegDecoder::volumize(AudioBufferPtr pBuffer)
     double curVol = m_Volume;
     double volDiff = m_LastVolume - curVol;
     
-    if(curVol == 1.0 && volDiff == 0.0)
+    if (curVol == 1.0 && volDiff == 0.0) {
         return;
+    }
    
     short * pData = pBuffer->getData();
     for (int i = 0; i < pBuffer->getNumFrames()*pBuffer->getNumChannels(); i++) {
