@@ -38,18 +38,19 @@ namespace avg {
 
 class AVG_API VideoDemuxerThread: public WorkerThread<VideoDemuxerThread> {
     public:
-        VideoDemuxerThread(CmdQueue& CmdQ, AVFormatContext * pFormatContext);
+        VideoDemuxerThread(CQueue& cmdQ, AVFormatContext * pFormatContext, 
+                const std::map<int, VideoPacketQueuePtr>& m_PacketQs);
         virtual ~VideoDemuxerThread();
         bool init();
         bool work();
         void deinit();
 
-        void enableStream(VideoPacketQueuePtr pPacketQ, int StreamIndex);
-        void seek(long long DestTime);
+        void enableStream(VideoPacketQueuePtr pPacketQ, int streamIndex);
+        void seek(double DestTime);
 
     private:
-        void onStreamEOF(int StreamIndex);
-        
+        void onStreamEOF(int streamIndex);
+       
         std::map<int, VideoPacketQueuePtr> m_PacketQs;
         std::map<int, bool> m_PacketQbEOF;
         bool m_bEOF;
