@@ -24,10 +24,11 @@
 
 #include "../api.h"
 #include "../base/Point.h"
-#include "../base/IntTriple.h"
+#include "../base/Triple.h"
 #include "../base/Exception.h"
 
 #include "../player/BoostPython.h"
+#include "../player/Player.h"
 
 #include <string>
 
@@ -271,80 +272,6 @@ struct from_python_sequence
   }
 };
 
-template<class NUM>
-struct Point_to_python_tuple
-{
-    static PyObject* convert (avg::Point<NUM> pt)
-    {
-        return boost::python::incref(boost::python::make_tuple(pt.x, pt.y).ptr());
-    }
-};
-
-template<class POINT, class ATTR>
-struct DPoint_from_python_tuple
-{
-    DPoint_from_python_tuple() 
-    {
-        boost::python::converter::registry::push_back(
-                &convertible, &construct, boost::python::type_id<POINT>());
-    }
-    
-    static void* convertible(PyObject* obj_ptr)
-    {
-        if (!PyTuple_Check(obj_ptr)) return 0;
-        return obj_ptr;
-    }
-
-    static void construct(PyObject* obj_ptr,
-            boost::python::converter::rvalue_from_python_stage1_data* data)
-    {
-        POINT pt;
-        PyObject * pEntry = PyTuple_GetItem(obj_ptr, 0);
-        pt.x = (ATTR)PyFloat_AsDouble(pEntry);
-        pEntry = PyTuple_GetItem(obj_ptr, 1);
-        pt.y = (ATTR)PyFloat_AsDouble(pEntry);
-        void* storage = (
-                (boost::python::converter::rvalue_from_python_storage<POINT>*)data)
-                    ->storage.bytes;
-        new (storage) POINT(pt);
-        data->convertible = storage;
-    }
-};
-
-
-struct IntTriple_from_python_tuple
-{
-    IntTriple_from_python_tuple() 
-    {
-        boost::python::converter::registry::push_back(
-                &convertible, &construct, boost::python::type_id<avg::IntTriple>());
-    }
-    
-    static void* convertible(PyObject* obj_ptr)
-    {
-        if (!PyTuple_Check(obj_ptr)) return 0;
-        return obj_ptr;
-    }
-
-    static void construct(PyObject* obj_ptr,
-            boost::python::converter::rvalue_from_python_stage1_data* data)
-    {
-        avg::IntTriple pt;
-        PyObject * pEntry = PyTuple_GetItem(obj_ptr, 0);
-        pt.x = (int)PyFloat_AsDouble(pEntry);
-        pEntry = PyTuple_GetItem(obj_ptr, 1);
-        pt.y = (int)PyFloat_AsDouble(pEntry);
-        pEntry = PyTuple_GetItem(obj_ptr, 2);
-        pt.z = (int)PyFloat_AsDouble(pEntry);
-        void* storage = (
-                (boost::python::converter::rvalue_from_python_storage<avg::IntTriple>*)data)
-                    ->storage.bytes;
-        new (storage) avg::IntTriple(pt);
-        data->convertible = storage;
-    }
-};
-
-
 template<class T>
 double deprecatedGet(T& node)
 {
@@ -380,5 +307,11 @@ public:
     operator avg::DPoint() const;
 };
 
+template<const char * pszType> 
+avg::NodePtr createNode(const boost::python::tuple &args,
+        const boost::python::dict &attrs)
+{
+    return avg::Player::get()->createNode(pszType, attrs);
+}
 
 #endif
